@@ -61,7 +61,9 @@ if t.TYPE_CHECKING:  # pragma: no cover
 
         @classmethod
         def parse_isoformat(
-            cls, isoformat: str, default_tz: datetime.timezone = ...
+            cls,
+            isoformat: str,
+            default_tz: datetime.timezone = ...,
         ) -> 'DatetimeWithTimezone':
             ...
 
@@ -138,7 +140,9 @@ else:
 
         @classmethod
         def parse_isoformat(
-            cls, isoformat: str, default_tz: datetime.timezone = _utc
+            cls,
+            isoformat: str,
+            default_tz: datetime.timezone = _utc,
         ) -> 'DatetimeWithTimezone':
             import dateutil.parser  # pylint: disable=import-outside-toplevel
             dt = dateutil.parser.isoparse(isoformat)
@@ -150,7 +154,9 @@ else:
 
         @classmethod
         def fromisoformat(
-            cls, isoformat: str, default_tz: datetime.timezone = _utc
+            cls,
+            isoformat: str,
+            default_tz: datetime.timezone = _utc,
         ) -> 'DatetimeWithTimezone':
             dt = datetime.datetime.fromisoformat(isoformat)
             if dt.tzinfo is None:
