@@ -59,7 +59,7 @@ class _Nothing(t.Generic[_T]):
     def or_default(self, value: _Y) -> _Y:
         return value
 
-    def or_none(self) -> t.Optional[_Y]:
+    def or_none(self) -> None:
         return None
 
     def or_default_lazy(self, _producer: t.Callable[[], _Y]) -> _Y:
@@ -112,7 +112,7 @@ class _Nothing(t.Generic[_T]):
         >>> Nothing.is_nothing_instance(Just(5))
         False
         """
-        return isinstance(obj, cls)
+        return obj is Nothing or isinstance(obj, cls)
 
     def __bool__(self) -> Literal[False]:
         raise Exception('Do not check Nothing for boolean value')
@@ -123,6 +123,9 @@ class _Nothing(t.Generic[_T]):
     def join(self: '_Nothing[Maybe[_Y]]') -> '_Nothing[_Y]':
         return Nothing
 
+    def filter(self, _pred: t.Callable[[_T], bool]) -> '_Nothing[_T]':
+        return self
+
     def eq(
         self: '_Nothing[_Y]',
         val: _Y,  # pylint: disable=unused-argument
