@@ -3,28 +3,18 @@
 import abc
 import copy
 import enum
-import uuid
 import typing as t
 import inspect
-import datetime
-import collections
 
-from typing_extensions import Final, Literal, TypedDict
+from typing_extensions import Final, TypedDict
 
 import cg_maybe
-from cg_dt_utils import DatetimeWithTimezone
 
 from ._base import Parser, SimpleValue
-from ._enum import EnumValue, StringEnum
-from ._list import List, TwoTuple
-from ._query import QueryParam
+from ._enum import StringEnum
 from ._utils import USE_SLOTS as _USE_SLOTS
 from ._utils import T as _T
-from ._utils import is_typeddict
-from ._nullable import Nullable
-from ._any_value import AnyValue
 from .exceptions import ParseError, SimpleParseError, MultipleParseErrors
-from ._rich_value import RichValue
 from ._swagger_utils import OpenAPISchema
 
 __all__ = (
@@ -93,7 +83,6 @@ class _Argument(t.Generic[_T, _Key]):
 class RequiredArgument(t.Generic[_T, _Key], _Argument[_T, _Key]):
     """An argument in a ``FixedMapping`` that is required to be present.
     """
-
     def describe(self) -> str:
         return f'{self.key}: {self.value.describe()}'
 
@@ -144,7 +133,6 @@ class DefaultArgument(t.Generic[_T, _Key], _Argument[_T, _Key]):
 class OptionalArgument(t.Generic[_T, _Key], _Argument[_T, _Key]):
     """An argument in a ``FixedMapping`` that doesn't have to be present.
     """
-
     def describe(self) -> str:
         return f'{self.key}?: {self.value.describe()}'
 
@@ -190,7 +178,6 @@ class _BaseFixedMapping(t.Generic[_BaseDictT]):
     def __init__(self, arguments: t.Sequence[_Argument]) -> None:
         super().__init__()
         self._arguments = arguments
-        self.__schema: t.Optional[t.Type[_BaseDictT]] = None
         self._on_extra = OnExtraAction.nothing
 
     def set_on_extra(
@@ -226,8 +213,9 @@ class _BaseFixedMapping(t.Generic[_BaseDictT]):
             content = ', '.join(args)
         return 'Mapping[{}]'.format(content)
 
-    def to_open_api_as_query(self, schema: OpenAPISchema
-                             ) -> t.Sequence[t.Mapping[str, t.Any]]:
+    def to_open_api_as_query(
+        self, schema: OpenAPISchema
+    ) -> t.Sequence[t.Mapping[str, t.Any]]:
         """Convert this mapping to a OpenAPI object as if it were used as a
         query string.
         """
@@ -306,7 +294,6 @@ class BaseFixedMapping(
         :meth:`.BaseFixedMapping.from_typeddict`, not using the normal
         constructor.
     """
-
     def __init__(
         self,
         *arguments: object,
@@ -316,13 +303,13 @@ class BaseFixedMapping(
         self.__has_optional = any(
             isinstance(arg, OptionalArgument) for arg in self._arguments
         )
-        self.__schema: t.Optional[t.Type[_BaseDictT]] = schema
+        self._schema: t.Optional[t.Type[_BaseDictT]] = schema
 
     def _to_open_api(self, schema: OpenAPISchema) -> t.Mapping[str, t.Any]:
-        if self.__schema is None:
+        if self._schema is None:
             return super()._to_open_api(schema)
         else:
-            return schema.add_schema(self.__schema)
+            return schema.add_schema(self._schema)
 
     def describe(self) -> str:
         return self._describe(self._use_readable_describe)
@@ -348,91 +335,6 @@ class BaseFixedMapping(
 
         return res
 
-    @classmethod
-    def __from_python_type(cls, typ, from_query):  # type: ignore
-        # pylint: disable=too-many-return-statements,too-many-nested-blocks,too-many-branches
-        # This function doesn't play nice at all with our plugins, so simply
-        # skip checking it.
-        origin = getattr(typ, '__origin__', None)
-
-        def assert_not_query(cond: bool = False) -> None:
-            if from_query and not cond:  # pragma: no cover
-                raise AssertionError(
-                    '{} is not supported as query param'.format(typ)
-                )
-
-        if is_typeddict(typ):
-            args = []
-            for key, subtyp in typ.__annotations__.items():
-                if key in typ.__required_keys__:
-                    args.append(
-                        RequiredArgument(
-                            key,
-                            cls.__from_python_type(subtyp, from_query),
-                            '',
-                        )
-                    )
-                else:
-                    args.append(
-                        OptionalArgument(
-                            key,
-                            cls.__from_python_type(subtyp, from_query),
-                            '',
-                        )
-                    )
-            return BaseFixedMapping(*args, schema=typ)
-        elif typ in (str, int, bool, float):
-            if from_query:
-                return getattr(QueryParam, typ.__name__)
-            else:
-                return getattr(SimpleValue, typ.__name__)
-        elif origin in (list, collections.abc.Sequence):
-            assert_not_query()
-
-            return List(cls.__from_python_type(typ.__args__[0], from_query))
-        elif origin == t.Union:
-            has_none = type(None) in typ.__args__
-            assert_not_query(not has_none)
-
-            first_arg, *args = [a for a in typ.__args__ if a != type(None)]
-            res = cls.__from_python_type(first_arg, from_query)
-            for item in args:
-                res = res | cls.__from_python_type(item, from_query)
-            return Nullable(res) if has_none else res
-        elif origin == Literal:
-            assert all(isinstance(arg, str) for arg in typ.__args__)
-            return StringEnum(*typ.__args__)
-        elif isinstance(typ, enum.EnumMeta):
-            return EnumValue(typ)
-        elif origin == dict:
-            assert_not_query()
-
-            key, value = typ.__args__
-            assert key == str, (
-                'Only mappings with strings as keys are supported'
-            )
-            return LookupMapping(cls.__from_python_type(value, from_query))
-        elif typ == uuid.UUID:
-            return RichValue.UUID
-        elif origin == tuple and len(typ.__args__) == 2:
-            assert_not_query()
-
-            return TwoTuple(
-                cls.__from_python_type(typ.__args__[0], from_query),
-                cls.__from_python_type(typ.__args__[1], from_query),
-            )
-        elif typ == DatetimeWithTimezone:
-            return RichValue.DateTime
-        elif typ == datetime.timedelta:
-            assert_not_query()
-            return RichValue.TimeDelta
-        elif typ == t.Any:
-            return AnyValue
-        else:  # pragma: no cover
-            raise AssertionError(
-                f'Could not convert: {typ} (origin: {origin})'
-            )
-
     @classmethod
     def from_function_parameters_list(
         cls,
@@ -441,14 +343,19 @@ class BaseFixedMapping(
     ) -> 'BaseFixedMapping[t.Any]':
         """Create a BaseFixedMapping from a list of function parameters.
         """
+        # pylint: disable=import-outside-toplevel
+        from ._convert import ConvertCtx
+
         args = []
         for param in params:
+            sub_parser = ConvertCtx(param.annotation, from_query,
+                                    False).convert()
             if param.default == inspect.Parameter.empty:
                 args.append(
                     RequiredArgument(  # type: ignore
                         param.name,
-                        cls.__from_python_type(param.annotation, from_query),
-                        '',
+                        sub_parser,
+                        ''
                     )
                 )
             else:
@@ -457,7 +364,7 @@ class BaseFixedMapping(
                 args.append(
                     DefaultArgument(  # type: ignore
                         param.name,
-                        cls.__from_python_type(param.annotation, from_query),
+                        sub_parser,
                         '',
                         default=t.cast(
                             t.Callable,
@@ -479,10 +386,18 @@ class BaseFixedMapping(
         )
 
     @classmethod
-    def from_typeddict(cls, typeddict: t.Type) -> 'BaseFixedMapping[t.Any]':
+    def from_typeddict(
+        cls,
+        typeddict: t.Type,
+        *,
+        readable: bool = False
+    ) -> 'BaseFixedMapping[t.Any]':
         """Create a mapping from an existing typeddict.
         """
-        return cls.__from_python_type(typeddict, False)
+        # pylint: disable=import-outside-toplevel
+        from ._convert import ConvertCtx
+        res = ConvertCtx(typeddict, False, readable=readable).convert()
+        return t.cast(BaseFixedMapping[t.Any], res)
 
 
 class FixedMapping(
@@ -492,7 +407,6 @@ class FixedMapping(
     """A mapping in which the keys are fixed and the values can have different
     types.
     """
-
     def __init__(self, *arguments: object) -> None:
         super().__init__(t.cast(t.Any, arguments))
         self.__tag: t.Optional[t.Tuple[str, object]] = None
@@ -536,6 +450,32 @@ class FixedMapping(
         args = [*self._arguments, *other._arguments]  # pylint: disable=protected-access
         return FixedMapping(*args)  # type: ignore
 
+    @classmethod
+    def make_discriminated_union(
+        cls,
+        discriminator: str,
+        *parsers: 'FixedMapping[t.Any]',
+    ) -> 'DiscriminatedUnion[t.Any]':
+        """Make a discriminated union based on a given discriminator.
+
+        :param discriminator: The key to be used as the discriminator.
+        :param parsers: The list of parsers to use for the union. Each parser
+            should map ``discriminator`` to a unique string literal.
+
+        :returns: The created union.
+        """
+        def get_value(parser: FixedMapping) -> str:
+            for arg in parser._arguments:  # pylint: disable=protected-access
+                if arg.key == discriminator:
+                    assert isinstance(arg, RequiredArgument)
+                    assert isinstance(arg.value, StringEnum)
+                    assert len(arg.value.opts) == 1
+                    return next(iter(arg.value.opts))
+            assert False
+
+        lookup = {get_value(parser): parser for parser in parsers}
+        return DiscriminatedUnion(discriminator, lookup)
+
 
 class LookupMapping(t.Generic[_T], Parser[t.Mapping[str, _T]]):
     """A parser that implements a lookup mapping.
@@ -577,3 +517,122 @@ class LookupMapping(t.Generic[_T], Parser[t.Mapping[str, _T]]):
             raise MultipleParseErrors(self, value, errors)
 
         return result
+
+
+class DiscriminatedUnion(t.Generic[_T], Parser[_T]):
+    """A union of mappings discriminated by a single key.
+    """
+    if _USE_SLOTS:
+        __slots__ = ('__discriminator', '__parser_lookup', '__key_parser')
+
+    def __init__(
+        self,
+        discriminator: str,
+        parser_lookup: t.Mapping[str, Parser[_T]],
+    ) -> None:
+        super().__init__()
+        self.__discriminator = discriminator
+        self.__parser_lookup = parser_lookup
+        self.__key_parser = StringEnum(*parser_lookup.keys())  # type: ignore
+
+    @classmethod
+    def maybe_create(
+        cls, parsers: t.Sequence[Parser[_T]]
+    ) -> cg_maybe.Maybe['DiscriminatedUnion[_T]']:
+        """Try to create a discriminated union from a list of parsers.
+
+        :param parses: The parsers to create a discriminated union from.
+
+        :returns: Maybe the create union.
+        """
+        if not parsers:
+            return cg_maybe.Nothing
+
+        first, *rest = parsers
+        if not isinstance(first, (BaseFixedMapping, FixedMapping)):
+            return cg_maybe.Nothing
+
+        def _is_possible(arg: _Argument) -> t.Sequence[str]:
+            if (
+                isinstance(arg, RequiredArgument) and
+                isinstance(arg.value, StringEnum) and len(arg.value.opts) == 1
+            ):
+                return (next(iter(arg.value.opts)), )
+            return ()
+
+        arguments = first._arguments  # pylint: disable=protected-access
+        possible_keys = {
+            arg.key: {value: first}
+            for arg in arguments for value in _is_possible(arg)
+        }
+        for parser in rest:
+            if not isinstance(parser, (BaseFixedMapping, FixedMapping)):
+                return cg_maybe.Nothing
+
+            found_any = False
+
+            for arg in parser._arguments:  # pylint: disable=protected-access
+                vals = possible_keys.get(arg.key)
+                if vals is None:
+                    continue
+                new_opt = _is_possible(arg)
+                # The arg is not valid or we found a duplicate value.
+                if not new_opt or new_opt[0] in vals:
+                    del possible_keys[arg.key]
+                else:
+                    vals[new_opt[0]] = parser
+                    found_any = True
+            if not found_any:
+                return cg_maybe.Nothing
+
+        if not possible_keys:
+            return cg_maybe.Nothing
+        discriminator, parser_lookup = list(possible_keys.items())[0]
+        return cg_maybe.Just(cls(discriminator, parser_lookup))
+
+    def describe(self) -> str:
+        if self._use_readable_describe:
+            import textwrap  # pylint: disable=import-outside-toplevel
+
+            def indent(part: str) -> str:
+                return textwrap.indent(part, '    ')
+
+            maybe_newline = '\n'
+        else:
+
+            def indent(part: str) -> str:
+                return part
+
+            maybe_newline = ''
+
+        return 'Union[{maybe_newline}{parts},{maybe_newline}]'.format(
+            maybe_newline=maybe_newline,
+            parts=f',{maybe_newline}'.join(
+                indent(part.describe())
+                for part in self.__parser_lookup.values()
+            )
+        )
+
+    def _to_open_api(self, schema: OpenAPISchema) -> t.Mapping[str, t.Any]:
+        mapping = {}
+        for name, parser in self.__parser_lookup.items():
+            sub = parser.to_open_api(schema)
+            if '$ref' not in sub:
+                assert 'x-model-name' in sub
+                sub = schema.add_as_schema(sub['x-model-name'], sub, parser)
+            mapping[name] = sub['$ref']
+        return {
+            'oneOf': [{'$ref': sub} for sub in mapping.values()],
+            'discriminator': {
+                'propertyName': self.__discriminator,
+                'mapping': mapping,
+            },
+        }
+
+    def try_parse(self, value: object) -> _T:
+        if not isinstance(value, dict):
+            raise SimpleParseError(self, value)
+        if self.__discriminator not in value:
+            raise SimpleParseError(self, value)
+        disc_value = self.__key_parser.try_parse(value[self.__discriminator])
+        return self.__parser_lookup[disc_value].try_parse(value)
