@@ -88,26 +88,46 @@ def literal_boolean_callback(ctx: FunctionContext) -> Type:
         return ctx.default_return_type
 
     arg, = ctx.arg_types[0]
-    assert isinstance(arg, Instance)
-    if not isinstance(arg.last_known_value, LiteralType):
-        ctx.api.fail(
-            'The argument to "LiteralBoolean" should be a literal',
-            ctx.context,
-        )
-        return ctx.default_return_type
-    literal = arg.last_known_value
+    if isinstance(arg, LiteralType):
+        literal = arg
+    else:
+        if not (
+            isinstance(arg, Instance) and
+            isinstance(arg.last_known_value, LiteralType)
+        ):
+            ctx.api.fail(
+                'The argument to "LiteralBoolean" should be a literal',
+                ctx.context,
+            )
+            return ctx.default_return_type
+        literal = arg.last_known_value
 
     assert isinstance(ctx.default_return_type, Instance)
     return ctx.default_return_type.copy_modified(args=[UnionType([literal])])
 
 
+def _get_literal_type(arg: Type) -> t.Optional[LiteralType]:
+    if not isinstance(arg, Instance):
+        return None
+    if not isinstance(arg.last_known_value, LiteralType):
+        return None
+    return arg.last_known_value
+
+
+def _get_literal_value(arg: Type) -> t.Optional[str]:
+    typ = _get_literal_type(arg)
+    if typ is None or not isinstance(typ.value, str):  # pragma: no cover
+        return None
+    return typ.value
+
+
 def string_enum_callback(ctx: FunctionContext) -> Type:
     """Callback to infer the correct type for ``StringEnum`` parsers.
     """
     literals = []
     for idx, arg in enumerate(ctx.arg_types[0]):
-        assert isinstance(arg, Instance)
-        if not isinstance(arg.last_known_value, LiteralType):
+        new_literal = _get_literal_type(arg)
+        if new_literal is None:
             ctx.api.fail(
                 (
                     'The arguments to "StringEnum" should all be literals'
@@ -116,12 +136,67 @@ def string_enum_callback(ctx: FunctionContext) -> Type:
                 ctx.context,
             )
             return ctx.default_return_type
-        literals.append(arg.last_known_value)
+        literals.append(new_literal)
 
     assert isinstance(ctx.default_return_type, Instance)
     return ctx.default_return_type.copy_modified(args=[UnionType(literals)])
 
 
+def make_union_callback(ctx: MethodContext) -> Type:
+    """Callback for the ``combine`` method on ``FixedMapping``.
+    """
+    (discriminator, ), parsers = ctx.arg_types
+    discriminator_lit = _get_literal_value(discriminator)
+    if discriminator_lit is None:
+        ctx.api.fail(
+            (
+                'The discriminator argument to "make_discriminated_union"'
+                ' should be a literal.'
+            ),
+            ctx.context,
+        )
+        return ctx.default_return_type
+
+    union_items = []
+    seen_values = set()
+    for parser in parsers:
+        assert isinstance(parser, Instance)
+        parser_typeddict, = parser.args
+        assert isinstance(parser_typeddict, TypedDictType)
+
+        discriminator_type = parser_typeddict.items.get(discriminator_lit)
+        if discriminator_type is None:
+            ctx.api.fail((
+                'Cannot make discriminated union, {!r} does not have key {!r}.'
+            ).format(parser_typeddict, discriminator_lit), ctx.context)
+            return ctx.default_return_type
+
+        if not isinstance(discriminator_type, LiteralType):
+            ctx.api.fail((
+                'Cannot make discriminated union, {!r} is not a string literal'
+            ).format(discriminator_type), ctx.context)
+            return ctx.default_return_type
+
+        discriminator_value = str(discriminator_type.value)
+        if discriminator_value in seen_values:
+            ctx.api.fail((
+                'Cannot make discriminated union, {!r} is a duplicate option.'
+            ).format(discriminator_value), ctx.context)
+            return ctx.default_return_type
+
+        seen_values.add(discriminator_value)
+
+        union_items.append(
+            ctx.api.named_generic_type(
+                'cg_request_args._DictGetter', [parser_typeddict]
+            )
+        )
+
+    union = UnionType(items=union_items)
+    assert isinstance(ctx.default_return_type, Instance)
+    return ctx.default_return_type.copy_modified(args=[union])
+
+
 def combine_callback(ctx: MethodContext) -> Type:
     """Callback for the ``combine`` method on ``FixedMapping``.
     """
@@ -326,6 +401,8 @@ class CgRequestArgPlugin(Plugin):
             return add_tag_callback
         if fullname == f'{MAPPING_MOD}.FixedMapping.combine':
             return combine_callback
+        if fullname == f'{MAPPING_MOD}.FixedMapping.make_discriminated_union':
+            return make_union_callback
         if fullname == f'{MAPPING_MOD}.BaseFixedMapping.from_typeddict':
             return from_typeddict_callback
         return None
