@@ -2,25 +2,22 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
-from typing import TYPE_CHECKING, Any, Generic, Mapping, TypeVar, Union
+import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 
-from ..utils import get_error, log_warnings, response_code_matches, to_dict
-
-if TYPE_CHECKING:
-    from typing import Sequence
+from .. import parsers, utils
 
+if t.TYPE_CHECKING:
     from ..client import AuthenticatedClient, _BaseClient
-    from ..models.base_error import BaseError
+    from ..models.any_error import AnyError
     from ..models.comment_reply_edit import CommentReplyEdit
-    from ..parsers import JsonResponseParser, ParserFor
 
-_ClientT = TypeVar("_ClientT", bound="_BaseClient")
+_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
 
 
-class CommentService(Generic[_ClientT]):
+class CommentService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
     def __init__(self, client: "_BaseClient") -> None:
@@ -31,8 +28,10 @@ class CommentService(Generic[_ClientT]):
         *,
         comment_base_id: "int",
         reply_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Sequence[CommentReplyEdit]":
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Sequence[CommentReplyEdit]":
         """Get the edits of a reply.
 
         :param comment_base_id: The base of the given reply.
@@ -43,11 +42,6 @@ class CommentService(Generic[_ClientT]):
 
         :returns: A list of edits, sorted from newest to oldest.
         """
-        from typing import Sequence
-
-        from ..models.base_error import BaseError
-        from ..models.comment_reply_edit import CommentReplyEdit
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = (
             "/api/v1/comments/{commentBaseId}/replies/{replyId}/edits/".format(
@@ -57,13 +51,26 @@ class CommentService(Generic[_ClientT]):
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                rqa.List(ParserFor.make(CommentReplyEdit))
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.comment_reply_edit import CommentReplyEdit
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                rqa.List(parsers.ParserFor.make(CommentReplyEdit))
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
