@@ -2,27 +2,22 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
-from typing import TYPE_CHECKING, Any, Generic, Mapping, TypeVar, Union
+import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
+from cg_maybe.utils import maybe_from_nullable
 
-from ..utils import get_error, log_warnings, response_code_matches, to_dict
-
-if TYPE_CHECKING:
-    from typing import Any, Dict, cast
-
-    from cg_maybe import Maybe, Nothing
-    from cg_maybe.utils import maybe_from_nullable
+from .. import parsers, utils
 
+if t.TYPE_CHECKING:
     from ..client import AuthenticatedClient, _BaseClient
-    from ..models.base_error import BaseError
-    from ..parsers import JsonResponseParser, ParserFor, ResponsePropertyParser
+    from ..models.any_error import AnyError
 
-_ClientT = TypeVar("_ClientT", bound="_BaseClient")
+_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
 
 
-class FileService(Generic[_ClientT]):
+class FileService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
     def __init__(self, client: "_BaseClient") -> None:
@@ -35,7 +30,9 @@ class FileService(Generic[_ClientT]):
         mime: Maybe["str"] = Nothing,
         as_attachment: "bool" = False,
         name: Maybe["str"] = Nothing,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "bytes":
         """Serve some specific file in the uploads folder.
 
@@ -52,36 +49,38 @@ class FileService(Generic[_ClientT]):
 
         :returns: The requested file.
         """
-        from typing import Any, Dict, cast
-
-        from cg_maybe import Maybe, Nothing
-        from cg_maybe.utils import maybe_from_nullable
-
-        from ..models.base_error import BaseError
-        from ..parsers import (
-            JsonResponseParser,
-            ParserFor,
-            ResponsePropertyParser,
-        )
 
         url = "/api/v1/files/{filename}".format(filename=filename)
-        params: "Dict[str, Any]" = {
+        params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
-            "as_attachment": to_dict(as_attachment),
+            "as_attachment": utils.to_dict(as_attachment),
         }
-        maybe_from_nullable(cast(Any, mime)).if_just(
+        maybe_from_nullable(t.cast(t.Any, mime)).if_just(
             lambda val: params.__setitem__("mime", val)
         )
-        maybe_from_nullable(cast(Any, name)).if_just(
+        maybe_from_nullable(t.cast(t.Any, name)).if_just(
             lambda val: params.__setitem__("name", val)
         )
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return ResponsePropertyParser("content", bytes).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            # fmt: on
+            return parsers.ResponsePropertyParser("content", bytes).try_parse(
+                resp
+            )
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
