@@ -2,24 +2,23 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
-from typing import TYPE_CHECKING, Any, Generic, Mapping, TypeVar, Union
+import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 
-from ..utils import get_error, log_warnings, response_code_matches, to_dict
+from .. import parsers, utils
 
-if TYPE_CHECKING:
+if t.TYPE_CHECKING:
     from ..client import AuthenticatedClient, _BaseClient
-    from ..models.base_error import BaseError
+    from ..models.any_error import AnyError
     from ..models.extended_group import ExtendedGroup
     from ..models.user_input import UserInput
-    from ..parsers import JsonResponseParser, ParserFor
 
-_ClientT = TypeVar("_ClientT", bound="_BaseClient")
+_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
 
 
-class GroupService(Generic[_ClientT]):
+class GroupService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
     def __init__(self, client: "_BaseClient") -> None:
@@ -27,10 +26,12 @@ class GroupService(Generic[_ClientT]):
 
     def add_member(
         self: "GroupService[AuthenticatedClient]",
-        json_body: Union[dict, list, "UserInput"],
+        json_body: t.Union[dict, list, "UserInput"],
         *,
         group_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "ExtendedGroup":
         """Add a user (member) to a group.
 
@@ -43,33 +44,44 @@ class GroupService(Generic[_ClientT]):
 
         :returns: The group with the newly added user.
         """
-        from ..models.base_error import BaseError
-        from ..models.extended_group import ExtendedGroup
-        from ..models.user_input import UserInput
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/groups/{groupId}/member".format(groupId=group_id)
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.post(
-                url=url, json=to_dict(json_body), params=params
+            resp = client.http.post(
+                url=url, json=utils.to_dict(json_body), params=params
             )
-        log_warnings(response)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(ParserFor.make(ExtendedGroup)).try_parse(
-                response
-            )
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.extended_group import ExtendedGroup
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(ExtendedGroup)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def get(
         self: "GroupService[AuthenticatedClient]",
         *,
         group_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "ExtendedGroup":
         """Get a group by id.
 
@@ -79,21 +91,31 @@ class GroupService(Generic[_ClientT]):
 
         :returns: The requested group.
         """
-        from ..models.base_error import BaseError
-        from ..models.extended_group import ExtendedGroup
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/groups/{groupId}".format(groupId=group_id)
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(ParserFor.make(ExtendedGroup)).try_parse(
-                response
-            )
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.extended_group import ExtendedGroup
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(ExtendedGroup)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
