@@ -2,26 +2,25 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
-from typing import TYPE_CHECKING, Any, Generic, Mapping, TypeVar, Union
+import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 
-from ..utils import get_error, log_warnings, response_code_matches, to_dict
+from .. import parsers, utils
 
-if TYPE_CHECKING:
+if t.TYPE_CHECKING:
     from ..client import AuthenticatedClient, _BaseClient
+    from ..models.any_error import AnyError
     from ..models.assignment_login_link import AssignmentLoginLink
-    from ..models.base_error import BaseError
     from ..models.result_data_post_login_link_login import (
         ResultDataPostLoginLinkLogin,
     )
-    from ..parsers import JsonResponseParser, ParserFor
 
-_ClientT = TypeVar("_ClientT", bound="_BaseClient")
+_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
 
 
-class LoginLinkService(Generic[_ClientT]):
+class LoginLinkService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
     def __init__(self, client: "_BaseClient") -> None:
@@ -31,7 +30,9 @@ class LoginLinkService(Generic[_ClientT]):
         self,
         *,
         login_link_id: "str",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "AssignmentLoginLink":
         """Get a login link and the connected assignment.
 
@@ -42,9 +43,6 @@ class LoginLinkService(Generic[_ClientT]):
         :returns: The requested login link, which will also contain information
                   about the connected assignment.
         """
-        from ..models.assignment_login_link import AssignmentLoginLink
-        from ..models.base_error import BaseError
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/login_links/{loginLinkId}".format(
             loginLinkId=login_link_id
@@ -52,22 +50,37 @@ class LoginLinkService(Generic[_ClientT]):
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                ParserFor.make(AssignmentLoginLink)
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.assignment_login_link import AssignmentLoginLink
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(AssignmentLoginLink)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def login(
         self,
         *,
         login_link_id: "str",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "ResultDataPostLoginLinkLogin":
         """Login with the given login link.
 
@@ -86,11 +99,6 @@ class LoginLinkService(Generic[_ClientT]):
 
         :returns: The logged in user and an access token.
         """
-        from ..models.base_error import BaseError
-        from ..models.result_data_post_login_link_login import (
-            ResultDataPostLoginLinkLogin,
-        )
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/login_links/{loginLinkId}/login".format(
             loginLinkId=login_link_id
@@ -98,13 +106,28 @@ class LoginLinkService(Generic[_ClientT]):
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.post(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.post(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                ParserFor.make(ResultDataPostLoginLinkLogin)
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.result_data_post_login_link_login import (
+                ResultDataPostLoginLinkLogin,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(ResultDataPostLoginLinkLogin)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
