@@ -2,28 +2,25 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
-from typing import TYPE_CHECKING, Any, Generic, Mapping, TypeVar, Union
+import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 
-from ..utils import get_error, log_warnings, response_code_matches, to_dict
-
-if TYPE_CHECKING:
-    from typing import Dict
+from .. import parsers, utils
 
+if t.TYPE_CHECKING:
     from ..client import AuthenticatedClient, _BaseClient
-    from ..models.base_error import BaseError
+    from ..models.any_error import AnyError
     from ..models.job import Job
     from ..models.result_data_get_task_result_get_all import (
         ResultDataGetTaskResultGetAll,
     )
-    from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
 
-_ClientT = TypeVar("_ClientT", bound="_BaseClient")
+_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
 
 
-class TaskResultService(Generic[_ClientT]):
+class TaskResultService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
     def __init__(self, client: "_BaseClient") -> None:
@@ -34,7 +31,9 @@ class TaskResultService(Generic[_ClientT]):
         *,
         offset: "int" = 0,
         limit: "int" = 50,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "ResultDataGetTaskResultGetAll":
         """Get all active tasks, all tasks that have not yet been started, a
         page of finished tasks, and the total number of finished tasks.
@@ -47,38 +46,48 @@ class TaskResultService(Generic[_ClientT]):
         :returns: The requested tasks, with the given limits applied to the
                   finished jobs.
         """
-        from typing import Dict
-
-        from ..models.base_error import BaseError
-        from ..models.result_data_get_task_result_get_all import (
-            ResultDataGetTaskResultGetAll,
-        )
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/tasks/"
-        params: "Dict[str, Any]" = {
+        params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
-            "offset": to_dict(offset),
-            "limit": to_dict(limit),
+            "offset": utils.to_dict(offset),
+            "limit": utils.to_dict(limit),
         }
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                ParserFor.make(ResultDataGetTaskResultGetAll)
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.result_data_get_task_result_get_all import (
+                ResultDataGetTaskResultGetAll,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(ResultDataGetTaskResultGetAll)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def get(
         self: "TaskResultService[AuthenticatedClient]",
         *,
         task_result_id: "str",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "Job":
         """Get the state of a task result.
 
@@ -93,9 +102,6 @@ class TaskResultService(Generic[_ClientT]):
 
         :returns: The retrieved task result.
         """
-        from ..models.base_error import BaseError
-        from ..models.job import Job
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/task_results/{taskResultId}".format(
             taskResultId=task_result_id
@@ -103,20 +109,37 @@ class TaskResultService(Generic[_ClientT]):
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(ParserFor.make(Job)).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.job import Job
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(Job)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def restart(
         self: "TaskResultService[AuthenticatedClient]",
         *,
         task_result_id: "str",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "None":
         """Restart a task result.
 
@@ -129,8 +152,6 @@ class TaskResultService(Generic[_ClientT]):
 
         :returns: Nothing.
         """
-        from ..models.base_error import BaseError
-        from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
 
         url = "/api/v1/tasks/{taskResultId}/restart".format(
             taskResultId=task_result_id
@@ -138,20 +159,33 @@ class TaskResultService(Generic[_ClientT]):
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.post(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.post(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 204):
-            return ConstantlyParser(None).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def revoke(
         self: "TaskResultService[AuthenticatedClient]",
         *,
         task_result_id: "str",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "None":
         """Revoke a task result.
 
@@ -163,8 +197,6 @@ class TaskResultService(Generic[_ClientT]):
 
         :returns: Nothing.
         """
-        from ..models.base_error import BaseError
-        from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
 
         url = "/api/v1/tasks/{taskResultId}/revoke".format(
             taskResultId=task_result_id
@@ -172,11 +204,22 @@ class TaskResultService(Generic[_ClientT]):
         params = extra_parameters or {}
 
         with self.__client as client:
-            response = client.http.post(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.post(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 204):
-            return ConstantlyParser(None).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
