@@ -2,21 +2,17 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
-from typing import TYPE_CHECKING, Any, Generic, Mapping, TypeVar, Union
+import typing as t
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
+from cg_maybe.utils import maybe_from_nullable
 
-from ..utils import get_error, log_warnings, response_code_matches, to_dict
-
-if TYPE_CHECKING:
-    from typing import Any, Dict, Optional, cast
-
-    from cg_maybe import Maybe, Nothing
-    from cg_maybe.utils import maybe_from_nullable
+from .. import parsers, utils
 
+if t.TYPE_CHECKING:
     from ..client import AuthenticatedClient, _BaseClient
-    from ..models.base_error import BaseError
+    from ..models.any_error import AnyError
     from ..models.notification_setting import NotificationSetting
     from ..models.patch_notification_setting_user_setting_data import (
         PatchNotificationSettingUserSettingData,
@@ -27,12 +23,11 @@ if TYPE_CHECKING:
     from ..models.result_data_get_user_setting_get_all_ui_preferences import (
         ResultDataGetUserSettingGetAllUiPreferences,
     )
-    from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
 
-_ClientT = TypeVar("_ClientT", bound="_BaseClient")
+_ClientT = t.TypeVar("_ClientT", bound="_BaseClient")
 
 
-class UserSettingService(Generic[_ClientT]):
+class UserSettingService(t.Generic[_ClientT]):
     __slots__ = ("__client",)
 
     def __init__(self, client: "_BaseClient") -> None:
@@ -42,7 +37,9 @@ class UserSettingService(Generic[_ClientT]):
         self,
         *,
         token: Maybe["str"] = Nothing,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "NotificationSetting":
         """Update preferences for notifications.
 
@@ -54,43 +51,50 @@ class UserSettingService(Generic[_ClientT]):
 
         :returns: The preferences for the user as described by the `token`.
         """
-        from typing import Any, Dict, cast
-
-        from cg_maybe import Maybe, Nothing
-        from cg_maybe.utils import maybe_from_nullable
-
-        from ..models.base_error import BaseError
-        from ..models.notification_setting import NotificationSetting
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/settings/notification_settings/"
-        params: "Dict[str, Any]" = {
+        params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
         }
-        maybe_from_nullable(cast(Any, token)).if_just(
+        maybe_from_nullable(t.cast(t.Any, token)).if_just(
             lambda val: params.__setitem__("token", val)
         )
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                ParserFor.make(NotificationSetting)
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.notification_setting import NotificationSetting
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(NotificationSetting)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def patch_notification_setting(
         self,
-        json_body: Union[
+        json_body: t.Union[
             dict, list, "PatchNotificationSettingUserSettingData"
         ],
         *,
         token: Maybe["str"] = Nothing,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "None":
         """Update preferences for notifications.
 
@@ -107,35 +111,36 @@ class UserSettingService(Generic[_ClientT]):
 
         :returns: Nothing.
         """
-        from typing import Any, Dict, cast
-
-        from cg_maybe import Maybe, Nothing
-        from cg_maybe.utils import maybe_from_nullable
-
-        from ..models.base_error import BaseError
-        from ..models.patch_notification_setting_user_setting_data import (
-            PatchNotificationSettingUserSettingData,
-        )
-        from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
 
         url = "/api/v1/settings/notification_settings/"
-        params: "Dict[str, Any]" = {
+        params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
         }
-        maybe_from_nullable(cast(Any, token)).if_just(
+        maybe_from_nullable(t.cast(t.Any, token)).if_just(
             lambda val: params.__setitem__("token", val)
         )
 
         with self.__client as client:
-            response = client.http.patch(
-                url=url, json=to_dict(json_body), params=params
+            resp = client.http.patch(
+                url=url, json=utils.to_dict(json_body), params=params
             )
-        log_warnings(response)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 204):
-            return ConstantlyParser(None).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def get_ui_preference(
@@ -143,8 +148,10 @@ class UserSettingService(Generic[_ClientT]):
         *,
         name: "str",
         token: Maybe["str"] = Nothing,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Optional[bool]":
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "t.Optional[bool]":
         """Get a single UI preferences.
 
         :param name: The preference name you want to get.
@@ -156,39 +163,45 @@ class UserSettingService(Generic[_ClientT]):
 
         :returns: The preferences for the user as described by the `token`.
         """
-        from typing import Any, Dict, Optional, cast
-
-        from cg_maybe import Maybe, Nothing
-        from cg_maybe.utils import maybe_from_nullable
-
-        from ..models.base_error import BaseError
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/settings/ui_preferences/{name}".format(name=name)
-        params: "Dict[str, Any]" = {
+        params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
         }
-        maybe_from_nullable(cast(Any, token)).if_just(
+        maybe_from_nullable(t.cast(t.Any, token)).if_just(
             lambda val: params.__setitem__("token", val)
         )
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            # fmt: on
+            return parsers.JsonResponseParser(
                 rqa.Nullable(rqa.SimpleValue.bool)
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def get_all_ui_preferences(
         self,
         *,
         token: Maybe["str"] = Nothing,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "ResultDataGetUserSettingGetAllUiPreferences":
         """Get ui preferences.
 
@@ -200,43 +213,52 @@ class UserSettingService(Generic[_ClientT]):
 
         :returns: The preferences for the user as described by the `token`.
         """
-        from typing import Any, Dict, cast
-
-        from cg_maybe import Maybe, Nothing
-        from cg_maybe.utils import maybe_from_nullable
-
-        from ..models.base_error import BaseError
-        from ..models.result_data_get_user_setting_get_all_ui_preferences import (
-            ResultDataGetUserSettingGetAllUiPreferences,
-        )
-        from ..parsers import JsonResponseParser, ParserFor
 
         url = "/api/v1/settings/ui_preferences/"
-        params: "Dict[str, Any]" = {
+        params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
         }
-        maybe_from_nullable(cast(Any, token)).if_just(
+        maybe_from_nullable(t.cast(t.Any, token)).if_just(
             lambda val: params.__setitem__("token", val)
         )
 
         with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
+            resp = client.http.get(url=url, params=params)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                ParserFor.make(ResultDataGetUserSettingGetAllUiPreferences)
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.result_data_get_user_setting_get_all_ui_preferences import (
+                ResultDataGetUserSettingGetAllUiPreferences,
+            )
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(
+                    ResultDataGetUserSettingGetAllUiPreferences
+                )
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
 
     def patch_ui_preference(
         self,
-        json_body: Union[dict, list, "PatchUiPreferenceUserSettingData"],
+        json_body: t.Union[dict, list, "PatchUiPreferenceUserSettingData"],
         *,
         token: Maybe["str"] = Nothing,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
     ) -> "None":
         """Update ui preferences.
 
@@ -252,33 +274,34 @@ class UserSettingService(Generic[_ClientT]):
 
         :returns: Nothing.
         """
-        from typing import Any, Dict, cast
-
-        from cg_maybe import Maybe, Nothing
-        from cg_maybe.utils import maybe_from_nullable
-
-        from ..models.base_error import BaseError
-        from ..models.patch_ui_preference_user_setting_data import (
-            PatchUiPreferenceUserSettingData,
-        )
-        from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
 
         url = "/api/v1/settings/ui_preferences/"
-        params: "Dict[str, Any]" = {
+        params: t.Dict[str, t.Any] = {
             **(extra_parameters or {}),
         }
-        maybe_from_nullable(cast(Any, token)).if_just(
+        maybe_from_nullable(t.cast(t.Any, token)).if_just(
             lambda val: params.__setitem__("token", val)
         )
 
         with self.__client as client:
-            response = client.http.patch(
-                url=url, json=to_dict(json_body), params=params
+            resp = client.http.patch(
+                url=url, json=utils.to_dict(json_body), params=params
             )
-        log_warnings(response)
+        utils.log_warnings(resp)
 
-        if response_code_matches(response.status_code, 204):
-            return ConstantlyParser(None).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
         )
