@@ -26,10 +26,22 @@ if t.TYPE_CHECKING:
     from codegrade._api.auto_test import AutoTestService as _AutoTestService
     from codegrade._api.comment import CommentService as _CommentService
     from codegrade._api.course import CourseService as _CourseService
+    from codegrade._api.course_price import (
+        CoursePriceService as _CoursePriceService,
+    )
     from codegrade._api.file import FileService as _FileService
+    from codegrade._api.git_provider import (
+        GitProviderService as _GitProviderService,
+    )
     from codegrade._api.group import GroupService as _GroupService
     from codegrade._api.login_link import LoginLinkService as _LoginLinkService
     from codegrade._api.lti import LTIService as _LTIService
+    from codegrade._api.oauth_provider import (
+        OAuthProviderService as _OAuthProviderService,
+    )
+    from codegrade._api.permission import (
+        PermissionService as _PermissionService,
+    )
     from codegrade._api.site_settings import (
         SiteSettingsService as _SiteSettingsService,
     )
@@ -41,6 +53,9 @@ if t.TYPE_CHECKING:
         TaskResultService as _TaskResultService,
     )
     from codegrade._api.tenant import TenantService as _TenantService
+    from codegrade._api.transaction import (
+        TransactionService as _TransactionService,
+    )
     from codegrade._api.user import UserService as _UserService
     from codegrade._api.user_setting import (
         UserSettingService as _UserSettingService,
@@ -56,10 +71,13 @@ class _BaseClient:
         "__course",
         "__group",
         "__user",
+        "__git_provider",
         "__auto_test",
         "__lti",
         "__tenant",
         "__submission",
+        "__oauth_provider",
+        "__permission",
         "__file",
         "__login_link",
         "__user_setting",
@@ -67,12 +85,17 @@ class _BaseClient:
         "__site_settings",
         "__snippet",
         "__task_result",
+        "__transaction",
+        "__course_price",
         "__open_level",
+        "__http",
+        "base_url",
     )
 
-    def __init__(self: "_BaseClientT") -> None:
+    def __init__(self: "_BaseClientT", base_url: str) -> None:
         # Open level makes it possible to efficiently nest the context manager.
         self.__open_level = 0
+        self.base_url = base_url
 
         self.__about: t.Optional["_AboutService[_BaseClientT]"] = None
         self.__assignment: t.Optional[
@@ -81,12 +104,21 @@ class _BaseClient:
         self.__course: t.Optional["_CourseService[_BaseClientT]"] = None
         self.__group: t.Optional["_GroupService[_BaseClientT]"] = None
         self.__user: t.Optional["_UserService[_BaseClientT]"] = None
+        self.__git_provider: t.Optional[
+            "_GitProviderService[_BaseClientT]"
+        ] = None
         self.__auto_test: t.Optional["_AutoTestService[_BaseClientT]"] = None
         self.__lti: t.Optional["_LTIService[_BaseClientT]"] = None
         self.__tenant: t.Optional["_TenantService[_BaseClientT]"] = None
         self.__submission: t.Optional[
             "_SubmissionService[_BaseClientT]"
         ] = None
+        self.__oauth_provider: t.Optional[
+            "_OAuthProviderService[_BaseClientT]"
+        ] = None
+        self.__permission: t.Optional[
+            "_PermissionService[_BaseClientT]"
+        ] = None
         self.__file: t.Optional["_FileService[_BaseClientT]"] = None
         self.__login_link: t.Optional["_LoginLinkService[_BaseClientT]"] = None
         self.__user_setting: t.Optional[
@@ -100,16 +132,28 @@ class _BaseClient:
         self.__task_result: t.Optional[
             "_TaskResultService[_BaseClientT]"
         ] = None
+        self.__transaction: t.Optional[
+            "_TransactionService[_BaseClientT]"
+        ] = None
+        self.__course_price: t.Optional[
+            "_CoursePriceService[_BaseClientT]"
+        ] = None
+        self.__http: t.Optional[httpx.Client] = None
 
     def _get_headers(self) -> t.Mapping[str, str]:
         """Get headers to be used in all endpoints"""
         return {}
 
-    @property
     @abc.abstractmethod
-    def http(self) -> httpx.Client:
+    def _make_http(self) -> httpx.Client:
         raise NotImplementedError
 
+    @property
+    def http(self) -> httpx.Client:
+        if self.__http is None:
+            self.__http = self._make_http()
+        return self.__http
+
     def __enter__(self: _BaseClientT) -> _BaseClientT:
         if self.__open_level == 0:
             self.http.__enter__()
@@ -125,6 +169,7 @@ class _BaseClient:
         self.__open_level -= 1
         if self.__open_level == 0:
             self.http.__exit__(exc_type, exc_value, traceback)
+            self.__http = None
 
     @property
     def about(self: _BaseClientT) -> "_AboutService[_BaseClientT]":
@@ -166,6 +211,16 @@ class _BaseClient:
             self.__user = m.UserService(self)
         return self.__user
 
+    @property
+    def git_provider(
+        self: _BaseClientT,
+    ) -> "_GitProviderService[_BaseClientT]":
+        if self.__git_provider is None:
+            import codegrade._api.git_provider as m
+
+            self.__git_provider = m.GitProviderService(self)
+        return self.__git_provider
+
     @property
     def auto_test(self: _BaseClientT) -> "_AutoTestService[_BaseClientT]":
         if self.__auto_test is None:
@@ -198,6 +253,24 @@ class _BaseClient:
             self.__submission = m.SubmissionService(self)
         return self.__submission
 
+    @property
+    def oauth_provider(
+        self: _BaseClientT,
+    ) -> "_OAuthProviderService[_BaseClientT]":
+        if self.__oauth_provider is None:
+            import codegrade._api.oauth_provider as m
+
+            self.__oauth_provider = m.OAuthProviderService(self)
+        return self.__oauth_provider
+
+    @property
+    def permission(self: _BaseClientT) -> "_PermissionService[_BaseClientT]":
+        if self.__permission is None:
+            import codegrade._api.permission as m
+
+            self.__permission = m.PermissionService(self)
+        return self.__permission
+
     @property
     def file(self: _BaseClientT) -> "_FileService[_BaseClientT]":
         if self.__file is None:
@@ -258,41 +331,49 @@ class _BaseClient:
             self.__task_result = m.TaskResultService(self)
         return self.__task_result
 
+    @property
+    def transaction(self: _BaseClientT) -> "_TransactionService[_BaseClientT]":
+        if self.__transaction is None:
+            import codegrade._api.transaction as m
+
+            self.__transaction = m.TransactionService(self)
+        return self.__transaction
+
+    @property
+    def course_price(
+        self: _BaseClientT,
+    ) -> "_CoursePriceService[_BaseClientT]":
+        if self.__course_price is None:
+            import codegrade._api.course_price as m
+
+            self.__course_price = m.CoursePriceService(self)
+        return self.__course_price
+
 
 class Client(_BaseClient):
     """A class used to do unauthenticated requests to CodeGrade"""
 
-    __slots__ = ("_http",)
+    __slots__ = ()
 
-    def __init__(self, base_url: str) -> None:
-        super().__init__()
-        self._http = httpx.Client(base_url=base_url)
-
-    @property
-    def http(self) -> httpx.Client:
-        return self._http
+    def _make_http(self) -> httpx.Client:
+        return httpx.Client(base_url=self.base_url)
 
 
 class AuthenticatedClient(_BaseClient):
     """A Client which has been authenticated for use on secured endpoints"""
 
-    __slots__ = (
-        "_http",
-        "token",
-    )
+    __slots__ = ("token",)
 
     def __init__(self, base_url: str, token: str):
-        super().__init__()
+        super().__init__(base_url)
         self.token = token
-        self._http = httpx.Client(
-            base_url=base_url,
+
+    def _make_http(self) -> httpx.Client:
+        return httpx.Client(
+            base_url=self.base_url,
             headers={"Authorization": f"Bearer {self.token}"},
         )
 
-    @property
-    def http(self) -> httpx.Client:
-        return self._http
-
     @staticmethod
     def _prepare_host(host: str) -> str:
         if not host.startswith("http"):
