@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -23,9 +23,9 @@ class _SubmissionRubricItemDataParser:
     #: type 'continuous'.
     multiplier: "float" = 1.0
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "row_id",
@@ -50,16 +50,17 @@ class _SubmissionRubricItemDataParser:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["row_id"] = to_dict(self.row_id)
-        res["item_id"] = to_dict(self.item_id)
-        res["multiplier"] = to_dict(self.multiplier)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "row_id": to_dict(self.row_id),
+            "item_id": to_dict(self.item_id),
+            "multiplier": to_dict(self.multiplier),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["_SubmissionRubricItemDataParser"], d: Dict[str, Any]
+        cls: t.Type["_SubmissionRubricItemDataParser"], d: t.Dict[str, t.Any]
     ) -> "_SubmissionRubricItemDataParser":
         parsed = cls.data_parser.try_parse(d)
 
