@@ -2,14 +2,14 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .base_about import BaseAbout
 from .health_information import HealthInformation
@@ -23,14 +23,14 @@ class About(BaseAbout):
     #: health key is provided.
     health: Maybe["HealthInformation"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseAbout.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.OptionalArgument(
                     "health",
-                    ParserFor.make(HealthInformation),
+                    parsers.ParserFor.make(HealthInformation),
                     doc=(
                         "Health information, will only be present when the"
                         " correct (secret) health key is provided."
@@ -44,20 +44,21 @@ class About(BaseAbout):
         getattr(super(), "__post_init__", lambda: None)()
         self.health = maybe_from_nullable(self.health)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["version"] = to_dict(self.version)
-        res["commit"] = to_dict(self.commit)
-        res["features"] = to_dict(self.features)
-        res["settings"] = to_dict(self.settings)
-        res["release"] = to_dict(self.release)
-        res["current_time"] = to_dict(self.current_time)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "version": to_dict(self.version),
+            "commit": to_dict(self.commit),
+            "features": to_dict(self.features),
+            "settings": to_dict(self.settings),
+            "release": to_dict(self.release),
+            "current_time": to_dict(self.current_time),
+        }
         if self.health.is_just:
             res["health"] = to_dict(self.health.value)
         return res
 
     @classmethod
-    def from_dict(cls: Type["About"], d: Dict[str, Any]) -> "About":
+    def from_dict(cls: t.Type["About"], d: t.Dict[str, t.Any]) -> "About":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
