@@ -2,8 +2,9 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -17,7 +18,7 @@ class AllSiteSettings(FrontendSiteSettings):
 
     #: The amount of time there can be between two heartbeats of a runner.
     #: Changing this to a lower value might cause some runners to crash.
-    auto_test_heartbeat_interval: "float"
+    auto_test_heartbeat_interval: "datetime.timedelta"
     #: The max amount of heartbeats that we may miss from a runner before we
     #: kill it and start a new one.
     auto_test_heartbeat_max_missed: "int"
@@ -32,7 +33,9 @@ class AllSiteSettings(FrontendSiteSettings):
     auto_test_max_concurrent_batch_runs: "int"
     #: The maximum amount of time a result can be in the "not started" state
     #: before we raise an alarm on the about health page.
-    auto_test_max_result_not_started: "float"
+    auto_test_max_result_not_started: "datetime.timedelta"
+    #: The maximum size of metadata stored on a unit test step.
+    auto_test_max_unit_test_metadata_length: "int"
     #: The minimum strength passwords by users should have. The higher this
     #: value the stronger the password should be. When increasing the strength
     #: all users with too weak passwords will be shown a warning on the next
@@ -41,10 +44,10 @@ class AllSiteSettings(FrontendSiteSettings):
     #: The amount of time a reset token is valid. You should not increase this
     #: value too much as users might be not be too careful with these tokens.
     #: Increasing this value will allow **all** existing tokens to live longer.
-    reset_token_time: "float"
+    reset_token_time: "datetime.timedelta"
     #: The amount of time the link send in notification emails to change the
     #: notification preferences works to actually change the notifications.
-    setting_token_time: "float"
+    setting_token_time: "datetime.timedelta"
     #: The maximum amount of files and directories allowed in a single archive.
     max_number_of_files: "int"
     #: The maximum size of uploaded files that are mostly uploaded by "trusted"
@@ -61,16 +64,19 @@ class AllSiteSettings(FrontendSiteSettings):
     max_file_size: "int"
     #: The time a login session is valid. After this amount of time a user will
     #: always need to re-authenticate.
-    jwt_access_token_expires: "float"
+    jwt_access_token_expires: "datetime.timedelta"
+    #: The time a user has to download a file from the mirror storage, after
+    #: this time the file will be deleted.
+    max_mirror_file_age: "datetime.timedelta"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: FrontendSiteSettings.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "AUTO_TEST_HEARTBEAT_INTERVAL",
-                    rqa.SimpleValue.float,
+                    rqa.RichValue.TimeDelta,
                     doc=(
                         "The amount of time there can be between two"
                         " heartbeats of a runner. Changing this to a lower"
@@ -108,13 +114,21 @@ class AllSiteSettings(FrontendSiteSettings):
                 ),
                 rqa.RequiredArgument(
                     "AUTO_TEST_MAX_RESULT_NOT_STARTED",
-                    rqa.SimpleValue.float,
+                    rqa.RichValue.TimeDelta,
                     doc=(
                         "The maximum amount of time a result can be in the"
                         ' "not started" state before we raise an alarm on the'
                         " about health page."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "AUTO_TEST_MAX_UNIT_TEST_METADATA_LENGTH",
+                    rqa.SimpleValue.int,
+                    doc=(
+                        "The maximum size of metadata stored on a unit test"
+                        " step."
+                    ),
+                ),
                 rqa.RequiredArgument(
                     "MIN_PASSWORD_SCORE",
                     rqa.SimpleValue.int,
@@ -128,7 +142,7 @@ class AllSiteSettings(FrontendSiteSettings):
                 ),
                 rqa.RequiredArgument(
                     "RESET_TOKEN_TIME",
-                    rqa.SimpleValue.float,
+                    rqa.RichValue.TimeDelta,
                     doc=(
                         "The amount of time a reset token is valid. You should"
                         " not increase this value too much as users might be"
@@ -139,7 +153,7 @@ class AllSiteSettings(FrontendSiteSettings):
                 ),
                 rqa.RequiredArgument(
                     "SETTING_TOKEN_TIME",
-                    rqa.SimpleValue.float,
+                    rqa.RichValue.TimeDelta,
                     doc=(
                         "The amount of time the link send in notification"
                         " emails to change the notification preferences works"
@@ -186,112 +200,124 @@ class AllSiteSettings(FrontendSiteSettings):
                 ),
                 rqa.RequiredArgument(
                     "JWT_ACCESS_TOKEN_EXPIRES",
-                    rqa.SimpleValue.float,
+                    rqa.RichValue.TimeDelta,
                     doc=(
                         "The time a login session is valid. After this amount"
                         " of time a user will always need to re-authenticate."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "MAX_MIRROR_FILE_AGE",
+                    rqa.RichValue.TimeDelta,
+                    doc=(
+                        "The time a user has to download a file from the"
+                        " mirror storage, after this time the file will be"
+                        " deleted."
+                    ),
+                ),
             )
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["AUTO_TEST_HEARTBEAT_INTERVAL"] = to_dict(
-            self.auto_test_heartbeat_interval
-        )
-        res["AUTO_TEST_HEARTBEAT_MAX_MISSED"] = to_dict(
-            self.auto_test_heartbeat_max_missed
-        )
-        res["AUTO_TEST_MAX_JOBS_PER_RUNNER"] = to_dict(
-            self.auto_test_max_jobs_per_runner
-        )
-        res["AUTO_TEST_MAX_CONCURRENT_BATCH_RUNS"] = to_dict(
-            self.auto_test_max_concurrent_batch_runs
-        )
-        res["AUTO_TEST_MAX_RESULT_NOT_STARTED"] = to_dict(
-            self.auto_test_max_result_not_started
-        )
-        res["MIN_PASSWORD_SCORE"] = to_dict(self.min_password_score)
-        res["RESET_TOKEN_TIME"] = to_dict(self.reset_token_time)
-        res["SETTING_TOKEN_TIME"] = to_dict(self.setting_token_time)
-        res["MAX_NUMBER_OF_FILES"] = to_dict(self.max_number_of_files)
-        res["MAX_LARGE_UPLOAD_SIZE"] = to_dict(self.max_large_upload_size)
-        res["MAX_NORMAL_UPLOAD_SIZE"] = to_dict(self.max_normal_upload_size)
-        res["MAX_FILE_SIZE"] = to_dict(self.max_file_size)
-        res["JWT_ACCESS_TOKEN_EXPIRES"] = to_dict(
-            self.jwt_access_token_expires
-        )
-        res["AUTO_TEST_MAX_TIME_COMMAND"] = to_dict(
-            self.auto_test_max_time_command
-        )
-        res["AUTO_TEST_IO_TEST_MESSAGE"] = to_dict(
-            self.auto_test_io_test_message
-        )
-        res["AUTO_TEST_IO_TEST_SUB_MESSAGE"] = to_dict(
-            self.auto_test_io_test_sub_message
-        )
-        res["AUTO_TEST_RUN_PROGRAM_MESSAGE"] = to_dict(
-            self.auto_test_run_program_message
-        )
-        res["AUTO_TEST_CAPTURE_POINTS_MESSAGE"] = to_dict(
-            self.auto_test_capture_points_message
-        )
-        res["AUTO_TEST_CHECKPOINT_MESSAGE"] = to_dict(
-            self.auto_test_checkpoint_message
-        )
-        res["AUTO_TEST_UNIT_TEST_MESSAGE"] = to_dict(
-            self.auto_test_unit_test_message
-        )
-        res["AUTO_TEST_CODE_QUALITY_MESSAGE"] = to_dict(
-            self.auto_test_code_quality_message
-        )
-        res["EXAM_LOGIN_MAX_LENGTH"] = to_dict(self.exam_login_max_length)
-        res["LOGIN_TOKEN_BEFORE_TIME"] = to_dict(self.login_token_before_time)
-        res["SITE_EMAIL"] = to_dict(self.site_email)
-        res["MAX_LINES"] = to_dict(self.max_lines)
-        res["NOTIFICATION_POLL_TIME"] = to_dict(self.notification_poll_time)
-        res["RELEASE_MESSAGE_MAX_TIME"] = to_dict(
-            self.release_message_max_time
-        )
-        res["MAX_PLAGIARISM_MATCHES"] = to_dict(self.max_plagiarism_matches)
-        res["AUTO_TEST_MAX_GLOBAL_SETUP_TIME"] = to_dict(
-            self.auto_test_max_global_setup_time
-        )
-        res["AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME"] = to_dict(
-            self.auto_test_max_per_student_setup_time
-        )
-        res["SERVER_TIME_DIFF_TOLERANCE"] = to_dict(
-            self.server_time_diff_tolerance
-        )
-        res["BLACKBOARD_ZIP_UPLOAD_ENABLED"] = to_dict(
-            self.blackboard_zip_upload_enabled
-        )
-        res["RUBRICS_ENABLED"] = to_dict(self.rubrics_enabled)
-        res["AUTOMATIC_LTI_ROLE_ENABLED"] = to_dict(
-            self.automatic_lti_role_enabled
-        )
-        res["LTI_ENABLED"] = to_dict(self.lti_enabled)
-        res["LINTERS_ENABLED"] = to_dict(self.linters_enabled)
-        res["INCREMENTAL_RUBRIC_SUBMISSION_ENABLED"] = to_dict(
-            self.incremental_rubric_submission_enabled
-        )
-        res["REGISTER_ENABLED"] = to_dict(self.register_enabled)
-        res["GROUPS_ENABLED"] = to_dict(self.groups_enabled)
-        res["AUTO_TEST_ENABLED"] = to_dict(self.auto_test_enabled)
-        res["COURSE_REGISTER_ENABLED"] = to_dict(self.course_register_enabled)
-        res["RENDER_HTML_ENABLED"] = to_dict(self.render_html_enabled)
-        res["EMAIL_STUDENTS_ENABLED"] = to_dict(self.email_students_enabled)
-        res["PEER_FEEDBACK_ENABLED"] = to_dict(self.peer_feedback_enabled)
-        res["AT_IMAGE_CACHING_ENABLED"] = to_dict(
-            self.at_image_caching_enabled
-        )
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "AUTO_TEST_HEARTBEAT_INTERVAL": to_dict(
+                self.auto_test_heartbeat_interval
+            ),
+            "AUTO_TEST_HEARTBEAT_MAX_MISSED": to_dict(
+                self.auto_test_heartbeat_max_missed
+            ),
+            "AUTO_TEST_MAX_JOBS_PER_RUNNER": to_dict(
+                self.auto_test_max_jobs_per_runner
+            ),
+            "AUTO_TEST_MAX_CONCURRENT_BATCH_RUNS": to_dict(
+                self.auto_test_max_concurrent_batch_runs
+            ),
+            "AUTO_TEST_MAX_RESULT_NOT_STARTED": to_dict(
+                self.auto_test_max_result_not_started
+            ),
+            "AUTO_TEST_MAX_UNIT_TEST_METADATA_LENGTH": to_dict(
+                self.auto_test_max_unit_test_metadata_length
+            ),
+            "MIN_PASSWORD_SCORE": to_dict(self.min_password_score),
+            "RESET_TOKEN_TIME": to_dict(self.reset_token_time),
+            "SETTING_TOKEN_TIME": to_dict(self.setting_token_time),
+            "MAX_NUMBER_OF_FILES": to_dict(self.max_number_of_files),
+            "MAX_LARGE_UPLOAD_SIZE": to_dict(self.max_large_upload_size),
+            "MAX_NORMAL_UPLOAD_SIZE": to_dict(self.max_normal_upload_size),
+            "MAX_FILE_SIZE": to_dict(self.max_file_size),
+            "JWT_ACCESS_TOKEN_EXPIRES": to_dict(self.jwt_access_token_expires),
+            "MAX_MIRROR_FILE_AGE": to_dict(self.max_mirror_file_age),
+            "AUTO_TEST_MAX_TIME_COMMAND": to_dict(
+                self.auto_test_max_time_command
+            ),
+            "AUTO_TEST_IO_TEST_MESSAGE": to_dict(
+                self.auto_test_io_test_message
+            ),
+            "AUTO_TEST_IO_TEST_SUB_MESSAGE": to_dict(
+                self.auto_test_io_test_sub_message
+            ),
+            "AUTO_TEST_RUN_PROGRAM_MESSAGE": to_dict(
+                self.auto_test_run_program_message
+            ),
+            "AUTO_TEST_CAPTURE_POINTS_MESSAGE": to_dict(
+                self.auto_test_capture_points_message
+            ),
+            "AUTO_TEST_CHECKPOINT_MESSAGE": to_dict(
+                self.auto_test_checkpoint_message
+            ),
+            "AUTO_TEST_UNIT_TEST_MESSAGE": to_dict(
+                self.auto_test_unit_test_message
+            ),
+            "AUTO_TEST_CODE_QUALITY_MESSAGE": to_dict(
+                self.auto_test_code_quality_message
+            ),
+            "EXAM_LOGIN_MAX_LENGTH": to_dict(self.exam_login_max_length),
+            "LOGIN_TOKEN_BEFORE_TIME": to_dict(self.login_token_before_time),
+            "SITE_EMAIL": to_dict(self.site_email),
+            "MAX_LINES": to_dict(self.max_lines),
+            "NOTIFICATION_POLL_TIME": to_dict(self.notification_poll_time),
+            "RELEASE_MESSAGE_MAX_TIME": to_dict(self.release_message_max_time),
+            "MAX_PLAGIARISM_MATCHES": to_dict(self.max_plagiarism_matches),
+            "AUTO_TEST_MAX_GLOBAL_SETUP_TIME": to_dict(
+                self.auto_test_max_global_setup_time
+            ),
+            "AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME": to_dict(
+                self.auto_test_max_per_student_setup_time
+            ),
+            "SERVER_TIME_DIFF_TOLERANCE": to_dict(
+                self.server_time_diff_tolerance
+            ),
+            "ASSIGNMENT_DEFAULT_GRADING_SCALE": to_dict(
+                self.assignment_default_grading_scale
+            ),
+            "BLACKBOARD_ZIP_UPLOAD_ENABLED": to_dict(
+                self.blackboard_zip_upload_enabled
+            ),
+            "RUBRICS_ENABLED": to_dict(self.rubrics_enabled),
+            "AUTOMATIC_LTI_ROLE_ENABLED": to_dict(
+                self.automatic_lti_role_enabled
+            ),
+            "LTI_ENABLED": to_dict(self.lti_enabled),
+            "LINTERS_ENABLED": to_dict(self.linters_enabled),
+            "INCREMENTAL_RUBRIC_SUBMISSION_ENABLED": to_dict(
+                self.incremental_rubric_submission_enabled
+            ),
+            "REGISTER_ENABLED": to_dict(self.register_enabled),
+            "GROUPS_ENABLED": to_dict(self.groups_enabled),
+            "AUTO_TEST_ENABLED": to_dict(self.auto_test_enabled),
+            "COURSE_REGISTER_ENABLED": to_dict(self.course_register_enabled),
+            "RENDER_HTML_ENABLED": to_dict(self.render_html_enabled),
+            "EMAIL_STUDENTS_ENABLED": to_dict(self.email_students_enabled),
+            "PEER_FEEDBACK_ENABLED": to_dict(self.peer_feedback_enabled),
+            "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
+            "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AllSiteSettings"], d: Dict[str, Any]
+        cls: t.Type["AllSiteSettings"], d: t.Dict[str, t.Any]
     ) -> "AllSiteSettings":
         parsed = cls.data_parser.try_parse(d)
 
@@ -301,6 +327,7 @@ class AllSiteSettings(FrontendSiteSettings):
             auto_test_max_jobs_per_runner=parsed.AUTO_TEST_MAX_JOBS_PER_RUNNER,
             auto_test_max_concurrent_batch_runs=parsed.AUTO_TEST_MAX_CONCURRENT_BATCH_RUNS,
             auto_test_max_result_not_started=parsed.AUTO_TEST_MAX_RESULT_NOT_STARTED,
+            auto_test_max_unit_test_metadata_length=parsed.AUTO_TEST_MAX_UNIT_TEST_METADATA_LENGTH,
             min_password_score=parsed.MIN_PASSWORD_SCORE,
             reset_token_time=parsed.RESET_TOKEN_TIME,
             setting_token_time=parsed.SETTING_TOKEN_TIME,
@@ -309,6 +336,7 @@ class AllSiteSettings(FrontendSiteSettings):
             max_normal_upload_size=parsed.MAX_NORMAL_UPLOAD_SIZE,
             max_file_size=parsed.MAX_FILE_SIZE,
             jwt_access_token_expires=parsed.JWT_ACCESS_TOKEN_EXPIRES,
+            max_mirror_file_age=parsed.MAX_MIRROR_FILE_AGE,
             auto_test_max_time_command=parsed.AUTO_TEST_MAX_TIME_COMMAND,
             auto_test_io_test_message=parsed.AUTO_TEST_IO_TEST_MESSAGE,
             auto_test_io_test_sub_message=parsed.AUTO_TEST_IO_TEST_SUB_MESSAGE,
@@ -327,6 +355,7 @@ class AllSiteSettings(FrontendSiteSettings):
             auto_test_max_global_setup_time=parsed.AUTO_TEST_MAX_GLOBAL_SETUP_TIME,
             auto_test_max_per_student_setup_time=parsed.AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
+            assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
             automatic_lti_role_enabled=parsed.AUTOMATIC_LTI_ROLE_ENABLED,
@@ -341,6 +370,7 @@ class AllSiteSettings(FrontendSiteSettings):
             email_students_enabled=parsed.EMAIL_STUDENTS_ENABLED,
             peer_feedback_enabled=parsed.PEER_FEEDBACK_ENABLED,
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
+            student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
         )
         res.raw_data = d
         return res
