@@ -3,17 +3,20 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type, Union
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
-from ..parsers import ParserFor, make_union
+from .. import parsers
 from ..utils import to_dict
 from .assignment_anonymization_algo import AssignmentAnonymizationAlgo
+from .assignment_grading_settings_as_json import (
+    AssignmentGradingSettingsAsJSON,
+)
 from .assignment_kind import AssignmentKind
 from .assignment_peer_feedback_settings import AssignmentPeerFeedbackSettings
+from .cg_ignore_version import CGIgnoreVersion
 from .group_set import GroupSet
 from .submission_validator_input_data import SubmissionValidatorInputData
 
@@ -28,17 +31,17 @@ class Assignment:
     #: The id of the assignment.
     id: "int"
     #: Current state of the assignment.
-    state: "Literal['hidden', 'submitting', 'grading', 'done']"
+    state: "t.Literal['done', 'grading', 'hidden', 'submitting']"
     #: Description of the assignment.
-    description: "Optional[str]"
+    description: "t.Optional[str]"
     #: When this assignment was created.
     created_at: "datetime.datetime"
     #: The deadline of the assignment. It is possible the assignment has no
     #: deadline yet, in which case it will be `None`.
-    deadline: "Optional[datetime.datetime]"
+    deadline: "t.Optional[datetime.datetime]"
     #: The moment this assignment locks, this can be seen as a form of second
     #: deadline.
-    lock_date: "Optional[datetime.datetime]"
+    lock_date: "t.Optional[datetime.datetime]"
     #: The name of the assignment.
     name: "str"
     #: Is this an LTI assignment.
@@ -46,76 +49,83 @@ class Assignment:
     #: Course of this assignment.
     course_id: "int"
     #: The cginore.
-    cgignore: "Optional[Union[SubmissionValidatorInputData, str]]"
+    cgignore: "t.Optional[t.Union[SubmissionValidatorInputData, str]]"
     #: The version of the cignore file.
-    cgignore_version: "Optional[str]"
+    cgignore_version: "t.Optional[CGIgnoreVersion]"
     #: The time the assignment will become available (i.e. the state will
     #: switch from 'hidden' to 'open'). If the state is not 'hidden' this value
     #: has no meaning. If this value is not `None` you cannot change to state
     #: to 'hidden' or 'open'.
-    available_at: "Optional[datetime.datetime]"
+    available_at: "t.Optional[datetime.datetime]"
     #: Should we send login links to all users before the `available_at` time.
     send_login_links: "bool"
     #: The fixed value for the maximum that can be achieved in a rubric. This
     #: can be higher and lower than the actual max. Will be `None` if unset.
-    fixed_max_rubric_points: "Optional[float]"
+    fixed_max_rubric_points: "t.Optional[float]"
     #: The maximum grade you can get for this assignment. This is based around
     #: the idea that a 10 is a 'perfect' score. So if this value is 12 a user
     #: can score 2 additional bonus points. If this value is `None` it is unset
     #: and regarded as a 10.
-    max_grade: "Optional[float]"
+    max_grade: "t.Optional[float]"
+    #: Settings that influence how the grade for a submission can be
+    #: determined. TODO: Should we also move max\_grade and/or
+    #: fixed\_max\_rubric\_points to the grading object?
+    grading: "AssignmentGradingSettingsAsJSON"
     #: The group set of this assignment. This is `None` if this assignment is
     #: not a group assignment.
-    group_set: "Optional[GroupSet]"
+    group_set: "t.Optional[GroupSet]"
     #: The id of the AutoTest configuration connected to this assignment. This
     #: will always be given if there is a configuration connected to this
     #: assignment, even if you do not have permission to see the configuration
     #: itself.
-    auto_test_id: "Optional[int]"
+    auto_test_id: "t.Optional[int]"
     #: Can you upload files to this assignment.
     files_upload_enabled: "bool"
     #: Can you connect git to this assignment
     webhook_upload_enabled: "bool"
     #: The maximum amount of submission a student may create, inclusive. The
     #: value `null` indicates that there is no limit.
-    max_submissions: "Optional[int]"
+    max_submissions: "t.Optional[int]"
     #: The time period in which a person can submit at most
     #: `amount_in_cool_off_period` amount.
-    cool_off_period: "float"
+    cool_off_period: "datetime.timedelta"
     #: The maximum amount of time a user can submit within
     #: `amount_in_cool_off_period`. This value is always \>= 0, if this value
     #: is 0 a user can submit an unlimited amount of time.
     amount_in_cool_off_period: "int"
     #: The moment reminder emails will be sent. This will be `None` if you
     #: don't have the permission to see this or if it is unset.
-    reminder_time: "Optional[str]"
+    reminder_time: "t.Optional[str]"
     #: The LMS providing this LTI assignment.
-    lms_name: "Optional[str]"
+    lms_name: "t.Optional[str]"
     #: The peer feedback settings for this assignment. If `null` this
     #: assignment is not a peer feedback assignment.
-    peer_feedback_settings: "Optional[AssignmentPeerFeedbackSettings]"
+    peer_feedback_settings: "t.Optional[AssignmentPeerFeedbackSettings]"
     #: The kind of reminder that will be sent. If you don't have the permission
-    #: to see this it will always be `null` If this is not set it will also be
+    #: to see this it will always be `null`. If this is not set it will also be
     #: `null`.
-    done_type: "Optional[str]"
+    done_type: "t.Optional[str]"
     #: The email where the done email will be sent to. This will be `null` if
     #: you do not have permission to see this information.
-    done_email: "Optional[str]"
+    done_email: "t.Optional[str]"
     #: The assignment id of the assignment that determines the grader division
     #: of this assignment. This will be `null` if you do not have permissions
     #: to see this information, or if no such parent is set.
-    division_parent_id: "Optional[int]"
+    division_parent_id: "t.Optional[int]"
     #: The ids of the analytics workspaces connected to this assignment.
     #: WARNING: This API is still in beta, and might change in the future.
-    analytics_workspace_ids: "Sequence[int]"
+    analytics_workspace_ids: "t.Sequence[int]"
     #: What kind of assignment is this.
     kind: "AssignmentKind"
     #: The anonymization algorithm used for this assignment.
-    anonymized_grading: "Optional[AssignmentAnonymizationAlgo]"
+    anonymized_grading: "t.Optional[AssignmentAnonymizationAlgo]"
+    #: Optionally a glob for a file that should be loaded first in the file
+    #: viewer. There is no guarantee that any file actually matches this glob.
+    file_to_load_first: "t.Optional[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -124,7 +134,7 @@ class Assignment:
             ),
             rqa.RequiredArgument(
                 "state",
-                rqa.StringEnum("hidden", "submitting", "grading", "done"),
+                rqa.StringEnum("done", "grading", "hidden", "submitting"),
                 doc="Current state of the assignment.",
             ),
             rqa.RequiredArgument(
@@ -172,8 +182,8 @@ class Assignment:
             rqa.RequiredArgument(
                 "cgignore",
                 rqa.Nullable(
-                    make_union(
-                        ParserFor.make(SubmissionValidatorInputData),
+                    parsers.make_union(
+                        parsers.ParserFor.make(SubmissionValidatorInputData),
                         rqa.SimpleValue.str,
                     )
                 ),
@@ -181,7 +191,7 @@ class Assignment:
             ),
             rqa.RequiredArgument(
                 "cgignore_version",
-                rqa.Nullable(rqa.SimpleValue.str),
+                rqa.Nullable(rqa.EnumValue(CGIgnoreVersion)),
                 doc="The version of the cignore file.",
             ),
             rqa.RequiredArgument(
@@ -223,9 +233,19 @@ class Assignment:
                     " regarded as a 10."
                 ),
             ),
+            rqa.RequiredArgument(
+                "grading",
+                parsers.ParserFor.make(AssignmentGradingSettingsAsJSON),
+                doc=(
+                    "Settings that influence how the grade for a submission"
+                    " can be determined. TODO: Should we also move max\\_grade"
+                    " and/or fixed\\_max\\_rubric\\_points to the grading"
+                    " object?"
+                ),
+            ),
             rqa.RequiredArgument(
                 "group_set",
-                rqa.Nullable(ParserFor.make(GroupSet)),
+                rqa.Nullable(parsers.ParserFor.make(GroupSet)),
                 doc=(
                     "The group set of this assignment. This is `None` if this"
                     " assignment is not a group assignment."
@@ -262,7 +282,7 @@ class Assignment:
             ),
             rqa.RequiredArgument(
                 "cool_off_period",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "The time period in which a person can submit at most"
                     " `amount_in_cool_off_period` amount."
@@ -294,7 +314,9 @@ class Assignment:
             ),
             rqa.RequiredArgument(
                 "peer_feedback_settings",
-                rqa.Nullable(ParserFor.make(AssignmentPeerFeedbackSettings)),
+                rqa.Nullable(
+                    parsers.ParserFor.make(AssignmentPeerFeedbackSettings)
+                ),
                 doc=(
                     "The peer feedback settings for this assignment. If `null`"
                     " this assignment is not a peer feedback assignment."
@@ -305,7 +327,7 @@ class Assignment:
                 rqa.Nullable(rqa.SimpleValue.str),
                 doc=(
                     "The kind of reminder that will be sent. If you don't have"
-                    " the permission to see this it will always be `null` If"
+                    " the permission to see this it will always be `null`. If"
                     " this is not set it will also be `null`."
                 ),
             ),
@@ -347,48 +369,62 @@ class Assignment:
                 rqa.Nullable(rqa.EnumValue(AssignmentAnonymizationAlgo)),
                 doc="The anonymization algorithm used for this assignment.",
             ),
+            rqa.RequiredArgument(
+                "file_to_load_first",
+                rqa.Nullable(rqa.SimpleValue.str),
+                doc=(
+                    "Optionally a glob for a file that should be loaded first"
+                    " in the file viewer. There is no guarantee that any file"
+                    " actually matches this glob."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["state"] = to_dict(self.state)
-        res["description"] = to_dict(self.description)
-        res["created_at"] = to_dict(self.created_at)
-        res["deadline"] = to_dict(self.deadline)
-        res["lock_date"] = to_dict(self.lock_date)
-        res["name"] = to_dict(self.name)
-        res["is_lti"] = to_dict(self.is_lti)
-        res["course_id"] = to_dict(self.course_id)
-        res["cgignore"] = to_dict(self.cgignore)
-        res["cgignore_version"] = to_dict(self.cgignore_version)
-        res["available_at"] = to_dict(self.available_at)
-        res["send_login_links"] = to_dict(self.send_login_links)
-        res["fixed_max_rubric_points"] = to_dict(self.fixed_max_rubric_points)
-        res["max_grade"] = to_dict(self.max_grade)
-        res["group_set"] = to_dict(self.group_set)
-        res["auto_test_id"] = to_dict(self.auto_test_id)
-        res["files_upload_enabled"] = to_dict(self.files_upload_enabled)
-        res["webhook_upload_enabled"] = to_dict(self.webhook_upload_enabled)
-        res["max_submissions"] = to_dict(self.max_submissions)
-        res["cool_off_period"] = to_dict(self.cool_off_period)
-        res["amount_in_cool_off_period"] = to_dict(
-            self.amount_in_cool_off_period
-        )
-        res["reminder_time"] = to_dict(self.reminder_time)
-        res["lms_name"] = to_dict(self.lms_name)
-        res["peer_feedback_settings"] = to_dict(self.peer_feedback_settings)
-        res["done_type"] = to_dict(self.done_type)
-        res["done_email"] = to_dict(self.done_email)
-        res["division_parent_id"] = to_dict(self.division_parent_id)
-        res["analytics_workspace_ids"] = to_dict(self.analytics_workspace_ids)
-        res["kind"] = to_dict(self.kind)
-        res["anonymized_grading"] = to_dict(self.anonymized_grading)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "state": to_dict(self.state),
+            "description": to_dict(self.description),
+            "created_at": to_dict(self.created_at),
+            "deadline": to_dict(self.deadline),
+            "lock_date": to_dict(self.lock_date),
+            "name": to_dict(self.name),
+            "is_lti": to_dict(self.is_lti),
+            "course_id": to_dict(self.course_id),
+            "cgignore": to_dict(self.cgignore),
+            "cgignore_version": to_dict(self.cgignore_version),
+            "available_at": to_dict(self.available_at),
+            "send_login_links": to_dict(self.send_login_links),
+            "fixed_max_rubric_points": to_dict(self.fixed_max_rubric_points),
+            "max_grade": to_dict(self.max_grade),
+            "grading": to_dict(self.grading),
+            "group_set": to_dict(self.group_set),
+            "auto_test_id": to_dict(self.auto_test_id),
+            "files_upload_enabled": to_dict(self.files_upload_enabled),
+            "webhook_upload_enabled": to_dict(self.webhook_upload_enabled),
+            "max_submissions": to_dict(self.max_submissions),
+            "cool_off_period": to_dict(self.cool_off_period),
+            "amount_in_cool_off_period": to_dict(
+                self.amount_in_cool_off_period
+            ),
+            "reminder_time": to_dict(self.reminder_time),
+            "lms_name": to_dict(self.lms_name),
+            "peer_feedback_settings": to_dict(self.peer_feedback_settings),
+            "done_type": to_dict(self.done_type),
+            "done_email": to_dict(self.done_email),
+            "division_parent_id": to_dict(self.division_parent_id),
+            "analytics_workspace_ids": to_dict(self.analytics_workspace_ids),
+            "kind": to_dict(self.kind),
+            "anonymized_grading": to_dict(self.anonymized_grading),
+            "file_to_load_first": to_dict(self.file_to_load_first),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["Assignment"], d: Dict[str, Any]) -> "Assignment":
+    def from_dict(
+        cls: t.Type["Assignment"], d: t.Dict[str, t.Any]
+    ) -> "Assignment":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
@@ -407,6 +443,7 @@ class Assignment:
             send_login_links=parsed.send_login_links,
             fixed_max_rubric_points=parsed.fixed_max_rubric_points,
             max_grade=parsed.max_grade,
+            grading=parsed.grading,
             group_set=parsed.group_set,
             auto_test_id=parsed.auto_test_id,
             files_upload_enabled=parsed.files_upload_enabled,
@@ -423,6 +460,7 @@ class Assignment:
             analytics_workspace_ids=parsed.analytics_workspace_ids,
             kind=parsed.kind,
             anonymized_grading=parsed.anonymized_grading,
+            file_to_load_first=parsed.file_to_load_first,
         )
         res.raw_data = d
         return res
