@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
@@ -19,13 +19,13 @@ class AssignmentFeedback:
     #: The general feedback of the submission.
     general: "str"
     #: The inline comments as a list of strings.
-    user: "Sequence[str]"
+    user: "t.Sequence[str]"
     #: The linter comments as a list of strings.
-    linter: "Sequence[str]"
+    linter: "t.Sequence[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "general",
@@ -45,16 +45,17 @@ class AssignmentFeedback:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["general"] = to_dict(self.general)
-        res["user"] = to_dict(self.user)
-        res["linter"] = to_dict(self.linter)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "general": to_dict(self.general),
+            "user": to_dict(self.user),
+            "linter": to_dict(self.linter),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AssignmentFeedback"], d: Dict[str, Any]
+        cls: t.Type["AssignmentFeedback"], d: t.Dict[str, t.Any]
     ) -> "AssignmentFeedback":
         parsed = cls.data_parser.try_parse(d)
 
