@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .assignment import Assignment
 from .user import User
@@ -24,11 +24,11 @@ class AssignmentLoginLink:
     #: The user that is link will login.
     user: "User"
     #: The amount of seconds until the exam starts.
-    time_to_start: "Optional[float]"
+    time_to_start: "t.Optional[float]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -37,12 +37,12 @@ class AssignmentLoginLink:
             ),
             rqa.RequiredArgument(
                 "assignment",
-                ParserFor.make(Assignment),
+                parsers.ParserFor.make(Assignment),
                 doc="The assignment connected to this login link.",
             ),
             rqa.RequiredArgument(
                 "user",
-                ParserFor.make(User),
+                parsers.ParserFor.make(User),
                 doc="The user that is link will login.",
             ),
             rqa.RequiredArgument(
@@ -53,17 +53,18 @@ class AssignmentLoginLink:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["assignment"] = to_dict(self.assignment)
-        res["user"] = to_dict(self.user)
-        res["time_to_start"] = to_dict(self.time_to_start)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "assignment": to_dict(self.assignment),
+            "user": to_dict(self.user),
+            "time_to_start": to_dict(self.time_to_start),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AssignmentLoginLink"], d: Dict[str, Any]
+        cls: t.Type["AssignmentLoginLink"], d: t.Dict[str, t.Any]
     ) -> "AssignmentLoginLink":
         parsed = cls.data_parser.try_parse(d)
 
