@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .user import User
 
@@ -21,32 +21,33 @@ class AssignmentPeerFeedbackConnection:
     #: The user that should do the review.
     peer: "User"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "subject",
-                ParserFor.make(User),
+                parsers.ParserFor.make(User),
                 doc="The user that should be given a review.",
             ),
             rqa.RequiredArgument(
                 "peer",
-                ParserFor.make(User),
+                parsers.ParserFor.make(User),
                 doc="The user that should do the review.",
             ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["subject"] = to_dict(self.subject)
-        res["peer"] = to_dict(self.peer)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "subject": to_dict(self.subject),
+            "peer": to_dict(self.peer),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AssignmentPeerFeedbackConnection"], d: Dict[str, Any]
+        cls: t.Type["AssignmentPeerFeedbackConnection"], d: t.Dict[str, t.Any]
     ) -> "AssignmentPeerFeedbackConnection":
         parsed = cls.data_parser.try_parse(d)
 
