@@ -2,8 +2,9 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -18,14 +19,19 @@ class AssignmentPeerFeedbackSettings:
     amount: "int"
     #: The amount of time in seconds a user has after the deadline to do the
     #: peer review.
-    time: "Optional[float]"
+    time: "t.Optional[datetime.timedelta]"
     #: Should new peer feedback comments be considered approved by default or
     #: not.
     auto_approved: "bool"
+    #: Should we redivide when a user submits its first submission or its last
+    #: submission is deleted after thde deadline? If this is `False` it might
+    #: happen that some users are reviewed by less or more than `amount` of
+    #: students.
+    redivide_after_deadline: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "amount",
@@ -37,7 +43,7 @@ class AssignmentPeerFeedbackSettings:
             ),
             rqa.RequiredArgument(
                 "time",
-                rqa.Nullable(rqa.SimpleValue.float),
+                rqa.Nullable(rqa.RichValue.TimeDelta),
                 doc=(
                     "The amount of time in seconds a user has after the"
                     " deadline to do the peer review."
@@ -51,19 +57,32 @@ class AssignmentPeerFeedbackSettings:
                     " by default or not."
                 ),
             ),
+            rqa.RequiredArgument(
+                "redivide_after_deadline",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Should we redivide when a user submits its first"
+                    " submission or its last submission is deleted after thde"
+                    " deadline? If this is `False` it might happen that some"
+                    " users are reviewed by less or more than `amount` of"
+                    " students."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["amount"] = to_dict(self.amount)
-        res["time"] = to_dict(self.time)
-        res["auto_approved"] = to_dict(self.auto_approved)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "amount": to_dict(self.amount),
+            "time": to_dict(self.time),
+            "auto_approved": to_dict(self.auto_approved),
+            "redivide_after_deadline": to_dict(self.redivide_after_deadline),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AssignmentPeerFeedbackSettings"], d: Dict[str, Any]
+        cls: t.Type["AssignmentPeerFeedbackSettings"], d: t.Dict[str, t.Any]
     ) -> "AssignmentPeerFeedbackSettings":
         parsed = cls.data_parser.try_parse(d)
 
@@ -71,6 +90,7 @@ class AssignmentPeerFeedbackSettings:
             amount=parsed.amount,
             time=parsed.time,
             auto_approved=parsed.auto_approved,
+            redivide_after_deadline=parsed.redivide_after_deadline,
         )
         res.raw_data = d
         return res
