@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -22,9 +22,9 @@ class AutoTestQualityComment(BaseAutoTestQualityComment):
     #: The id of the file to which this comment is connected.
     file_id: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseAutoTestQualityComment.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -55,22 +55,23 @@ class AutoTestQualityComment(BaseAutoTestQualityComment):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["step_id"] = to_dict(self.step_id)
-        res["result_id"] = to_dict(self.result_id)
-        res["file_id"] = to_dict(self.file_id)
-        res["severity"] = to_dict(self.severity)
-        res["code"] = to_dict(self.code)
-        res["origin"] = to_dict(self.origin)
-        res["msg"] = to_dict(self.msg)
-        res["line"] = to_dict(self.line)
-        res["column"] = to_dict(self.column)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "step_id": to_dict(self.step_id),
+            "result_id": to_dict(self.result_id),
+            "file_id": to_dict(self.file_id),
+            "severity": to_dict(self.severity),
+            "code": to_dict(self.code),
+            "origin": to_dict(self.origin),
+            "msg": to_dict(self.msg),
+            "line": to_dict(self.line),
+            "column": to_dict(self.column),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestQualityComment"], d: Dict[str, Any]
+        cls: t.Type["AutoTestQualityComment"], d: t.Dict[str, t.Any]
     ) -> "AutoTestQualityComment":
         parsed = cls.data_parser.try_parse(d)
 
