@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .auto_test_result_state import AutoTestResultState
 
@@ -25,7 +25,7 @@ class AutoTestResult:
     updated_at: "datetime.datetime"
     #: The moment this result was started. If this is `null` the result has not
     #: yet started.
-    started_at: "Optional[datetime.datetime]"
+    started_at: "t.Optional[datetime.datetime]"
     #: The id of the submission (work) that was tested in this result.
     work_id: "int"
     #: The state the result is in.
@@ -33,9 +33,9 @@ class AutoTestResult:
     #: The amount of points achieved in this step by the student.
     points_achieved: "float"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -84,20 +84,21 @@ class AutoTestResult:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["updated_at"] = to_dict(self.updated_at)
-        res["started_at"] = to_dict(self.started_at)
-        res["work_id"] = to_dict(self.work_id)
-        res["state"] = to_dict(self.state)
-        res["points_achieved"] = to_dict(self.points_achieved)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "updated_at": to_dict(self.updated_at),
+            "started_at": to_dict(self.started_at),
+            "work_id": to_dict(self.work_id),
+            "state": to_dict(self.state),
+            "points_achieved": to_dict(self.points_achieved),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestResult"], d: Dict[str, Any]
+        cls: t.Type["AutoTestResult"], d: t.Dict[str, t.Any]
     ) -> "AutoTestResult":
         parsed = cls.data_parser.try_parse(d)
 
