@@ -3,11 +3,10 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
 from ..utils import to_dict
 
@@ -22,13 +21,13 @@ class AutoTestRun:
     created_at: "datetime.datetime"
     #: The state it is in. This is only kept for backwards compatibility
     #: reasons, it will always be "running".
-    state: "Literal['running']"
+    state: "t.Literal['running']"
     #: Also not used anymore, will always be `false`.
-    is_continuous: "Literal[False]"
+    is_continuous: "t.Literal[False]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -56,17 +55,18 @@ class AutoTestRun:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["state"] = to_dict(self.state)
-        res["is_continuous"] = to_dict(self.is_continuous)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "state": to_dict(self.state),
+            "is_continuous": to_dict(self.is_continuous),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestRun"], d: Dict[str, Any]
+        cls: t.Type["AutoTestRun"], d: t.Dict[str, t.Any]
     ) -> "AutoTestRun":
         parsed = cls.data_parser.try_parse(d)
 
