@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .auto_test_runner_state import AutoTestRunnerState
 
@@ -19,9 +19,9 @@ class AutoTestRunner:
     #: The current state of the runner
     state: "AutoTestRunnerState"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "state",
@@ -31,14 +31,15 @@ class AutoTestRunner:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["state"] = to_dict(self.state)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "state": to_dict(self.state),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestRunner"], d: Dict[str, Any]
+        cls: t.Type["AutoTestRunner"], d: t.Dict[str, t.Any]
     ) -> "AutoTestRunner":
         parsed = cls.data_parser.try_parse(d)
 
