@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .auto_test_suite import AutoTestSuite
 
@@ -20,15 +20,15 @@ class AutoTestSet:
     id: "int"
     #: The suites connected to this set. In the UI these are called
     #: "categories"
-    suites: "Sequence[AutoTestSuite]"
+    suites: "t.Sequence[AutoTestSuite]"
     #: A floating indicating the minimum percentage of points a student should
     #: achieve after this set (or "level"). If this percentage is not achieved
     #: the AutoTest will stop running.
     stop_points: "float"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -37,7 +37,7 @@ class AutoTestSet:
             ),
             rqa.RequiredArgument(
                 "suites",
-                rqa.List(ParserFor.make(AutoTestSuite)),
+                rqa.List(parsers.ParserFor.make(AutoTestSuite)),
                 doc=(
                     "The suites connected to this set. In the UI these are"
                     ' called "categories"'
@@ -56,16 +56,17 @@ class AutoTestSet:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["suites"] = to_dict(self.suites)
-        res["stop_points"] = to_dict(self.stop_points)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "suites": to_dict(self.suites),
+            "stop_points": to_dict(self.stop_points),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestSet"], d: Dict[str, Any]
+        cls: t.Type["AutoTestSet"], d: t.Dict[str, t.Any]
     ) -> "AutoTestSet":
         parsed = cls.data_parser.try_parse(d)
 
