@@ -2,31 +2,31 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
 from ..utils import to_dict
-from .base_auto_test_step_base import BaseAutoTestStepBase
+from .auto_test_step_base_as_json import AutoTestStepBaseAsJSON
 
 
 @dataclass
-class AutoTestStepBaseInputAsJSON(BaseAutoTestStepBase):
-    """The input data needed for a new AutoTest step."""
+class AutoTestStepBaseInputAsJSON(AutoTestStepBaseAsJSON):
+    """The step as JSON."""
 
     #: The id of the step. Provide this if you want to edit an existing step.
     #: If not provided a new step will be created.
     id: Maybe["int"] = Nothing
     #: Description template for this step that is shown to students.
-    description: Maybe["Optional[str]"] = Nothing
+    description: Maybe["t.Optional[str]"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
-        lambda: BaseAutoTestStepBase.data_parser.parser.combine(
+    data_parser: t.ClassVar = rqa.Lazy(
+        lambda: AutoTestStepBaseAsJSON.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.OptionalArgument(
                     "id",
@@ -54,13 +54,12 @@ class AutoTestStepBaseInputAsJSON(BaseAutoTestStepBase):
         self.id = maybe_from_nullable(self.id)
         self.description = maybe_from_nullable(self.description)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["name"] = to_dict(self.name)
-        res["type"] = to_dict(self.type)
-        res["weight"] = to_dict(self.weight)
-        res["hidden"] = to_dict(self.hidden)
-        res["data"] = to_dict(self.data)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "name": to_dict(self.name),
+            "weight": to_dict(self.weight),
+            "hidden": to_dict(self.hidden),
+        }
         if self.id.is_just:
             res["id"] = to_dict(self.id.value)
         if self.description.is_just:
@@ -69,16 +68,14 @@ class AutoTestStepBaseInputAsJSON(BaseAutoTestStepBase):
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestStepBaseInputAsJSON"], d: Dict[str, Any]
+        cls: t.Type["AutoTestStepBaseInputAsJSON"], d: t.Dict[str, t.Any]
     ) -> "AutoTestStepBaseInputAsJSON":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
             name=parsed.name,
-            type=parsed.type,
             weight=parsed.weight,
             hidden=parsed.hidden,
-            data=parsed.data,
             id=parsed.id,
             description=parsed.description,
         )
