@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -17,19 +17,19 @@ class AutoTestStepLogBase:
     This is also the type of the log when the test hasn't been started yet.
     """
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping().use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {}
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestStepLogBase"], d: Dict[str, Any]
+        cls: t.Type["AutoTestStepLogBase"], d: t.Dict[str, t.Any]
     ) -> "AutoTestStepLogBase":
         parsed = cls.data_parser.try_parse(d)
 
