@@ -3,20 +3,26 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type, Union
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor, make_union
+from .. import parsers
 from ..utils import to_dict
-from .auto_test_step_base import AutoTestStepBase
+from .any_redacted_auto_test_step_as_json import AnyRedactedAutoTestStepAsJSON
 from .auto_test_step_log_base import AutoTestStepLogBase
 from .auto_test_step_result_state import AutoTestStepResultState
+from .check_points_as_json import CheckPointsAsJSON
+from .code_quality_as_json import CodeQualityAsJSON
+from .custom_output_as_json import CustomOutputAsJSON
 from .custom_output_log import CustomOutputLog
+from .io_test_as_json import IOTestAsJSON
 from .io_test_log import IOTestLog
+from .junit_test_as_json import JunitTestAsJSON
 from .junit_test_log import JunitTestLog
 from .quality_test_log import QualityTestLog
+from .run_program_as_json import RunProgramAsJSON
 from .run_program_log import RunProgramLog
 
 
@@ -27,24 +33,24 @@ class AutoTestStepResult:
     #: The id of the result of a step
     id: "int"
     #: The step this is the result of.
-    auto_test_step: "AutoTestStepBase"
+    auto_test_step: "t.Union[IOTestAsJSON, RunProgramAsJSON, CustomOutputAsJSON, CheckPointsAsJSON, JunitTestAsJSON, CodeQualityAsJSON, AnyRedactedAutoTestStepAsJSON]"
     #: The state this result is in.
     state: "AutoTestStepResultState"
     #: The amount of points achieved by the student in this step.
     achieved_points: "float"
     #: The log produced by this result. The format of this log depends on the
     #: step result.
-    log: "Optional[Union[CustomOutputLog, JunitTestLog, QualityTestLog, RunProgramLog, IOTestLog, AutoTestStepLogBase]]"
+    log: "t.Optional[t.Union[CustomOutputLog, JunitTestLog, QualityTestLog, RunProgramLog, IOTestLog, AutoTestStepLogBase]]"
     #: The time this result was started, if `null` the result hasn't started
     #: yet.
-    started_at: "Optional[datetime.datetime]"
+    started_at: "t.Optional[datetime.datetime]"
     #: The id of the attachment produced by this result. If `null` no
     #: attachment was produced.
-    attachment_id: "Optional[str]"
+    attachment_id: "t.Optional[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -53,7 +59,15 @@ class AutoTestStepResult:
             ),
             rqa.RequiredArgument(
                 "auto_test_step",
-                ParserFor.make(AutoTestStepBase),
+                parsers.make_union(
+                    parsers.ParserFor.make(IOTestAsJSON),
+                    parsers.ParserFor.make(RunProgramAsJSON),
+                    parsers.ParserFor.make(CustomOutputAsJSON),
+                    parsers.ParserFor.make(CheckPointsAsJSON),
+                    parsers.ParserFor.make(JunitTestAsJSON),
+                    parsers.ParserFor.make(CodeQualityAsJSON),
+                    parsers.ParserFor.make(AnyRedactedAutoTestStepAsJSON),
+                ),
                 doc="The step this is the result of.",
             ),
             rqa.RequiredArgument(
@@ -72,13 +86,13 @@ class AutoTestStepResult:
             rqa.RequiredArgument(
                 "log",
                 rqa.Nullable(
-                    make_union(
-                        ParserFor.make(CustomOutputLog),
-                        ParserFor.make(JunitTestLog),
-                        ParserFor.make(QualityTestLog),
-                        ParserFor.make(RunProgramLog),
-                        ParserFor.make(IOTestLog),
-                        ParserFor.make(AutoTestStepLogBase),
+                    parsers.make_union(
+                        parsers.ParserFor.make(CustomOutputLog),
+                        parsers.ParserFor.make(JunitTestLog),
+                        parsers.ParserFor.make(QualityTestLog),
+                        parsers.ParserFor.make(RunProgramLog),
+                        parsers.ParserFor.make(IOTestLog),
+                        parsers.ParserFor.make(AutoTestStepLogBase),
                     )
                 ),
                 doc=(
@@ -105,20 +119,21 @@ class AutoTestStepResult:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["auto_test_step"] = to_dict(self.auto_test_step)
-        res["state"] = to_dict(self.state)
-        res["achieved_points"] = to_dict(self.achieved_points)
-        res["log"] = to_dict(self.log)
-        res["started_at"] = to_dict(self.started_at)
-        res["attachment_id"] = to_dict(self.attachment_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "auto_test_step": to_dict(self.auto_test_step),
+            "state": to_dict(self.state),
+            "achieved_points": to_dict(self.achieved_points),
+            "log": to_dict(self.log),
+            "started_at": to_dict(self.started_at),
+            "attachment_id": to_dict(self.attachment_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestStepResult"], d: Dict[str, Any]
+        cls: t.Type["AutoTestStepResult"], d: t.Dict[str, t.Any]
     ) -> "AutoTestStepResult":
         parsed = cls.data_parser.try_parse(d)
 
