@@ -2,15 +2,22 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
-from .auto_test_step_base import AutoTestStepBase
+from .any_redacted_auto_test_step_as_json import AnyRedactedAutoTestStepAsJSON
+from .check_points_as_json import CheckPointsAsJSON
+from .code_quality_as_json import CodeQualityAsJSON
+from .custom_output_as_json import CustomOutputAsJSON
+from .io_test_as_json import IOTestAsJSON
+from .junit_test_as_json import JunitTestAsJSON
 from .rubric_row_base import RubricRowBase
+from .run_program_as_json import RunProgramAsJSON
 
 
 @dataclass
@@ -20,20 +27,20 @@ class AutoTestSuite:
     #: The id of this suite (or "category")
     id: "int"
     #: The steps that will be executed in this suite.
-    steps: "Sequence[AutoTestStepBase]"
+    steps: "t.Sequence[t.Union[IOTestAsJSON, RunProgramAsJSON, CustomOutputAsJSON, CheckPointsAsJSON, JunitTestAsJSON, CodeQualityAsJSON, AnyRedactedAutoTestStepAsJSON]]"
     #: The rubric row this category is connected to.
     rubric_row: "RubricRowBase"
     #: Is the network disabled while running this category.
     network_disabled: "bool"
     #: Will submission info be available while running this step.
     submission_info: "bool"
-    #: The maximum amount of time in seconds a step (or substep) may take. If
-    #: `null` the instance default will be used.
-    command_time_limit: "Optional[float]"
+    #: The maximum amount of time a step (or substep) may take. If `null` the
+    #: instance default will be used.
+    command_time_limit: "t.Optional[datetime.timedelta]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -42,12 +49,22 @@ class AutoTestSuite:
             ),
             rqa.RequiredArgument(
                 "steps",
-                rqa.List(ParserFor.make(AutoTestStepBase)),
+                rqa.List(
+                    parsers.make_union(
+                        parsers.ParserFor.make(IOTestAsJSON),
+                        parsers.ParserFor.make(RunProgramAsJSON),
+                        parsers.ParserFor.make(CustomOutputAsJSON),
+                        parsers.ParserFor.make(CheckPointsAsJSON),
+                        parsers.ParserFor.make(JunitTestAsJSON),
+                        parsers.ParserFor.make(CodeQualityAsJSON),
+                        parsers.ParserFor.make(AnyRedactedAutoTestStepAsJSON),
+                    )
+                ),
                 doc="The steps that will be executed in this suite.",
             ),
             rqa.RequiredArgument(
                 "rubric_row",
-                ParserFor.make(RubricRowBase),
+                parsers.ParserFor.make(RubricRowBase),
                 doc="The rubric row this category is connected to.",
             ),
             rqa.RequiredArgument(
@@ -65,28 +82,29 @@ class AutoTestSuite:
             ),
             rqa.RequiredArgument(
                 "command_time_limit",
-                rqa.Nullable(rqa.SimpleValue.float),
+                rqa.Nullable(rqa.RichValue.TimeDelta),
                 doc=(
-                    "The maximum amount of time in seconds a step (or substep)"
-                    " may take. If `null` the instance default will be used."
+                    "The maximum amount of time a step (or substep) may take."
+                    " If `null` the instance default will be used."
                 ),
             ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["steps"] = to_dict(self.steps)
-        res["rubric_row"] = to_dict(self.rubric_row)
-        res["network_disabled"] = to_dict(self.network_disabled)
-        res["submission_info"] = to_dict(self.submission_info)
-        res["command_time_limit"] = to_dict(self.command_time_limit)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "steps": to_dict(self.steps),
+            "rubric_row": to_dict(self.rubric_row),
+            "network_disabled": to_dict(self.network_disabled),
+            "submission_info": to_dict(self.submission_info),
+            "command_time_limit": to_dict(self.command_time_limit),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["AutoTestSuite"], d: Dict[str, Any]
+        cls: t.Type["AutoTestSuite"], d: t.Dict[str, t.Any]
     ) -> "AutoTestSuite":
         parsed = cls.data_parser.try_parse(d)
 
