@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .frontend_site_settings import FrontendSiteSettings
 from .legacy_features import LegacyFeatures
@@ -21,7 +21,7 @@ class BaseAbout:
 
     #: What version is running on this server. Deprecated, please use `version`
     #: instead.
-    version: "Optional[str]"
+    version: "t.Optional[str]"
     #: The commit this server is running. Deprecated, please use `commit`
     #: instead.
     commit: "str"
@@ -35,9 +35,9 @@ class BaseAbout:
     #: The current time on the server
     current_time: "datetime.datetime"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "version",
@@ -57,7 +57,7 @@ class BaseAbout:
             ),
             rqa.RequiredArgument(
                 "features",
-                ParserFor.make(LegacyFeatures),
+                parsers.ParserFor.make(LegacyFeatures),
                 doc=(
                     "The features enabled on this instance. Deprecated, please"
                     " use `settings`."
@@ -65,14 +65,14 @@ class BaseAbout:
             ),
             rqa.RequiredArgument(
                 "settings",
-                ParserFor.make(FrontendSiteSettings),
+                parsers.ParserFor.make(FrontendSiteSettings),
                 doc=(
                     "The frontend settings and their values for this instance."
                 ),
             ),
             rqa.RequiredArgument(
                 "release",
-                ParserFor.make(ReleaseInfo),
+                parsers.ParserFor.make(ReleaseInfo),
                 doc="Information about the release running on this server.",
             ),
             rqa.RequiredArgument(
@@ -83,18 +83,21 @@ class BaseAbout:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["version"] = to_dict(self.version)
-        res["commit"] = to_dict(self.commit)
-        res["features"] = to_dict(self.features)
-        res["settings"] = to_dict(self.settings)
-        res["release"] = to_dict(self.release)
-        res["current_time"] = to_dict(self.current_time)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "version": to_dict(self.version),
+            "commit": to_dict(self.commit),
+            "features": to_dict(self.features),
+            "settings": to_dict(self.settings),
+            "release": to_dict(self.release),
+            "current_time": to_dict(self.current_time),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["BaseAbout"], d: Dict[str, Any]) -> "BaseAbout":
+    def from_dict(
+        cls: t.Type["BaseAbout"], d: t.Dict[str, t.Any]
+    ) -> "BaseAbout":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
