@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .column_range import ColumnRange
 from .line_range import LineRange
@@ -22,7 +22,7 @@ class BaseAutoTestQualityComment:
     #: deducted.
     severity: "QualityCommentSeverity"
     #: The error code from the linter.
-    code: "Optional[str]"
+    code: "t.Optional[str]"
     #: The name of the linter that created this comment.
     origin: "str"
     #: The message of this comment.
@@ -32,9 +32,9 @@ class BaseAutoTestQualityComment:
     #: The columns to which this comment applies.
     column: "ColumnRange"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "severity",
@@ -61,30 +61,31 @@ class BaseAutoTestQualityComment:
             ),
             rqa.RequiredArgument(
                 "line",
-                ParserFor.make(LineRange),
+                parsers.ParserFor.make(LineRange),
                 doc="The lines to which this comment applies.",
             ),
             rqa.RequiredArgument(
                 "column",
-                ParserFor.make(ColumnRange),
+                parsers.ParserFor.make(ColumnRange),
                 doc="The columns to which this comment applies.",
             ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["severity"] = to_dict(self.severity)
-        res["code"] = to_dict(self.code)
-        res["origin"] = to_dict(self.origin)
-        res["msg"] = to_dict(self.msg)
-        res["line"] = to_dict(self.line)
-        res["column"] = to_dict(self.column)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "severity": to_dict(self.severity),
+            "code": to_dict(self.code),
+            "origin": to_dict(self.origin),
+            "msg": to_dict(self.msg),
+            "line": to_dict(self.line),
+            "column": to_dict(self.column),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["BaseAutoTestQualityComment"], d: Dict[str, Any]
+        cls: t.Type["BaseAutoTestQualityComment"], d: t.Dict[str, t.Any]
     ) -> "BaseAutoTestQualityComment":
         parsed = cls.data_parser.try_parse(d)
 
