@@ -2,11 +2,10 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
 from ..utils import to_dict
 from .base_lti_provider import BaseLTIProvider
@@ -17,28 +16,28 @@ class BaseLTI1p1Provider(BaseLTIProvider):
     """The base JSON representation of a LTI 1.1 provider."""
 
     #: The LMS that is connected as this LTI provider.
-    lms: "Literal['Canvas', 'Blackboard', 'Sakai', 'Open edX', 'Moodle', 'BrightSpace', 'Populi']"
+    lms: "t.Literal['Blackboard', 'BrightSpace', 'Canvas', 'Moodle', 'Open edX', 'Populi', 'Sakai']"
     #: The LTI version used.
-    version: "Literal['lti1.1']"
+    version: "t.Literal['lti1.1']"
     #: Can you set the `lock_date` of assignment connected to this LTI
     #: provider?
     supports_lock_date: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseLTIProvider.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "lms",
                     rqa.StringEnum(
-                        "Canvas",
                         "Blackboard",
-                        "Sakai",
-                        "Open edX",
-                        "Moodle",
                         "BrightSpace",
+                        "Canvas",
+                        "Moodle",
+                        "Open edX",
                         "Populi",
+                        "Sakai",
                     ),
                     doc="The LMS that is connected as this LTI provider.",
                 ),
@@ -59,20 +58,21 @@ class BaseLTI1p1Provider(BaseLTIProvider):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["lms"] = to_dict(self.lms)
-        res["version"] = to_dict(self.version)
-        res["supports_lock_date"] = to_dict(self.supports_lock_date)
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["intended_use"] = to_dict(self.intended_use)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "lms": to_dict(self.lms),
+            "version": to_dict(self.version),
+            "supports_lock_date": to_dict(self.supports_lock_date),
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "intended_use": to_dict(self.intended_use),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["BaseLTI1p1Provider"], d: Dict[str, Any]
+        cls: t.Type["BaseLTI1p1Provider"], d: t.Dict[str, t.Any]
     ) -> "BaseLTI1p1Provider":
         parsed = cls.data_parser.try_parse(d)
 
