@@ -2,16 +2,18 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .base_lti_provider import BaseLTIProvider
 from .lms_capabilities import LMSCapabilities
+from .lti1p3_provider_presentation_as_json import (
+    LTI1p3ProviderPresentationAsJSON,
+)
 
 
 @dataclass
@@ -19,29 +21,31 @@ class BaseLTI1p3Provider(BaseLTIProvider):
     """The base representation of an LTI 1.3 provider."""
 
     #: The LMS that is connected as this LTI provider.
-    lms: "Literal['Canvas', 'Blackboard', 'Moodle', 'Brightspace']"
+    lms: "t.Literal['Blackboard', 'Brightspace', 'Canvas', 'Moodle']"
     #: The capabilities of this LMS
     capabilities: "LMSCapabilities"
     #: The LTI version used.
-    version: "Literal['lti1.3']"
+    version: "t.Literal['lti1.3']"
     #: The iss configured for this provider.
     iss: "str"
+    #: Presentational settings for this provider.
+    presentation: "LTI1p3ProviderPresentationAsJSON"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseLTIProvider.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "lms",
                     rqa.StringEnum(
-                        "Canvas", "Blackboard", "Moodle", "Brightspace"
+                        "Blackboard", "Brightspace", "Canvas", "Moodle"
                     ),
                     doc="The LMS that is connected as this LTI provider.",
                 ),
                 rqa.RequiredArgument(
                     "capabilities",
-                    ParserFor.make(LMSCapabilities),
+                    parsers.ParserFor.make(LMSCapabilities),
                     doc="The capabilities of this LMS",
                 ),
                 rqa.RequiredArgument(
@@ -54,25 +58,32 @@ class BaseLTI1p3Provider(BaseLTIProvider):
                     rqa.SimpleValue.str,
                     doc="The iss configured for this provider.",
                 ),
+                rqa.RequiredArgument(
+                    "presentation",
+                    parsers.ParserFor.make(LTI1p3ProviderPresentationAsJSON),
+                    doc="Presentational settings for this provider.",
+                ),
             )
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["lms"] = to_dict(self.lms)
-        res["capabilities"] = to_dict(self.capabilities)
-        res["version"] = to_dict(self.version)
-        res["iss"] = to_dict(self.iss)
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["intended_use"] = to_dict(self.intended_use)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "lms": to_dict(self.lms),
+            "capabilities": to_dict(self.capabilities),
+            "version": to_dict(self.version),
+            "iss": to_dict(self.iss),
+            "presentation": to_dict(self.presentation),
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "intended_use": to_dict(self.intended_use),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["BaseLTI1p3Provider"], d: Dict[str, Any]
+        cls: t.Type["BaseLTI1p3Provider"], d: t.Dict[str, t.Any]
     ) -> "BaseLTI1p3Provider":
         parsed = cls.data_parser.try_parse(d)
 
@@ -81,6 +92,7 @@ class BaseLTI1p3Provider(BaseLTIProvider):
             capabilities=parsed.capabilities,
             version=parsed.version,
             iss=parsed.iss,
+            presentation=parsed.presentation,
             id=parsed.id,
             created_at=parsed.created_at,
             intended_use=parsed.intended_use,
