@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -17,9 +17,9 @@ class BaseReleaseInfo:
     #: The commit which is running on this server.
     commit: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "commit",
@@ -29,14 +29,15 @@ class BaseReleaseInfo:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["commit"] = to_dict(self.commit)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "commit": to_dict(self.commit),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["BaseReleaseInfo"], d: Dict[str, Any]
+        cls: t.Type["BaseReleaseInfo"], d: t.Dict[str, t.Any]
     ) -> "BaseReleaseInfo":
         parsed = cls.data_parser.try_parse(d)
 
