@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -21,9 +21,9 @@ class BaseRubricItem:
     #: The amount of points a user gets when this item is selected.
     points: "float"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "description",
@@ -46,16 +46,17 @@ class BaseRubricItem:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["description"] = to_dict(self.description)
-        res["header"] = to_dict(self.header)
-        res["points"] = to_dict(self.points)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "description": to_dict(self.description),
+            "header": to_dict(self.header),
+            "points": to_dict(self.points),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["BaseRubricItem"], d: Dict[str, Any]
+        cls: t.Type["BaseRubricItem"], d: t.Dict[str, t.Any]
     ) -> "BaseRubricItem":
         parsed = cls.data_parser.try_parse(d)
 
