@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, Any, ClassVar, Dict, Optional, Type, Union
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -22,9 +22,9 @@ class ChangeUserRoleCourseData_1:
     #: The id of the user of which you want to change the role.
     user_id: "int"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "role_id",
@@ -39,15 +39,16 @@ class ChangeUserRoleCourseData_1:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["role_id"] = to_dict(self.role_id)
-        res["user_id"] = to_dict(self.user_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "role_id": to_dict(self.role_id),
+            "user_id": to_dict(self.user_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ChangeUserRoleCourseData_1"], d: Dict[str, Any]
+        cls: t.Type["ChangeUserRoleCourseData_1"], d: t.Dict[str, t.Any]
     ) -> "ChangeUserRoleCourseData_1":
         parsed = cls.data_parser.try_parse(d)
 
@@ -71,9 +72,9 @@ class ChangeUserRoleCourseData_1_2:
     #: starting with release Nobel.2
     tenant_id: Maybe["str"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "role_id",
@@ -97,19 +98,21 @@ class ChangeUserRoleCourseData_1_2:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.tenant_id = maybe_from_nullable(self.tenant_id)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["role_id"] = to_dict(self.role_id)
-        res["username"] = to_dict(self.username)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "role_id": to_dict(self.role_id),
+            "username": to_dict(self.username),
+        }
         if self.tenant_id.is_just:
             res["tenant_id"] = to_dict(self.tenant_id.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ChangeUserRoleCourseData_1_2"], d: Dict[str, Any]
+        cls: t.Type["ChangeUserRoleCourseData_1_2"], d: t.Dict[str, t.Any]
     ) -> "ChangeUserRoleCourseData_1_2":
         parsed = cls.data_parser.try_parse(d)
 
@@ -122,7 +125,7 @@ class ChangeUserRoleCourseData_1_2:
         return res
 
 
-ChangeUserRoleCourseData = Union[
+ChangeUserRoleCourseData = t.Union[
     ChangeUserRoleCourseData_1,
     ChangeUserRoleCourseData_1_2,
 ]
