@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -18,11 +18,11 @@ class ColumnRange:
     start: "int"
     #: The column the comment ends (inclusive), one indexed. If it is `null`
     #: the comments spans till the end of the line.
-    end: "Optional[int]"
+    end: "t.Optional[int]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "start",
@@ -41,15 +41,16 @@ class ColumnRange:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["start"] = to_dict(self.start)
-        res["end"] = to_dict(self.end)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "start": to_dict(self.start),
+            "end": to_dict(self.end),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ColumnRange"], d: Dict[str, Any]
+        cls: t.Type["ColumnRange"], d: t.Dict[str, t.Any]
     ) -> "ColumnRange":
         parsed = cls.data_parser.try_parse(d)
 
