@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .comment_reply import CommentReply
 
@@ -28,11 +28,11 @@ class CommentBase:
     #: always contain the file with `file_id`.
     work_id: "int"
     #: The replies, that you are allowed to see, in this comment base.
-    replies: "Sequence[CommentReply]"
+    replies: "t.Sequence[CommentReply]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -59,7 +59,7 @@ class CommentBase:
             ),
             rqa.RequiredArgument(
                 "replies",
-                rqa.List(ParserFor.make(CommentReply)),
+                rqa.List(parsers.ParserFor.make(CommentReply)),
                 doc=(
                     "The replies, that you are allowed to see, in this comment"
                     " base."
@@ -68,18 +68,19 @@ class CommentBase:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["line"] = to_dict(self.line)
-        res["file_id"] = to_dict(self.file_id)
-        res["work_id"] = to_dict(self.work_id)
-        res["replies"] = to_dict(self.replies)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "line": to_dict(self.line),
+            "file_id": to_dict(self.file_id),
+            "work_id": to_dict(self.work_id),
+            "replies": to_dict(self.replies),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["CommentBase"], d: Dict[str, Any]
+        cls: t.Type["CommentBase"], d: t.Dict[str, t.Any]
     ) -> "CommentBase":
         parsed = cls.data_parser.try_parse(d)
 
