@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .comment_reply_type import CommentReplyType
 from .comment_type import CommentType
@@ -26,13 +26,13 @@ class CommentReply:
     #: The id of the author of this reply, this will be `null` if no author is
     #: known (for legacy replies), or if you do not have the permission to see
     #: the author.
-    author_id: "Optional[int]"
+    author_id: "t.Optional[int]"
     #: If this reply was a reply to a specific `CommentReply`, this field will
-    #: be the id of this `CommentReply` Otherwise this will be `null`.
-    in_reply_to_id: "Optional[int]"
+    #: be the id of this `CommentReply`. Otherwise this will be `null`.
+    in_reply_to_id: "t.Optional[int]"
     #: The date the last edit was made to this reply, this will be `null` if
     #: you do not have the permission to see this information.
-    last_edit: "Optional[datetime.datetime]"
+    last_edit: "t.Optional[datetime.datetime]"
     #: The date this reply was created.
     created_at: "datetime.datetime"
     #: The formatting that the content of this reply is in.
@@ -45,9 +45,9 @@ class CommentReply:
     #: The id of the `CommentBase` this reply is in.
     comment_base_id: "int"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -76,7 +76,7 @@ class CommentReply:
                 rqa.Nullable(rqa.SimpleValue.int),
                 doc=(
                     "If this reply was a reply to a specific `CommentReply`,"
-                    " this field will be the id of this `CommentReply`"
+                    " this field will be the id of this `CommentReply`."
                     " Otherwise this will be `null`."
                 ),
             ),
@@ -120,23 +120,24 @@ class CommentReply:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["comment"] = to_dict(self.comment)
-        res["author_id"] = to_dict(self.author_id)
-        res["in_reply_to_id"] = to_dict(self.in_reply_to_id)
-        res["last_edit"] = to_dict(self.last_edit)
-        res["created_at"] = to_dict(self.created_at)
-        res["reply_type"] = to_dict(self.reply_type)
-        res["comment_type"] = to_dict(self.comment_type)
-        res["approved"] = to_dict(self.approved)
-        res["comment_base_id"] = to_dict(self.comment_base_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "comment": to_dict(self.comment),
+            "author_id": to_dict(self.author_id),
+            "in_reply_to_id": to_dict(self.in_reply_to_id),
+            "last_edit": to_dict(self.last_edit),
+            "created_at": to_dict(self.created_at),
+            "reply_type": to_dict(self.reply_type),
+            "comment_type": to_dict(self.comment_type),
+            "approved": to_dict(self.approved),
+            "comment_base_id": to_dict(self.comment_base_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["CommentReply"], d: Dict[str, Any]
+        cls: t.Type["CommentReply"], d: t.Dict[str, t.Any]
     ) -> "CommentReply":
         parsed = cls.data_parser.try_parse(d)
 
