@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .user import User
 
@@ -27,11 +27,11 @@ class CommentReplyEdit:
     old_text: "str"
     #: The new text after the edit. This will be `None` if this edit represents
     #: a deletion.
-    new_text: "Optional[str]"
+    new_text: "t.Optional[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -45,7 +45,7 @@ class CommentReplyEdit:
             ),
             rqa.RequiredArgument(
                 "editor",
-                ParserFor.make(User),
+                parsers.ParserFor.make(User),
                 doc="The users who edited the comment.",
             ),
             rqa.RequiredArgument(
@@ -64,18 +64,19 @@ class CommentReplyEdit:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["editor"] = to_dict(self.editor)
-        res["old_text"] = to_dict(self.old_text)
-        res["new_text"] = to_dict(self.new_text)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "editor": to_dict(self.editor),
+            "old_text": to_dict(self.old_text),
+            "new_text": to_dict(self.new_text),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["CommentReplyEdit"], d: Dict[str, Any]
+        cls: t.Type["CommentReplyEdit"], d: t.Dict[str, t.Any]
     ) -> "CommentReplyEdit":
         parsed = cls.data_parser.try_parse(d)
 
