@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .course_role import CourseRole
 
@@ -26,9 +26,9 @@ class CourseRegistrationLink:
     #: Can users register with this link
     allow_register: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -42,7 +42,7 @@ class CourseRegistrationLink:
             ),
             rqa.RequiredArgument(
                 "role",
-                ParserFor.make(CourseRole),
+                parsers.ParserFor.make(CourseRole),
                 doc="The role new users will get",
             ),
             rqa.RequiredArgument(
@@ -53,17 +53,18 @@ class CourseRegistrationLink:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["expiration_date"] = to_dict(self.expiration_date)
-        res["role"] = to_dict(self.role)
-        res["allow_register"] = to_dict(self.allow_register)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "expiration_date": to_dict(self.expiration_date),
+            "role": to_dict(self.role),
+            "allow_register": to_dict(self.allow_register),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["CourseRegistrationLink"], d: Dict[str, Any]
+        cls: t.Type["CourseRegistrationLink"], d: t.Dict[str, t.Any]
     ) -> "CourseRegistrationLink":
         parsed = cls.data_parser.try_parse(d)
 
