@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .abstract_role import AbstractRole
 from .course import Course
@@ -22,14 +22,14 @@ class CourseRole(AbstractRole):
     #: Is this role hidden
     hidden: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: AbstractRole.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "course",
-                    ParserFor.make(Course),
+                    parsers.ParserFor.make(Course),
                     doc="The course this role is connected to",
                 ),
                 rqa.RequiredArgument(
@@ -41,16 +41,19 @@ class CourseRole(AbstractRole):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["course"] = to_dict(self.course)
-        res["hidden"] = to_dict(self.hidden)
-        res["id"] = to_dict(self.id)
-        res["name"] = to_dict(self.name)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "course": to_dict(self.course),
+            "hidden": to_dict(self.hidden),
+            "id": to_dict(self.id),
+            "name": to_dict(self.name),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["CourseRole"], d: Dict[str, Any]) -> "CourseRole":
+    def from_dict(
+        cls: t.Type["CourseRole"], d: t.Dict[str, t.Any]
+    ) -> "CourseRole":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
