@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -21,9 +21,9 @@ class CourseSnippet:
     #: The value of this snippet, i.e. what this snippet should expand to.
     value: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -46,16 +46,17 @@ class CourseSnippet:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["key"] = to_dict(self.key)
-        res["value"] = to_dict(self.value)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "key": to_dict(self.key),
+            "value": to_dict(self.value),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["CourseSnippet"], d: Dict[str, Any]
+        cls: t.Type["CourseSnippet"], d: t.Dict[str, t.Any]
     ) -> "CourseSnippet":
         parsed = cls.data_parser.try_parse(d)
 
