@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -14,7 +14,7 @@ from ..utils import to_dict
 
 @dataclass
 class CreateCourseData:
-    """"""
+    """Input data required for the `Course::Create` operation."""
 
     #: The name of the new course
     name: "str"
@@ -22,9 +22,9 @@ class CreateCourseData:
     #: default to your own tenant.
     tenant_id: Maybe["str"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "name",
@@ -43,18 +43,20 @@ class CreateCourseData:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.tenant_id = maybe_from_nullable(self.tenant_id)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["name"] = to_dict(self.name)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "name": to_dict(self.name),
+        }
         if self.tenant_id.is_just:
             res["tenant_id"] = to_dict(self.tenant_id.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["CreateCourseData"], d: Dict[str, Any]
+        cls: t.Type["CreateCourseData"], d: t.Dict[str, t.Any]
     ) -> "CreateCourseData":
         parsed = cls.data_parser.try_parse(d)
 
