@@ -2,14 +2,14 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .json_create_tenant import JsonCreateTenant
 from .types import File
@@ -17,19 +17,19 @@ from .types import File
 
 @dataclass
 class CreateTenantData:
-    """"""
+    """Input data required for the `Tenant::Create` operation."""
 
     json: "JsonCreateTenant"
     logo_default: Maybe["File"] = Nothing
     logo_dark: Maybe["File"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "json",
-                ParserFor.make(JsonCreateTenant),
+                parsers.ParserFor.make(JsonCreateTenant),
                 doc="",
             ),
             rqa.OptionalArgument(
@@ -46,12 +46,14 @@ class CreateTenantData:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.logo_default = maybe_from_nullable(self.logo_default)
         self.logo_dark = maybe_from_nullable(self.logo_dark)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["json"] = to_dict(self.json)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "json": to_dict(self.json),
+        }
         if self.logo_default.is_just:
             res["logo-default"] = to_dict(self.logo_default.value)
         if self.logo_dark.is_just:
@@ -60,7 +62,7 @@ class CreateTenantData:
 
     @classmethod
     def from_dict(
-        cls: Type["CreateTenantData"], d: Dict[str, Any]
+        cls: t.Type["CreateTenantData"], d: t.Dict[str, t.Any]
     ) -> "CreateTenantData":
         parsed = cls.data_parser.try_parse(d)
 
