@@ -2,20 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    ClassVar,
-    Dict,
-    Optional,
-    Sequence,
-    Type,
-    Union,
-)
 
 import cg_request_args as rqa
 
+from .. import parsers
 from ..parsers import ParserFor, make_union
 from ..utils import to_dict
 from .user_input import UserInput
@@ -29,16 +21,16 @@ class EmailUsersCourseData_1:
     subject: "str"
     #: The plain text body of the email
     body: "str"
-    #: Email all users of the course except those specified in `usernames` If
+    #: Email all users of the course except those specified in `usernames`. If
     #: `false` we will email only the users specified in `usernames`.
     email_all_users: "bool"
     #: The usernames of the users to email (or not to email, depending on the
     #: value of `email_all_users`).
-    usernames: "Sequence[str]"
+    usernames: "t.Sequence[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "subject",
@@ -55,7 +47,7 @@ class EmailUsersCourseData_1:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Email all users of the course except those specified in"
-                    " `usernames` If `false` we will email only the users"
+                    " `usernames`. If `false` we will email only the users"
                     " specified in `usernames`."
                 ),
             ),
@@ -70,17 +62,18 @@ class EmailUsersCourseData_1:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["subject"] = to_dict(self.subject)
-        res["body"] = to_dict(self.body)
-        res["email_all_users"] = to_dict(self.email_all_users)
-        res["usernames"] = to_dict(self.usernames)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "subject": to_dict(self.subject),
+            "body": to_dict(self.body),
+            "email_all_users": to_dict(self.email_all_users),
+            "usernames": to_dict(self.usernames),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["EmailUsersCourseData_1"], d: Dict[str, Any]
+        cls: t.Type["EmailUsersCourseData_1"], d: t.Dict[str, t.Any]
     ) -> "EmailUsersCourseData_1":
         parsed = cls.data_parser.try_parse(d)
 
@@ -96,22 +89,22 @@ class EmailUsersCourseData_1:
 
 @dataclass
 class EmailUsersCourseData_1_2:
-    """"""
+    """ """
 
     #: The subject of the email
     subject: "str"
     #: The plain text body of the email
     body: "str"
-    #: Email all users of the course except those specified in `usernames` If
+    #: Email all users of the course except those specified in `usernames`. If
     #: `false` we will email only the users specified in `usernames`.
     email_all_users: "bool"
     #: The usernames of the users to email (or not to email, depending on the
     #: value of `email_all_users`).
-    users: "Sequence[UserInput]"
+    users: "t.Sequence[UserInput]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "subject",
@@ -128,13 +121,13 @@ class EmailUsersCourseData_1_2:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Email all users of the course except those specified in"
-                    " `usernames` If `false` we will email only the users"
+                    " `usernames`. If `false` we will email only the users"
                     " specified in `usernames`."
                 ),
             ),
             rqa.RequiredArgument(
                 "users",
-                rqa.List(ParserFor.make(UserInput)),
+                rqa.List(parsers.ParserFor.make(UserInput)),
                 doc=(
                     "The usernames of the users to email (or not to email,"
                     " depending on the value of `email_all_users`)."
@@ -143,17 +136,18 @@ class EmailUsersCourseData_1_2:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["subject"] = to_dict(self.subject)
-        res["body"] = to_dict(self.body)
-        res["email_all_users"] = to_dict(self.email_all_users)
-        res["users"] = to_dict(self.users)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "subject": to_dict(self.subject),
+            "body": to_dict(self.body),
+            "email_all_users": to_dict(self.email_all_users),
+            "users": to_dict(self.users),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["EmailUsersCourseData_1_2"], d: Dict[str, Any]
+        cls: t.Type["EmailUsersCourseData_1_2"], d: t.Dict[str, t.Any]
     ) -> "EmailUsersCourseData_1_2":
         parsed = cls.data_parser.try_parse(d)
 
@@ -167,7 +161,7 @@ class EmailUsersCourseData_1_2:
         return res
 
 
-EmailUsersCourseData = Union[
+EmailUsersCourseData = t.Union[
     EmailUsersCourseData_1,
     EmailUsersCourseData_1_2,
 ]
