@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .auto_test_result import AutoTestResult
 from .auto_test_run import AutoTestRun
@@ -19,7 +19,7 @@ class ExtendedAutoTestRun(AutoTestRun):
 
     #: The results in this run. This will only contain the result for the
     #: latest submissions.
-    results: "Sequence[AutoTestResult]"
+    results: "t.Sequence[AutoTestResult]"
     #: The stdout output of the `run_setup_script`. Deprecated, please use the
     #: value on a result.
     setup_stdout: "str"
@@ -27,14 +27,14 @@ class ExtendedAutoTestRun(AutoTestRun):
     #: value on a result.
     setup_stderr: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: AutoTestRun.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "results",
-                    rqa.List(ParserFor.make(AutoTestResult)),
+                    rqa.List(parsers.ParserFor.make(AutoTestResult)),
                     doc=(
                         "The results in this run. This will only contain the"
                         " result for the latest submissions."
@@ -60,20 +60,21 @@ class ExtendedAutoTestRun(AutoTestRun):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["results"] = to_dict(self.results)
-        res["setup_stdout"] = to_dict(self.setup_stdout)
-        res["setup_stderr"] = to_dict(self.setup_stderr)
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["state"] = to_dict(self.state)
-        res["is_continuous"] = to_dict(self.is_continuous)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "results": to_dict(self.results),
+            "setup_stdout": to_dict(self.setup_stdout),
+            "setup_stderr": to_dict(self.setup_stderr),
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "state": to_dict(self.state),
+            "is_continuous": to_dict(self.is_continuous),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ExtendedAutoTestRun"], d: Dict[str, Any]
+        cls: t.Type["ExtendedAutoTestRun"], d: t.Dict[str, t.Any]
     ) -> "ExtendedAutoTestRun":
         parsed = cls.data_parser.try_parse(d)
 
