@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .group import Group
 from .user_without_group import UserWithoutGroup
@@ -21,14 +21,14 @@ class ExtendedGroup(Group):
     #: `group` key as this would lead to an infinite recursion.
     virtual_user: "UserWithoutGroup"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: Group.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "virtual_user",
-                    ParserFor.make(UserWithoutGroup),
+                    parsers.ParserFor.make(UserWithoutGroup),
                     doc=(
                         "The virtual user connected to this course. It will"
                         " not contain the `group` key as this would lead to an"
@@ -39,19 +39,20 @@ class ExtendedGroup(Group):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["virtual_user"] = to_dict(self.virtual_user)
-        res["id"] = to_dict(self.id)
-        res["members"] = to_dict(self.members)
-        res["name"] = to_dict(self.name)
-        res["group_set_id"] = to_dict(self.group_set_id)
-        res["created_at"] = to_dict(self.created_at)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "virtual_user": to_dict(self.virtual_user),
+            "id": to_dict(self.id),
+            "members": to_dict(self.members),
+            "name": to_dict(self.name),
+            "group_set_id": to_dict(self.group_set_id),
+            "created_at": to_dict(self.created_at),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ExtendedGroup"], d: Dict[str, Any]
+        cls: t.Type["ExtendedGroup"], d: t.Dict[str, t.Any]
     ) -> "ExtendedGroup":
         parsed = cls.data_parser.try_parse(d)
 
