@@ -3,8 +3,8 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Mapping, Optional, Type
 
 import cg_request_args as rqa
 
@@ -19,17 +19,17 @@ class ExtendedJob(Job):
     #: The name of the job.
     name: "str"
     #: The kwargs given to the job.
-    kwargs: "Mapping[str, Any]"
+    kwargs: "t.Mapping[str, t.Any]"
     #: The current try of the job.
     try_n: "int"
     #: The time the job should be executed.
     eta: "datetime.datetime"
     #: Possibly the traceback of the job. Only not `null` when the job failed.
-    traceback: "Optional[str]"
+    traceback: "t.Optional[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: Job.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -64,21 +64,22 @@ class ExtendedJob(Job):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["name"] = to_dict(self.name)
-        res["kwargs"] = to_dict(self.kwargs)
-        res["try_n"] = to_dict(self.try_n)
-        res["eta"] = to_dict(self.eta)
-        res["traceback"] = to_dict(self.traceback)
-        res["id"] = to_dict(self.id)
-        res["state"] = to_dict(self.state)
-        res["result"] = to_dict(self.result)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "name": to_dict(self.name),
+            "kwargs": to_dict(self.kwargs),
+            "try_n": to_dict(self.try_n),
+            "eta": to_dict(self.eta),
+            "traceback": to_dict(self.traceback),
+            "id": to_dict(self.id),
+            "state": to_dict(self.state),
+            "result": to_dict(self.result),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ExtendedJob"], d: Dict[str, Any]
+        cls: t.Type["ExtendedJob"], d: t.Dict[str, t.Any]
     ) -> "ExtendedJob":
         parsed = cls.data_parser.try_parse(d)
 
