@@ -2,16 +2,17 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .global_perm_map import GlobalPermMap
+from .transaction import Transaction
 from .user import User
 
 
@@ -24,12 +25,15 @@ class ExtendedUser(User):
     email: "str"
     #: Can this user see hidden assignments at least in one course.
     hidden: "bool"
+    #: The payments this user did. This will only be provided for the currently
+    #: logged in user. For other users it will be an empty array.
+    payments: "t.Sequence[Transaction]"
     #: The permissions of the user. This will only be present if requested.
     permissions: Maybe["GlobalPermMap"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: User.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -48,9 +52,18 @@ class ExtendedUser(User):
                         " course."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "payments",
+                    rqa.List(parsers.ParserFor.make(Transaction)),
+                    doc=(
+                        "The payments this user did. This will only be"
+                        " provided for the currently logged in user. For other"
+                        " users it will be an empty array."
+                    ),
+                ),
                 rqa.OptionalArgument(
                     "permissions",
-                    ParserFor.make(GlobalPermMap),
+                    parsers.ParserFor.make(GlobalPermMap),
                     doc=(
                         "The permissions of the user. This will only be"
                         " present if requested."
@@ -64,29 +77,32 @@ class ExtendedUser(User):
         getattr(super(), "__post_init__", lambda: None)()
         self.permissions = maybe_from_nullable(self.permissions)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["email"] = to_dict(self.email)
-        res["hidden"] = to_dict(self.hidden)
-        res["group"] = to_dict(self.group)
-        res["id"] = to_dict(self.id)
-        res["name"] = to_dict(self.name)
-        res["username"] = to_dict(self.username)
-        res["is_test_student"] = to_dict(self.is_test_student)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "email": to_dict(self.email),
+            "hidden": to_dict(self.hidden),
+            "payments": to_dict(self.payments),
+            "group": to_dict(self.group),
+            "id": to_dict(self.id),
+            "name": to_dict(self.name),
+            "username": to_dict(self.username),
+            "is_test_student": to_dict(self.is_test_student),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         if self.permissions.is_just:
             res["permissions"] = to_dict(self.permissions.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ExtendedUser"], d: Dict[str, Any]
+        cls: t.Type["ExtendedUser"], d: t.Dict[str, t.Any]
     ) -> "ExtendedUser":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
             email=parsed.email,
             hidden=parsed.hidden,
+            payments=parsed.payments,
             group=parsed.group,
             id=parsed.id,
             name=parsed.name,
