@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .user import User
 from .work import Work
@@ -23,17 +23,17 @@ class ExtendedWork(Work):
     """
 
     #: The general feedback comment for this submission.
-    comment: "Optional[str]"
+    comment: "t.Optional[str]"
     #: The author of the general feedback comment.
-    comment_author: "Optional[User]"
+    comment_author: "t.Optional[User]"
     #: The assignment id of this submission.
     assignment_id: "int"
     #: The rubric result of this submission.
-    rubric_result: "Optional[WorkRubricResultAsJSON]"
+    rubric_result: "t.Optional[WorkRubricResultAsJSON]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: Work.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -43,7 +43,7 @@ class ExtendedWork(Work):
                 ),
                 rqa.RequiredArgument(
                     "comment_author",
-                    rqa.Nullable(ParserFor.make(User)),
+                    rqa.Nullable(parsers.ParserFor.make(User)),
                     doc="The author of the general feedback comment.",
                 ),
                 rqa.RequiredArgument(
@@ -53,32 +53,35 @@ class ExtendedWork(Work):
                 ),
                 rqa.RequiredArgument(
                     "rubric_result",
-                    rqa.Nullable(ParserFor.make(WorkRubricResultAsJSON)),
+                    rqa.Nullable(
+                        parsers.ParserFor.make(WorkRubricResultAsJSON)
+                    ),
                     doc="The rubric result of this submission.",
                 ),
             )
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["comment"] = to_dict(self.comment)
-        res["comment_author"] = to_dict(self.comment_author)
-        res["assignment_id"] = to_dict(self.assignment_id)
-        res["rubric_result"] = to_dict(self.rubric_result)
-        res["id"] = to_dict(self.id)
-        res["user"] = to_dict(self.user)
-        res["origin"] = to_dict(self.origin)
-        res["created_at"] = to_dict(self.created_at)
-        res["grade"] = to_dict(self.grade)
-        res["assignee"] = to_dict(self.assignee)
-        res["grade_overridden"] = to_dict(self.grade_overridden)
-        res["extra_info"] = to_dict(self.extra_info)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "comment": to_dict(self.comment),
+            "comment_author": to_dict(self.comment_author),
+            "assignment_id": to_dict(self.assignment_id),
+            "rubric_result": to_dict(self.rubric_result),
+            "id": to_dict(self.id),
+            "user": to_dict(self.user),
+            "origin": to_dict(self.origin),
+            "created_at": to_dict(self.created_at),
+            "grade": to_dict(self.grade),
+            "assignee": to_dict(self.assignee),
+            "grade_overridden": to_dict(self.grade_overridden),
+            "extra_info": to_dict(self.extra_info),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ExtendedWork"], d: Dict[str, Any]
+        cls: t.Type["ExtendedWork"], d: t.Dict[str, t.Any]
     ) -> "ExtendedWork":
         parsed = cls.data_parser.try_parse(d)
 
