@@ -2,21 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import (
-    Any,
-    ClassVar,
-    Dict,
-    Mapping,
-    Optional,
-    Sequence,
-    Type,
-    Union,
-)
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor, make_union
+from .. import parsers
 from ..utils import to_dict
 from .linter_comment import LinterComment
 
@@ -26,16 +17,16 @@ class FeedbackBase:
     """The base JSON representation for feedback."""
 
     #: The general feedback given on this submission.
-    general: "Optional[str]"
+    general: "t.Optional[str]"
     #: A mapping that is almost the same the user feedback mapping for feedback
     #: without replies, only the final key is not a string but a list of tuples
     #: where the first item is the linter code and the second item is linter
     #: comments.
-    linter: "Mapping[str, Mapping[str, Sequence[Sequence[Union[LinterComment, str]]]]]"
+    linter: "t.Mapping[str, t.Mapping[str, t.Sequence[t.Sequence[t.Union[LinterComment, str]]]]]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "general",
@@ -48,8 +39,8 @@ class FeedbackBase:
                     rqa.LookupMapping(
                         rqa.List(
                             rqa.List(
-                                make_union(
-                                    ParserFor.make(LinterComment),
+                                parsers.make_union(
+                                    parsers.ParserFor.make(LinterComment),
                                     rqa.SimpleValue.str,
                                 )
                             )
@@ -67,15 +58,16 @@ class FeedbackBase:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["general"] = to_dict(self.general)
-        res["linter"] = to_dict(self.linter)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "general": to_dict(self.general),
+            "linter": to_dict(self.linter),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["FeedbackBase"], d: Dict[str, Any]
+        cls: t.Type["FeedbackBase"], d: t.Dict[str, t.Any]
     ) -> "FeedbackBase":
         parsed = cls.data_parser.try_parse(d)
 
