@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .comment_base import CommentBase
 from .feedback_base import FeedbackBase
@@ -19,19 +19,19 @@ class FeedbackWithReplies(FeedbackBase):
     """The JSON representation for feedback with replies."""
 
     #: A list of users that have given inline feedback on this submission.
-    user: "Sequence[CommentBase]"
+    user: "t.Sequence[CommentBase]"
     #: A list of all authors you have permission to see that placed comments.
     #: This list is unique, i.e. each author occurs at most once.
-    authors: "Sequence[User]"
+    authors: "t.Sequence[User]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: FeedbackBase.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "user",
-                    rqa.List(ParserFor.make(CommentBase)),
+                    rqa.List(parsers.ParserFor.make(CommentBase)),
                     doc=(
                         "A list of users that have given inline feedback on"
                         " this submission."
@@ -39,7 +39,7 @@ class FeedbackWithReplies(FeedbackBase):
                 ),
                 rqa.RequiredArgument(
                     "authors",
-                    rqa.List(ParserFor.make(User)),
+                    rqa.List(parsers.ParserFor.make(User)),
                     doc=(
                         "A list of all authors you have permission to see that"
                         " placed comments. This list is unique, i.e. each"
@@ -50,17 +50,18 @@ class FeedbackWithReplies(FeedbackBase):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["user"] = to_dict(self.user)
-        res["authors"] = to_dict(self.authors)
-        res["general"] = to_dict(self.general)
-        res["linter"] = to_dict(self.linter)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "user": to_dict(self.user),
+            "authors": to_dict(self.authors),
+            "general": to_dict(self.general),
+            "linter": to_dict(self.linter),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["FeedbackWithReplies"], d: Dict[str, Any]
+        cls: t.Type["FeedbackWithReplies"], d: t.Dict[str, t.Any]
     ) -> "FeedbackWithReplies":
         parsed = cls.data_parser.try_parse(d)
 
