@@ -2,11 +2,10 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
 from ..utils import to_dict
 
@@ -16,16 +15,16 @@ class FileRuleInputData:
     """The input data for a single file rule for the SubmissionValidator."""
 
     #: The type of rule
-    rule_type: "Literal['allow', 'deny', 'require']"
+    rule_type: "t.Literal['allow', 'deny', 'require']"
     #: The type of files this rule should apply to.
-    file_type: "Literal['file', 'directory']"
+    file_type: "t.Literal['directory', 'file']"
     #: The pattern that describes which files this rule should apply to. This
     #: cannot be empty.
     name: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "rule_type",
@@ -34,7 +33,7 @@ class FileRuleInputData:
             ),
             rqa.RequiredArgument(
                 "file_type",
-                rqa.StringEnum("file", "directory"),
+                rqa.StringEnum("directory", "file"),
                 doc="The type of files this rule should apply to.",
             ),
             rqa.RequiredArgument(
@@ -48,16 +47,17 @@ class FileRuleInputData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["rule_type"] = to_dict(self.rule_type)
-        res["file_type"] = to_dict(self.file_type)
-        res["name"] = to_dict(self.name)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "rule_type": to_dict(self.rule_type),
+            "file_type": to_dict(self.file_type),
+            "name": to_dict(self.name),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["FileRuleInputData"], d: Dict[str, Any]
+        cls: t.Type["FileRuleInputData"], d: t.Dict[str, t.Any]
     ) -> "FileRuleInputData":
         parsed = cls.data_parser.try_parse(d)
 
