@@ -2,11 +2,10 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
 from ..utils import to_dict
 from .base_lti1p1_provider import BaseLTI1p1Provider
@@ -17,11 +16,11 @@ class FinalizedLTI1p1Provider(BaseLTI1p1Provider):
     """The JSON representation of a finalized provider."""
 
     #: This is a already finalized provider and thus is actively being used.
-    finalized: "Literal[True]"
+    finalized: "t.Literal[True]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseLTI1p1Provider.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -36,21 +35,22 @@ class FinalizedLTI1p1Provider(BaseLTI1p1Provider):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["finalized"] = to_dict(self.finalized)
-        res["lms"] = to_dict(self.lms)
-        res["version"] = to_dict(self.version)
-        res["supports_lock_date"] = to_dict(self.supports_lock_date)
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["intended_use"] = to_dict(self.intended_use)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "finalized": to_dict(self.finalized),
+            "lms": to_dict(self.lms),
+            "version": to_dict(self.version),
+            "supports_lock_date": to_dict(self.supports_lock_date),
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "intended_use": to_dict(self.intended_use),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["FinalizedLTI1p1Provider"], d: Dict[str, Any]
+        cls: t.Type["FinalizedLTI1p1Provider"], d: t.Dict[str, t.Any]
     ) -> "FinalizedLTI1p1Provider":
         parsed = cls.data_parser.try_parse(d)
 
