@@ -2,8 +2,9 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
@@ -16,7 +17,7 @@ class FrontendSiteSettings:
 
     #: The default amount of time a step/substep in AutoTest can run. This can
     #: be overridden by the teacher.
-    auto_test_max_time_command: "float"
+    auto_test_max_time_command: "datetime.timedelta"
     #: Default message for IO Test steps of an AutoTest.
     auto_test_io_test_message: "str"
     #: Default message for IO Test sub-steps of an AutoTest.
@@ -34,10 +35,10 @@ class FrontendSiteSettings:
     #: The maximum time-delta an exam may take. Increasing this value also
     #: increases the maximum amount of time the login tokens send via email are
     #: valid. Therefore, you should make this too long.
-    exam_login_max_length: "float"
+    exam_login_max_length: "datetime.timedelta"
     #: This determines how long before the exam we will send the login emails
     #: to the students (only when enabled of course).
-    login_token_before_time: "Sequence[float]"
+    login_token_before_time: "t.Sequence[datetime.timedelta]"
     #: The email shown to users as the email of CodeGrade.
     site_email: "str"
     #: The maximum amount of lines that we should in render in one go. If a
@@ -47,26 +48,28 @@ class FrontendSiteSettings:
     #: The amount of time to wait between two consecutive polls to see if a
     #: user has new notifications. Setting this value too low will cause
     #: unnecessary stres on the server.
-    notification_poll_time: "float"
+    notification_poll_time: "datetime.timedelta"
     #: What is the maximum amount of time after a release a message should be
     #: shown on the HomeGrid. **Note**: this is the amount of time after the
     #: release, not after this instance has been upgraded to this release.
-    release_message_max_time: "float"
+    release_message_max_time: "datetime.timedelta"
     #: The maximum amount of matches of a plagiarism run that we will store. If
     #: there are more matches than this they will be discarded.
     max_plagiarism_matches: "int"
     #: The maximum amount of time that the global setup script in AutoTest may
     #: take. If it takes longer than this it will be killed and the run will
     #: fail.
-    auto_test_max_global_setup_time: "float"
+    auto_test_max_global_setup_time: "datetime.timedelta"
     #: The maximum amount of time that the per student setup script in AutoTest
     #: may take. If it takes longer than this it will be killed and the result
     #: of the student will be in the state "timed-out"
-    auto_test_max_per_student_setup_time: "float"
+    auto_test_max_per_student_setup_time: "datetime.timedelta"
     #: The maximum amount of difference between the server time and the local
     #: time before we consider the local time to be out of sync with our
     #: servers.
-    server_time_diff_tolerance: "float"
+    server_time_diff_tolerance: "datetime.timedelta"
+    #: The default value for the grading scale of new assignments.
+    assignment_default_grading_scale: "t.Literal['percentage', 'points']"
     #: If enabled teachers are allowed to bulk upload submissions (and create
     #: users) using a zip file in a format created by Blackboard.
     blackboard_zip_upload_enabled: "bool"
@@ -105,14 +108,18 @@ class FrontendSiteSettings:
     peer_feedback_enabled: "bool"
     #: Should AT image caching be enabled.
     at_image_caching_enabled: "bool"
+    #: Should it be possible to let students pay for a course. Please note that
+    #: to enable this deploy config needs to be updated, so don't just enable
+    #: it.
+    student_payment_enabled: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "AUTO_TEST_MAX_TIME_COMMAND",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "The default amount of time a step/substep in AutoTest can"
                     " run. This can be overridden by the teacher."
@@ -155,7 +162,7 @@ class FrontendSiteSettings:
             ),
             rqa.RequiredArgument(
                 "EXAM_LOGIN_MAX_LENGTH",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "The maximum time-delta an exam may take. Increasing this"
                     " value also increases the maximum amount of time the"
@@ -165,7 +172,7 @@ class FrontendSiteSettings:
             ),
             rqa.RequiredArgument(
                 "LOGIN_TOKEN_BEFORE_TIME",
-                rqa.List(rqa.SimpleValue.float),
+                rqa.List(rqa.RichValue.TimeDelta),
                 doc=(
                     "This determines how long before the exam we will send the"
                     " login emails to the students (only when enabled of"
@@ -188,7 +195,7 @@ class FrontendSiteSettings:
             ),
             rqa.RequiredArgument(
                 "NOTIFICATION_POLL_TIME",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "The amount of time to wait between two consecutive polls"
                     " to see if a user has new notifications. Setting this"
@@ -198,7 +205,7 @@ class FrontendSiteSettings:
             ),
             rqa.RequiredArgument(
                 "RELEASE_MESSAGE_MAX_TIME",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "What is the maximum amount of time after a release a"
                     " message should be shown on the HomeGrid. **Note**: this"
@@ -217,7 +224,7 @@ class FrontendSiteSettings:
             ),
             rqa.RequiredArgument(
                 "AUTO_TEST_MAX_GLOBAL_SETUP_TIME",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "The maximum amount of time that the global setup script"
                     " in AutoTest may take. If it takes longer than this it"
@@ -226,7 +233,7 @@ class FrontendSiteSettings:
             ),
             rqa.RequiredArgument(
                 "AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "The maximum amount of time that the per student setup"
                     " script in AutoTest may take. If it takes longer than"
@@ -236,13 +243,21 @@ class FrontendSiteSettings:
             ),
             rqa.RequiredArgument(
                 "SERVER_TIME_DIFF_TOLERANCE",
-                rqa.SimpleValue.float,
+                rqa.RichValue.TimeDelta,
                 doc=(
                     "The maximum amount of difference between the server time"
                     " and the local time before we consider the local time to"
                     " be out of sync with our servers."
                 ),
             ),
+            rqa.RequiredArgument(
+                "ASSIGNMENT_DEFAULT_GRADING_SCALE",
+                rqa.StringEnum("percentage", "points"),
+                doc=(
+                    "The default value for the grading scale of new"
+                    " assignments."
+                ),
+            ),
             rqa.RequiredArgument(
                 "BLACKBOARD_ZIP_UPLOAD_ENABLED",
                 rqa.SimpleValue.bool,
@@ -339,80 +354,90 @@ class FrontendSiteSettings:
                 rqa.SimpleValue.bool,
                 doc="Should AT image caching be enabled.",
             ),
+            rqa.RequiredArgument(
+                "STUDENT_PAYMENT_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Should it be possible to let students pay for a course."
+                    " Please note that to enable this deploy config needs to"
+                    " be updated, so don't just enable it."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["AUTO_TEST_MAX_TIME_COMMAND"] = to_dict(
-            self.auto_test_max_time_command
-        )
-        res["AUTO_TEST_IO_TEST_MESSAGE"] = to_dict(
-            self.auto_test_io_test_message
-        )
-        res["AUTO_TEST_IO_TEST_SUB_MESSAGE"] = to_dict(
-            self.auto_test_io_test_sub_message
-        )
-        res["AUTO_TEST_RUN_PROGRAM_MESSAGE"] = to_dict(
-            self.auto_test_run_program_message
-        )
-        res["AUTO_TEST_CAPTURE_POINTS_MESSAGE"] = to_dict(
-            self.auto_test_capture_points_message
-        )
-        res["AUTO_TEST_CHECKPOINT_MESSAGE"] = to_dict(
-            self.auto_test_checkpoint_message
-        )
-        res["AUTO_TEST_UNIT_TEST_MESSAGE"] = to_dict(
-            self.auto_test_unit_test_message
-        )
-        res["AUTO_TEST_CODE_QUALITY_MESSAGE"] = to_dict(
-            self.auto_test_code_quality_message
-        )
-        res["EXAM_LOGIN_MAX_LENGTH"] = to_dict(self.exam_login_max_length)
-        res["LOGIN_TOKEN_BEFORE_TIME"] = to_dict(self.login_token_before_time)
-        res["SITE_EMAIL"] = to_dict(self.site_email)
-        res["MAX_LINES"] = to_dict(self.max_lines)
-        res["NOTIFICATION_POLL_TIME"] = to_dict(self.notification_poll_time)
-        res["RELEASE_MESSAGE_MAX_TIME"] = to_dict(
-            self.release_message_max_time
-        )
-        res["MAX_PLAGIARISM_MATCHES"] = to_dict(self.max_plagiarism_matches)
-        res["AUTO_TEST_MAX_GLOBAL_SETUP_TIME"] = to_dict(
-            self.auto_test_max_global_setup_time
-        )
-        res["AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME"] = to_dict(
-            self.auto_test_max_per_student_setup_time
-        )
-        res["SERVER_TIME_DIFF_TOLERANCE"] = to_dict(
-            self.server_time_diff_tolerance
-        )
-        res["BLACKBOARD_ZIP_UPLOAD_ENABLED"] = to_dict(
-            self.blackboard_zip_upload_enabled
-        )
-        res["RUBRICS_ENABLED"] = to_dict(self.rubrics_enabled)
-        res["AUTOMATIC_LTI_ROLE_ENABLED"] = to_dict(
-            self.automatic_lti_role_enabled
-        )
-        res["LTI_ENABLED"] = to_dict(self.lti_enabled)
-        res["LINTERS_ENABLED"] = to_dict(self.linters_enabled)
-        res["INCREMENTAL_RUBRIC_SUBMISSION_ENABLED"] = to_dict(
-            self.incremental_rubric_submission_enabled
-        )
-        res["REGISTER_ENABLED"] = to_dict(self.register_enabled)
-        res["GROUPS_ENABLED"] = to_dict(self.groups_enabled)
-        res["AUTO_TEST_ENABLED"] = to_dict(self.auto_test_enabled)
-        res["COURSE_REGISTER_ENABLED"] = to_dict(self.course_register_enabled)
-        res["RENDER_HTML_ENABLED"] = to_dict(self.render_html_enabled)
-        res["EMAIL_STUDENTS_ENABLED"] = to_dict(self.email_students_enabled)
-        res["PEER_FEEDBACK_ENABLED"] = to_dict(self.peer_feedback_enabled)
-        res["AT_IMAGE_CACHING_ENABLED"] = to_dict(
-            self.at_image_caching_enabled
-        )
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "AUTO_TEST_MAX_TIME_COMMAND": to_dict(
+                self.auto_test_max_time_command
+            ),
+            "AUTO_TEST_IO_TEST_MESSAGE": to_dict(
+                self.auto_test_io_test_message
+            ),
+            "AUTO_TEST_IO_TEST_SUB_MESSAGE": to_dict(
+                self.auto_test_io_test_sub_message
+            ),
+            "AUTO_TEST_RUN_PROGRAM_MESSAGE": to_dict(
+                self.auto_test_run_program_message
+            ),
+            "AUTO_TEST_CAPTURE_POINTS_MESSAGE": to_dict(
+                self.auto_test_capture_points_message
+            ),
+            "AUTO_TEST_CHECKPOINT_MESSAGE": to_dict(
+                self.auto_test_checkpoint_message
+            ),
+            "AUTO_TEST_UNIT_TEST_MESSAGE": to_dict(
+                self.auto_test_unit_test_message
+            ),
+            "AUTO_TEST_CODE_QUALITY_MESSAGE": to_dict(
+                self.auto_test_code_quality_message
+            ),
+            "EXAM_LOGIN_MAX_LENGTH": to_dict(self.exam_login_max_length),
+            "LOGIN_TOKEN_BEFORE_TIME": to_dict(self.login_token_before_time),
+            "SITE_EMAIL": to_dict(self.site_email),
+            "MAX_LINES": to_dict(self.max_lines),
+            "NOTIFICATION_POLL_TIME": to_dict(self.notification_poll_time),
+            "RELEASE_MESSAGE_MAX_TIME": to_dict(self.release_message_max_time),
+            "MAX_PLAGIARISM_MATCHES": to_dict(self.max_plagiarism_matches),
+            "AUTO_TEST_MAX_GLOBAL_SETUP_TIME": to_dict(
+                self.auto_test_max_global_setup_time
+            ),
+            "AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME": to_dict(
+                self.auto_test_max_per_student_setup_time
+            ),
+            "SERVER_TIME_DIFF_TOLERANCE": to_dict(
+                self.server_time_diff_tolerance
+            ),
+            "ASSIGNMENT_DEFAULT_GRADING_SCALE": to_dict(
+                self.assignment_default_grading_scale
+            ),
+            "BLACKBOARD_ZIP_UPLOAD_ENABLED": to_dict(
+                self.blackboard_zip_upload_enabled
+            ),
+            "RUBRICS_ENABLED": to_dict(self.rubrics_enabled),
+            "AUTOMATIC_LTI_ROLE_ENABLED": to_dict(
+                self.automatic_lti_role_enabled
+            ),
+            "LTI_ENABLED": to_dict(self.lti_enabled),
+            "LINTERS_ENABLED": to_dict(self.linters_enabled),
+            "INCREMENTAL_RUBRIC_SUBMISSION_ENABLED": to_dict(
+                self.incremental_rubric_submission_enabled
+            ),
+            "REGISTER_ENABLED": to_dict(self.register_enabled),
+            "GROUPS_ENABLED": to_dict(self.groups_enabled),
+            "AUTO_TEST_ENABLED": to_dict(self.auto_test_enabled),
+            "COURSE_REGISTER_ENABLED": to_dict(self.course_register_enabled),
+            "RENDER_HTML_ENABLED": to_dict(self.render_html_enabled),
+            "EMAIL_STUDENTS_ENABLED": to_dict(self.email_students_enabled),
+            "PEER_FEEDBACK_ENABLED": to_dict(self.peer_feedback_enabled),
+            "AT_IMAGE_CACHING_ENABLED": to_dict(self.at_image_caching_enabled),
+            "STUDENT_PAYMENT_ENABLED": to_dict(self.student_payment_enabled),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["FrontendSiteSettings"], d: Dict[str, Any]
+        cls: t.Type["FrontendSiteSettings"], d: t.Dict[str, t.Any]
     ) -> "FrontendSiteSettings":
         parsed = cls.data_parser.try_parse(d)
 
@@ -435,6 +460,7 @@ class FrontendSiteSettings:
             auto_test_max_global_setup_time=parsed.AUTO_TEST_MAX_GLOBAL_SETUP_TIME,
             auto_test_max_per_student_setup_time=parsed.AUTO_TEST_MAX_PER_STUDENT_SETUP_TIME,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
+            assignment_default_grading_scale=parsed.ASSIGNMENT_DEFAULT_GRADING_SCALE,
             blackboard_zip_upload_enabled=parsed.BLACKBOARD_ZIP_UPLOAD_ENABLED,
             rubrics_enabled=parsed.RUBRICS_ENABLED,
             automatic_lti_role_enabled=parsed.AUTOMATIC_LTI_ROLE_ENABLED,
@@ -449,6 +475,7 @@ class FrontendSiteSettings:
             email_students_enabled=parsed.EMAIL_STUDENTS_ENABLED,
             peer_feedback_enabled=parsed.PEER_FEEDBACK_ENABLED,
             at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
+            student_payment_enabled=parsed.STUDENT_PAYMENT_ENABLED,
         )
         res.raw_data = d
         return res
