@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .grade_origin import GradeOrigin
 from .user import User
@@ -21,20 +21,20 @@ class GradeHistory:
     #: The moment the grade was changed.
     changed_at: "datetime.datetime"
     #: Was this grade given by a rubric.
-    is_rubric: "Optional[bool]"
+    is_rubric: "t.Optional[bool]"
     #: What grade was given.
-    grade: "Optional[float]"
+    grade: "t.Optional[float]"
     #: Has this grade been passed back to the LMS?
-    passed_back: "Optional[bool]"
+    passed_back: "t.Optional[bool]"
     #: What as the origin of the grade.
     origin: "GradeOrigin"
     #: The user that gave the grade, only available when `grade_origin` is
     #: `human`.
-    user: "Optional[User]"
+    user: "t.Optional[User]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "changed_at",
@@ -63,7 +63,7 @@ class GradeHistory:
             ),
             rqa.RequiredArgument(
                 "user",
-                rqa.Nullable(ParserFor.make(User)),
+                rqa.Nullable(parsers.ParserFor.make(User)),
                 doc=(
                     "The user that gave the grade, only available when"
                     " `grade_origin` is `human`."
@@ -72,19 +72,20 @@ class GradeHistory:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["changed_at"] = to_dict(self.changed_at)
-        res["is_rubric"] = to_dict(self.is_rubric)
-        res["grade"] = to_dict(self.grade)
-        res["passed_back"] = to_dict(self.passed_back)
-        res["origin"] = to_dict(self.origin)
-        res["user"] = to_dict(self.user)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "changed_at": to_dict(self.changed_at),
+            "is_rubric": to_dict(self.is_rubric),
+            "grade": to_dict(self.grade),
+            "passed_back": to_dict(self.passed_back),
+            "origin": to_dict(self.origin),
+            "user": to_dict(self.user),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["GradeHistory"], d: Dict[str, Any]
+        cls: t.Type["GradeHistory"], d: t.Dict[str, t.Any]
     ) -> "GradeHistory":
         parsed = cls.data_parser.try_parse(d)
 
