@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .user_without_group import UserWithoutGroup
 
@@ -20,7 +20,7 @@ class Group:
     #: The id of this gropu
     id: "int"
     #: The members of this group.
-    members: "Sequence[UserWithoutGroup]"
+    members: "t.Sequence[UserWithoutGroup]"
     #: The name of this group.
     name: "str"
     #: The id of the group set that this group is connected to.
@@ -28,9 +28,9 @@ class Group:
     #: The datetime this group was created.
     created_at: "datetime.datetime"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -39,7 +39,7 @@ class Group:
             ),
             rqa.RequiredArgument(
                 "members",
-                rqa.List(ParserFor.make(UserWithoutGroup)),
+                rqa.List(parsers.ParserFor.make(UserWithoutGroup)),
                 doc="The members of this group.",
             ),
             rqa.RequiredArgument(
@@ -60,17 +60,18 @@ class Group:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["members"] = to_dict(self.members)
-        res["name"] = to_dict(self.name)
-        res["group_set_id"] = to_dict(self.group_set_id)
-        res["created_at"] = to_dict(self.created_at)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "members": to_dict(self.members),
+            "name": to_dict(self.name),
+            "group_set_id": to_dict(self.group_set_id),
+            "created_at": to_dict(self.created_at),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["Group"], d: Dict[str, Any]) -> "Group":
+    def from_dict(cls: t.Type["Group"], d: t.Dict[str, t.Any]) -> "Group":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
