@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
@@ -21,11 +21,11 @@ class GroupSet:
     #: The maximum size a group can be.
     maximum_size: "int"
     #: The ids of the assignments connected to this group set.
-    assignment_ids: "Sequence[int]"
+    assignment_ids: "t.Sequence[int]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -53,16 +53,19 @@ class GroupSet:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["minimum_size"] = to_dict(self.minimum_size)
-        res["maximum_size"] = to_dict(self.maximum_size)
-        res["assignment_ids"] = to_dict(self.assignment_ids)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "minimum_size": to_dict(self.minimum_size),
+            "maximum_size": to_dict(self.maximum_size),
+            "assignment_ids": to_dict(self.assignment_ids),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["GroupSet"], d: Dict[str, Any]) -> "GroupSet":
+    def from_dict(
+        cls: t.Type["GroupSet"], d: t.Dict[str, t.Any]
+    ) -> "GroupSet":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
