@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -12,14 +12,14 @@ from ..utils import to_dict
 
 @dataclass
 class ImportIntoCourseData:
-    """"""
+    """Input data required for the `Course::ImportInto` operation."""
 
     #: The id of the course from which you want to import.
     from_course_id: "int"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "from_course_id",
@@ -29,14 +29,15 @@ class ImportIntoCourseData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["from_course_id"] = to_dict(self.from_course_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "from_course_id": to_dict(self.from_course_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ImportIntoCourseData"], d: Dict[str, Any]
+        cls: t.Type["ImportIntoCourseData"], d: t.Dict[str, t.Any]
     ) -> "ImportIntoCourseData":
         parsed = cls.data_parser.try_parse(d)
 
