@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .task_result_state import TaskResultState
 
@@ -21,11 +21,11 @@ class Job:
     #: The state of the job.
     state: "TaskResultState"
     #: Possibly the result of the job.
-    result: "Optional[Any]"
+    result: "t.Optional[t.Any]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -48,15 +48,16 @@ class Job:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["state"] = to_dict(self.state)
-        res["result"] = to_dict(self.result)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "state": to_dict(self.state),
+            "result": to_dict(self.result),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["Job"], d: Dict[str, Any]) -> "Job":
+    def from_dict(cls: t.Type["Job"], d: t.Dict[str, t.Any]) -> "Job":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
