@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -12,16 +12,16 @@ from ..utils import to_dict
 
 @dataclass
 class JsonCreateTenant:
-    """"""
+    """ """
 
     #: The name of the new tenant
     name: "str"
     #: The abbreviated name of this tenant, useful for searching.
     abbreviated_name: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "name",
@@ -39,15 +39,16 @@ class JsonCreateTenant:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["name"] = to_dict(self.name)
-        res["abbreviated_name"] = to_dict(self.abbreviated_name)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "name": to_dict(self.name),
+            "abbreviated_name": to_dict(self.abbreviated_name),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["JsonCreateTenant"], d: Dict[str, Any]
+        cls: t.Type["JsonCreateTenant"], d: t.Dict[str, t.Any]
     ) -> "JsonCreateTenant":
         parsed = cls.data_parser.try_parse(d)
 
