@@ -2,21 +2,21 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .fixture_like import FixtureLike
 
 
 @dataclass
 class JsonPatchAutoTest:
-    """"""
+    """ """
 
     #: The new setup script (per student) of the auto test.
     setup_script: Maybe["str"] = Nothing
@@ -30,19 +30,19 @@ class JsonPatchAutoTest:
     grade_calculation: Maybe["str"] = Nothing
     #: Should results be visible for students before the assignment is set to
     #: "done"?
-    results_always_visible: Maybe["Optional[bool]"] = Nothing
+    results_always_visible: Maybe["t.Optional[bool]"] = Nothing
     #: If `true` we will use the teacher revision if available when running
     #: tests.
-    prefer_teacher_revision: Maybe["Optional[bool]"] = Nothing
+    prefer_teacher_revision: Maybe["t.Optional[bool]"] = Nothing
     #: A list of old fixtures you want to keep
-    fixtures: Maybe["Sequence[FixtureLike]"] = Nothing
+    fixtures: Maybe["t.Sequence[FixtureLike]"] = Nothing
     #: If true existing fixtures with the same name as one of the new fixtures
     #: are deleted and no renaming is performed.
     overwrite_duplicate_fixtures: "bool" = False
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.OptionalArgument(
                 "setup_script",
@@ -93,7 +93,7 @@ class JsonPatchAutoTest:
             ),
             rqa.OptionalArgument(
                 "fixtures",
-                rqa.List(ParserFor.make(FixtureLike)),
+                rqa.List(parsers.ParserFor.make(FixtureLike)),
                 doc="A list of old fixtures you want to keep",
             ),
             rqa.DefaultArgument(
@@ -110,6 +110,7 @@ class JsonPatchAutoTest:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.setup_script = maybe_from_nullable(self.setup_script)
         self.run_setup_script = maybe_from_nullable(self.run_setup_script)
         self.has_new_fixtures = maybe_from_nullable(self.has_new_fixtures)
@@ -123,8 +124,12 @@ class JsonPatchAutoTest:
         )
         self.fixtures = maybe_from_nullable(self.fixtures)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "overwrite_duplicate_fixtures": to_dict(
+                self.overwrite_duplicate_fixtures
+            ),
+        }
         if self.setup_script.is_just:
             res["setup_script"] = to_dict(self.setup_script.value)
         if self.run_setup_script.is_just:
@@ -145,14 +150,11 @@ class JsonPatchAutoTest:
             )
         if self.fixtures.is_just:
             res["fixtures"] = to_dict(self.fixtures.value)
-        res["overwrite_duplicate_fixtures"] = to_dict(
-            self.overwrite_duplicate_fixtures
-        )
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["JsonPatchAutoTest"], d: Dict[str, Any]
+        cls: t.Type["JsonPatchAutoTest"], d: t.Dict[str, t.Any]
     ) -> "JsonPatchAutoTest":
         parsed = cls.data_parser.try_parse(d)
 
