@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -42,9 +42,9 @@ class LegacyFeatures:
     #: See settings.
     rubrics: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "AUTOMATIC_LTI_ROLE",
@@ -109,27 +109,28 @@ class LegacyFeatures:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["AUTOMATIC_LTI_ROLE"] = to_dict(self.automatic_lti_role)
-        res["AUTO_TEST"] = to_dict(self.auto_test)
-        res["BLACKBOARD_ZIP_UPLOAD"] = to_dict(self.blackboard_zip_upload)
-        res["COURSE_REGISTER"] = to_dict(self.course_register)
-        res["EMAIL_STUDENTS"] = to_dict(self.email_students)
-        res["GROUPS"] = to_dict(self.groups)
-        res["INCREMENTAL_RUBRIC_SUBMISSION"] = to_dict(
-            self.incremental_rubric_submission
-        )
-        res["LTI"] = to_dict(self.lti)
-        res["PEER_FEEDBACK"] = to_dict(self.peer_feedback)
-        res["REGISTER"] = to_dict(self.register)
-        res["RENDER_HTML"] = to_dict(self.render_html)
-        res["RUBRICS"] = to_dict(self.rubrics)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "AUTOMATIC_LTI_ROLE": to_dict(self.automatic_lti_role),
+            "AUTO_TEST": to_dict(self.auto_test),
+            "BLACKBOARD_ZIP_UPLOAD": to_dict(self.blackboard_zip_upload),
+            "COURSE_REGISTER": to_dict(self.course_register),
+            "EMAIL_STUDENTS": to_dict(self.email_students),
+            "GROUPS": to_dict(self.groups),
+            "INCREMENTAL_RUBRIC_SUBMISSION": to_dict(
+                self.incremental_rubric_submission
+            ),
+            "LTI": to_dict(self.lti),
+            "PEER_FEEDBACK": to_dict(self.peer_feedback),
+            "REGISTER": to_dict(self.register),
+            "RENDER_HTML": to_dict(self.render_html),
+            "RUBRICS": to_dict(self.rubrics),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["LegacyFeatures"], d: Dict[str, Any]
+        cls: t.Type["LegacyFeatures"], d: t.Dict[str, t.Any]
     ) -> "LegacyFeatures":
         parsed = cls.data_parser.try_parse(d)
 
