@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -19,11 +19,11 @@ class LinterComment:
     #: The line the comment was placed on.
     line: "int"
     #: The message of the comment.
-    msg: "Optional[str]"
+    msg: "t.Optional[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "code",
@@ -46,16 +46,17 @@ class LinterComment:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["code"] = to_dict(self.code)
-        res["line"] = to_dict(self.line)
-        res["msg"] = to_dict(self.msg)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "code": to_dict(self.code),
+            "line": to_dict(self.line),
+            "msg": to_dict(self.msg),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["LinterComment"], d: Dict[str, Any]
+        cls: t.Type["LinterComment"], d: t.Dict[str, t.Any]
     ) -> "LinterComment":
         parsed = cls.data_parser.try_parse(d)
 
