@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
@@ -15,10 +15,12 @@ class LMSCapabilities:
     """This class defines the capabilities of an LMS connected using LTI 1.3.
 
     An important note about naming in this class: most of the attribute names
-    are not really intuitive. For example: *supporting* `set_deadline`1
-    classes, and 2) it describes what you can do inside CodeGrade with the LMS,
-    maybe it is in the future possible to sync back the deadline to the LMS,
-    and in this case the name `set_deadline` makes way more sense.
+    are not really intuitive. For example: *supporting* `set_deadline` means
+    that we probably don't get the deadline from the LMS. This has two main
+    reasons: 1) legacy: these strange names mirror the names used in our LTI
+    1.1 classes, and 2) it describes what you can do inside CodeGrade with the
+    LMS, maybe it is in the future possible to sync back the deadline to the
+    LMS, and in this case the name `set_deadline` makes way more sense.
     """
 
     #: The name of the LMS.
@@ -38,11 +40,16 @@ class LMSCapabilities:
     #: not be copied from the LMS?
     set_available_at: "bool"
     #: If there is a test student in the lms this its full name.
-    test_student_name: "Optional[str]"
-    #: The name of the iframe `postMessage` If set to `None` this LMS doesn't
-    #: have any post message that will allow us to send cookies (this is
-    #: currently the case for all LMSes except `Canvas`).
-    cookie_post_message: "Optional[str]"
+    test_student_name: "t.Optional[str]"
+    #: The name of the iframe `postMessage` we can send to the LMS to notify
+    #: that we want to set cookies in a full window.  This property is ugly,
+    #: and shows that these capabilities are not really a very good
+    #: abstraction: Only Canvas supports this, and it is not that likely that
+    #: other LMSes will support this in the exact same way as Canvas does now.
+    #: If set to `None` this LMS doesn't have any post message that will allow
+    #: us to send cookies (this is currently the case for all LMSes except
+    #: `Canvas`).
+    cookie_post_message: "t.Optional[str]"
     #: A list of replacements groups (or namespaces) supported by this LMS.
     #: Some LMSes support more replacement variables than others, however we
     #: don't want to send replacement variables to an LMS we know it will never
@@ -51,17 +58,17 @@ class LMSCapabilities:
     #: called `name'`, this variable will be included (parsed and returned as
     #: wanted config), if the `supported_custom_replacement_groups` contains
     #: `['$com']`. It will also be included if it contains `['$com',
-    #: 'custom_lms']` However, it will not be included if it only contains
-    #: `['$com.custom_lms']` or `['$com', 'other_lms']`.
-    supported_custom_replacement_groups: "Sequence[Sequence[str]]"
+    #: 'custom_lms']`. However, it will not be included if it only contains
+    #: `custom_lms']` or `['$com', 'other_lms']`.
+    supported_custom_replacement_groups: "t.Sequence[t.Sequence[str]]"
     #: Should we use the `id` in the url.  Some LMSes do not provide both the
-    #: `iss` and the `client_id` This means that finding the correct
-    #: `LTI1p3Provider` is not always correct (especially as the `iss` often
-    #: gets used multiple times). For some LMSes therefore it is a better idea
-    #: to simply include the id of the provider in the launch url, and verify
-    #: with the given information that the provider could theoretically be the
-    #: correct one (i.e. all given information matches with the information in
-    #: the LTI provider that belongs to the `id`).
+    #: `iss` and the `client_id` in all launches. This means that finding the
+    #: correct `LTI1p3Provider` is not always correct (especially as the `iss`
+    #: often gets used multiple times). For some LMSes therefore it is a better
+    #: idea to simply include the id of the provider in the launch url, and
+    #: verify with the given information that the provider could theoretically
+    #: be the correct one (i.e. all given information matches with the
+    #: information in the LTI provider that belongs to the `id`).
     use_id_in_urls: "bool"
     #: Does this LMS require actual deep linking, where the user inputs a name
     #: and deadline.
@@ -70,9 +77,9 @@ class LMSCapabilities:
     #: can finalize it.
     auth_audience_required: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "lms",
@@ -124,10 +131,16 @@ class LMSCapabilities:
                 "cookie_post_message",
                 rqa.Nullable(rqa.SimpleValue.str),
                 doc=(
-                    "The name of the iframe `postMessage` If set to `None`"
-                    " this LMS doesn't have any post message that will allow"
-                    " us to send cookies (this is currently the case for all"
-                    " LMSes except `Canvas`)."
+                    "The name of the iframe `postMessage` we can send to the"
+                    " LMS to notify that we want to set cookies in a full"
+                    " window.  This property is ugly, and shows that these"
+                    " capabilities are not really a very good abstraction:"
+                    " Only Canvas supports this, and it is not that likely"
+                    " that other LMSes will support this in the exact same way"
+                    " as Canvas does now. If set to `None` this LMS doesn't"
+                    " have any post message that will allow us to send cookies"
+                    " (this is currently the case for all LMSes except"
+                    " `Canvas`)."
                 ),
             ),
             rqa.RequiredArgument(
@@ -144,8 +157,8 @@ class LMSCapabilities:
                     " variable will be included (parsed and returned as wanted"
                     " config), if the `supported_custom_replacement_groups`"
                     " contains `['$com']`. It will also be included if it"
-                    " contains `['$com', 'custom_lms']` However, it will not"
-                    " be included if it only contains `['$com.custom_lms']` or"
+                    " contains `['$com', 'custom_lms']`. However, it will not"
+                    " be included if it only contains `custom_lms']` or"
                     " `['$com', 'other_lms']`."
                 ),
             ),
@@ -154,15 +167,16 @@ class LMSCapabilities:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Should we use the `id` in the url.  Some LMSes do not"
-                    " provide both the `iss` and the `client_id` This means"
-                    " that finding the correct `LTI1p3Provider` is not always"
-                    " correct (especially as the `iss` often gets used"
-                    " multiple times). For some LMSes therefore it is a better"
-                    " idea to simply include the id of the provider in the"
-                    " launch url, and verify with the given information that"
-                    " the provider could theoretically be the correct one"
-                    " (i.e. all given information matches with the information"
-                    " in the LTI provider that belongs to the `id`)."
+                    " provide both the `iss` and the `client_id` in all"
+                    " launches. This means that finding the correct"
+                    " `LTI1p3Provider` is not always correct (especially as"
+                    " the `iss` often gets used multiple times). For some"
+                    " LMSes therefore it is a better idea to simply include"
+                    " the id of the provider in the launch url, and verify"
+                    " with the given information that the provider could"
+                    " theoretically be the correct one (i.e. all given"
+                    " information matches with the information in the LTI"
+                    " provider that belongs to the `id`)."
                 ),
             ),
             rqa.RequiredArgument(
@@ -184,28 +198,29 @@ class LMSCapabilities:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["lms"] = to_dict(self.lms)
-        res["set_deadline"] = to_dict(self.set_deadline)
-        res["set_lock_date"] = to_dict(self.set_lock_date)
-        res["set_state"] = to_dict(self.set_state)
-        res["set_available_at"] = to_dict(self.set_available_at)
-        res["test_student_name"] = to_dict(self.test_student_name)
-        res["cookie_post_message"] = to_dict(self.cookie_post_message)
-        res["supported_custom_replacement_groups"] = to_dict(
-            self.supported_custom_replacement_groups
-        )
-        res["use_id_in_urls"] = to_dict(self.use_id_in_urls)
-        res["actual_deep_linking_required"] = to_dict(
-            self.actual_deep_linking_required
-        )
-        res["auth_audience_required"] = to_dict(self.auth_audience_required)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "lms": to_dict(self.lms),
+            "set_deadline": to_dict(self.set_deadline),
+            "set_lock_date": to_dict(self.set_lock_date),
+            "set_state": to_dict(self.set_state),
+            "set_available_at": to_dict(self.set_available_at),
+            "test_student_name": to_dict(self.test_student_name),
+            "cookie_post_message": to_dict(self.cookie_post_message),
+            "supported_custom_replacement_groups": to_dict(
+                self.supported_custom_replacement_groups
+            ),
+            "use_id_in_urls": to_dict(self.use_id_in_urls),
+            "actual_deep_linking_required": to_dict(
+                self.actual_deep_linking_required
+            ),
+            "auth_audience_required": to_dict(self.auth_audience_required),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["LMSCapabilities"], d: Dict[str, Any]
+        cls: t.Type["LMSCapabilities"], d: t.Dict[str, t.Any]
     ) -> "LMSCapabilities":
         parsed = cls.data_parser.try_parse(d)
 
