@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, Any, ClassVar, Dict, Optional, Type, Union
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -25,9 +25,9 @@ class LoginUserData_1:
     #: starting with release Nobel.2
     tenant_id: Maybe["str"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "username",
@@ -51,19 +51,21 @@ class LoginUserData_1:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.tenant_id = maybe_from_nullable(self.tenant_id)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["username"] = to_dict(self.username)
-        res["password"] = to_dict(self.password)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "username": to_dict(self.username),
+            "password": to_dict(self.password),
+        }
         if self.tenant_id.is_just:
             res["tenant_id"] = to_dict(self.tenant_id.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["LoginUserData_1"], d: Dict[str, Any]
+        cls: t.Type["LoginUserData_1"], d: t.Dict[str, t.Any]
     ) -> "LoginUserData_1":
         parsed = cls.data_parser.try_parse(d)
 
@@ -88,9 +90,9 @@ class LoginUserData_1_2:
     #: starting with release Nobel.2
     tenant_id: Maybe["str"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "username",
@@ -114,19 +116,21 @@ class LoginUserData_1_2:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.tenant_id = maybe_from_nullable(self.tenant_id)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["username"] = to_dict(self.username)
-        res["own_password"] = to_dict(self.own_password)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "username": to_dict(self.username),
+            "own_password": to_dict(self.own_password),
+        }
         if self.tenant_id.is_just:
             res["tenant_id"] = to_dict(self.tenant_id.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["LoginUserData_1_2"], d: Dict[str, Any]
+        cls: t.Type["LoginUserData_1_2"], d: t.Dict[str, t.Any]
     ) -> "LoginUserData_1_2":
         parsed = cls.data_parser.try_parse(d)
 
@@ -139,7 +143,7 @@ class LoginUserData_1_2:
         return res
 
 
-LoginUserData = Union[
+LoginUserData = t.Union[
     LoginUserData_1,
     LoginUserData_1_2,
 ]
