@@ -2,11 +2,10 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Mapping, Optional, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
 from ..utils import to_dict
 from .base_lti1p3_provider import BaseLTI1p3Provider
@@ -17,31 +16,31 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
     """A non finalized LTI 1.3 provider as JSON."""
 
     #: This is a non finalized provider.
-    finalized: "Literal[False]"
+    finalized: "t.Literal[False]"
     #: The auth login url, if already configured.
-    auth_login_url: "Optional[str]"
+    auth_login_url: "t.Optional[str]"
     #: The auth token url, if already configured.
-    auth_token_url: "Optional[str]"
+    auth_token_url: "t.Optional[str]"
     #: The client id, if already configured.
-    client_id: "Optional[str]"
+    client_id: "t.Optional[str]"
     #: The url where we can download the keyset of the LMS, if already
     #: configured.
-    key_set_url: "Optional[str]"
+    key_set_url: "t.Optional[str]"
     #: The auth audience, if already configured.
-    auth_audience: "Optional[str]"
+    auth_audience: "t.Optional[str]"
     #: Custom fields that the LMS should provide when launching.
-    custom_fields: "Mapping[str, str]"
+    custom_fields: "t.Mapping[str, str]"
     #: The public JWK for this provider, this should be provided to the LMS.
-    public_jwk: "Mapping[str, str]"
+    public_jwk: "t.Mapping[str, str]"
     #: The public key for this provider, this should be provided to the LMS.
     public_key: "str"
     #: If you have the permission to edit this provider this will be a key with
     #: which you can do that.
-    edit_secret: "Optional[str]"
+    edit_secret: "t.Optional[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseLTI1p3Provider.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -113,31 +112,33 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["finalized"] = to_dict(self.finalized)
-        res["auth_login_url"] = to_dict(self.auth_login_url)
-        res["auth_token_url"] = to_dict(self.auth_token_url)
-        res["client_id"] = to_dict(self.client_id)
-        res["key_set_url"] = to_dict(self.key_set_url)
-        res["auth_audience"] = to_dict(self.auth_audience)
-        res["custom_fields"] = to_dict(self.custom_fields)
-        res["public_jwk"] = to_dict(self.public_jwk)
-        res["public_key"] = to_dict(self.public_key)
-        res["edit_secret"] = to_dict(self.edit_secret)
-        res["lms"] = to_dict(self.lms)
-        res["capabilities"] = to_dict(self.capabilities)
-        res["version"] = to_dict(self.version)
-        res["iss"] = to_dict(self.iss)
-        res["id"] = to_dict(self.id)
-        res["created_at"] = to_dict(self.created_at)
-        res["intended_use"] = to_dict(self.intended_use)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "finalized": to_dict(self.finalized),
+            "auth_login_url": to_dict(self.auth_login_url),
+            "auth_token_url": to_dict(self.auth_token_url),
+            "client_id": to_dict(self.client_id),
+            "key_set_url": to_dict(self.key_set_url),
+            "auth_audience": to_dict(self.auth_audience),
+            "custom_fields": to_dict(self.custom_fields),
+            "public_jwk": to_dict(self.public_jwk),
+            "public_key": to_dict(self.public_key),
+            "edit_secret": to_dict(self.edit_secret),
+            "lms": to_dict(self.lms),
+            "capabilities": to_dict(self.capabilities),
+            "version": to_dict(self.version),
+            "iss": to_dict(self.iss),
+            "presentation": to_dict(self.presentation),
+            "id": to_dict(self.id),
+            "created_at": to_dict(self.created_at),
+            "intended_use": to_dict(self.intended_use),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["NonFinalizedLTI1p3Provider"], d: Dict[str, Any]
+        cls: t.Type["NonFinalizedLTI1p3Provider"], d: t.Dict[str, t.Any]
     ) -> "NonFinalizedLTI1p3Provider":
         parsed = cls.data_parser.try_parse(d)
 
@@ -156,6 +157,7 @@ class NonFinalizedLTI1p3Provider(BaseLTI1p3Provider):
             capabilities=parsed.capabilities,
             version=parsed.version,
             iss=parsed.iss,
+            presentation=parsed.presentation,
             id=parsed.id,
             created_at=parsed.created_at,
             intended_use=parsed.intended_use,
