@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .email_notification_types import EmailNotificationTypes
 from .notification_setting_option import NotificationSettingOption
@@ -18,17 +18,17 @@ class NotificationSetting:
     """The notification preferences of a user."""
 
     #: The possible options to set.
-    options: "Sequence[NotificationSettingOption]"
+    options: "t.Sequence[NotificationSettingOption]"
     #: The possible values for each option.
-    possible_values: "Sequence[EmailNotificationTypes]"
+    possible_values: "t.Sequence[EmailNotificationTypes]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "options",
-                rqa.List(ParserFor.make(NotificationSettingOption)),
+                rqa.List(parsers.ParserFor.make(NotificationSettingOption)),
                 doc="The possible options to set.",
             ),
             rqa.RequiredArgument(
@@ -39,15 +39,16 @@ class NotificationSetting:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["options"] = to_dict(self.options)
-        res["possible_values"] = to_dict(self.possible_values)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "options": to_dict(self.options),
+            "possible_values": to_dict(self.possible_values),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["NotificationSetting"], d: Dict[str, Any]
+        cls: t.Type["NotificationSetting"], d: t.Dict[str, t.Any]
     ) -> "NotificationSetting":
         parsed = cls.data_parser.try_parse(d)
 
