@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .email_notification_types import EmailNotificationTypes
 from .notification_reasons import NotificationReasons
@@ -24,9 +24,9 @@ class NotificationSettingOption:
     #: The current value for this notification reason.
     value: "EmailNotificationTypes"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "reason",
@@ -46,16 +46,17 @@ class NotificationSettingOption:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["reason"] = to_dict(self.reason)
-        res["explanation"] = to_dict(self.explanation)
-        res["value"] = to_dict(self.value)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "reason": to_dict(self.reason),
+            "explanation": to_dict(self.explanation),
+            "value": to_dict(self.value),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["NotificationSettingOption"], d: Dict[str, Any]
+        cls: t.Type["NotificationSettingOption"], d: t.Dict[str, t.Any]
     ) -> "NotificationSettingOption":
         parsed = cls.data_parser.try_parse(d)
 
