@@ -2,11 +2,10 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
 from ..utils import to_dict
 
@@ -16,20 +15,20 @@ class OptionsInputData:
     """The input data for a single option for the SubmissionValidator."""
 
     #: What option is this.
-    key: "Literal['delete_empty_directories', 'remove_leading_directories', 'allow_override']"
+    key: "t.Literal['allow_override', 'delete_empty_directories', 'remove_leading_directories']"
     #: Is this option enabled.
     value: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "key",
                 rqa.StringEnum(
+                    "allow_override",
                     "delete_empty_directories",
                     "remove_leading_directories",
-                    "allow_override",
                 ),
                 doc="What option is this.",
             ),
@@ -41,15 +40,16 @@ class OptionsInputData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["key"] = to_dict(self.key)
-        res["value"] = to_dict(self.value)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "key": to_dict(self.key),
+            "value": to_dict(self.value),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["OptionsInputData"], d: Dict[str, Any]
+        cls: t.Type["OptionsInputData"], d: t.Dict[str, t.Any]
     ) -> "OptionsInputData":
         parsed = cls.data_parser.try_parse(d)
 
