@@ -3,15 +3,14 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type, Union
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
-from typing_extensions import Literal
 
-from ..parsers import ParserFor, make_union
+from .. import parsers
 from ..utils import to_dict
 from .assignment_anonymization_algo import AssignmentAnonymizationAlgo
 from .assignment_done_type import AssignmentDoneType
@@ -22,7 +21,7 @@ from .submission_validator_input_data import SubmissionValidatorInputData
 
 @dataclass
 class PatchAssignmentData:
-    """"""
+    """Input data required for the `Assignment::Patch` operation."""
 
     #: The new state of the assignment
     state: Maybe["AssignmentStateEnum"] = Nothing
@@ -31,15 +30,15 @@ class PatchAssignmentData:
     #: The new deadline of the assignment
     deadline: Maybe["datetime.datetime"] = Nothing
     #: The new lock date of the assignment
-    lock_date: Maybe["Optional[datetime.datetime]"] = Nothing
+    lock_date: Maybe["t.Optional[datetime.datetime]"] = Nothing
     #: The maximum possible grade for this assignment. You can reset this by
     #: passing `null` as value
-    max_grade: Maybe["Optional[int]"] = Nothing
+    max_grade: Maybe["t.Optional[float]"] = Nothing
     #: The group set id for this assignment. Set to `null` to make this
     #: assignment not a group assignment
-    group_set_id: Maybe["Optional[int]"] = Nothing
+    group_set_id: Maybe["t.Optional[int]"] = Nothing
     #: The time the assignment should become available
-    available_at: Maybe["Optional[datetime.datetime]"] = Nothing
+    available_at: Maybe["t.Optional[datetime.datetime]"] = Nothing
     #: Should we send login links to students before the assignment opens. This
     #: is only available for assignments with 'kind' equal to 'exam'
     send_login_links: Maybe["bool"] = Nothing
@@ -50,7 +49,7 @@ class PatchAssignmentData:
     #: Should students be allowed to make submissions using git webhooks
     webhook_upload_enabled: Maybe["bool"] = Nothing
     #: The maximum amount of submissions a user may create.
-    max_submissions: Maybe["Optional[int]"] = Nothing
+    max_submissions: Maybe["t.Optional[int]"] = Nothing
     #: The amount of time in seconds there should be between
     #: `amount_in_cool_off_period + 1` submissions.
     cool_off_period: Maybe["float"] = Nothing
@@ -58,27 +57,33 @@ class PatchAssignmentData:
     #: `cool_off_period` seconds. This should be higher than or equal to 1.
     amount_in_cool_off_period: Maybe["int"] = Nothing
     #: The ignore file to use
-    ignore: Maybe["Union[SubmissionValidatorInputData, str]"] = Nothing
+    ignore: Maybe["t.Union[SubmissionValidatorInputData, str]"] = Nothing
     #: The ignore version to use, defaults to "IgnoreFilterManager".
     ignore_version: Maybe[
-        "Literal['EmptySubmissionFilter', 'IgnoreFilterManager',"
+        "t.Literal['EmptySubmissionFilter', 'IgnoreFilterManager',"
         " 'SubmissionValidator']"
     ] = Nothing
     #: How to determine grading is done for this assignment, this value is not
     #: used when `reminder_time` is `null`.
-    done_type: Maybe["AssignmentDoneType"] = Nothing
+    done_type: Maybe["t.Optional[AssignmentDoneType]"] = Nothing
     #: At what time should we send the reminder emails to the graders. This
     #: value is not used wehn `done_type` is `null`.
-    reminder_time: Maybe["Optional[datetime.datetime]"] = Nothing
+    reminder_time: Maybe["t.Optional[datetime.datetime]"] = Nothing
     #: A list of emails that should receive an email when grading is done. This
     #: value has no effect when `done_type` is set to `null`.
-    done_email: Maybe["Optional[str]"] = Nothing
+    done_email: Maybe["t.Optional[str]"] = Nothing
     #: Should anonymized grading be enabled for this assignment.
-    anonymized_grading: Maybe["AssignmentAnonymizationAlgo"] = Nothing
+    anonymized_grading: Maybe[
+        "t.Optional[AssignmentAnonymizationAlgo]"
+    ] = Nothing
+    #: The file we should load first in an asignment
+    file_to_load_first: Maybe["t.Optional[str]"] = Nothing
+    #: Grading settings of this assignment.
+    grading: Maybe["t.Mapping[str, t.Any]"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.OptionalArgument(
                 "state",
@@ -102,7 +107,7 @@ class PatchAssignmentData:
             ),
             rqa.OptionalArgument(
                 "max_grade",
-                rqa.Nullable(rqa.SimpleValue.int),
+                rqa.Nullable(rqa.SimpleValue.float),
                 doc=(
                     "The maximum possible grade for this assignment. You can"
                     " reset this by passing `null` as value"
@@ -175,8 +180,8 @@ class PatchAssignmentData:
             ),
             rqa.OptionalArgument(
                 "ignore",
-                make_union(
-                    ParserFor.make(SubmissionValidatorInputData),
+                parsers.make_union(
+                    parsers.ParserFor.make(SubmissionValidatorInputData),
                     rqa.SimpleValue.str,
                 ),
                 doc="The ignore file to use",
@@ -195,7 +200,7 @@ class PatchAssignmentData:
             ),
             rqa.OptionalArgument(
                 "done_type",
-                rqa.EnumValue(AssignmentDoneType),
+                rqa.Nullable(rqa.EnumValue(AssignmentDoneType)),
                 doc=(
                     "How to determine grading is done for this assignment,"
                     " this value is not used when `reminder_time` is `null`."
@@ -221,15 +226,26 @@ class PatchAssignmentData:
             ),
             rqa.OptionalArgument(
                 "anonymized_grading",
-                rqa.EnumValue(AssignmentAnonymizationAlgo),
+                rqa.Nullable(rqa.EnumValue(AssignmentAnonymizationAlgo)),
                 doc=(
                     "Should anonymized grading be enabled for this assignment."
                 ),
             ),
+            rqa.OptionalArgument(
+                "file_to_load_first",
+                rqa.Nullable(rqa.SimpleValue.str),
+                doc="The file we should load first in an asignment",
+            ),
+            rqa.OptionalArgument(
+                "grading",
+                rqa.LookupMapping(rqa.AnyValue),
+                doc="Grading settings of this assignment.",
+            ),
         ).use_readable_describe(True)
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.state = maybe_from_nullable(self.state)
         self.name = maybe_from_nullable(self.name)
         self.deadline = maybe_from_nullable(self.deadline)
@@ -256,9 +272,11 @@ class PatchAssignmentData:
         self.reminder_time = maybe_from_nullable(self.reminder_time)
         self.done_email = maybe_from_nullable(self.done_email)
         self.anonymized_grading = maybe_from_nullable(self.anonymized_grading)
+        self.file_to_load_first = maybe_from_nullable(self.file_to_load_first)
+        self.grading = maybe_from_nullable(self.grading)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {}
         if self.state.is_just:
             res["state"] = to_dict(self.state.value)
         if self.name.is_just:
@@ -305,11 +323,15 @@ class PatchAssignmentData:
             res["done_email"] = to_dict(self.done_email.value)
         if self.anonymized_grading.is_just:
             res["anonymized_grading"] = to_dict(self.anonymized_grading.value)
+        if self.file_to_load_first.is_just:
+            res["file_to_load_first"] = to_dict(self.file_to_load_first.value)
+        if self.grading.is_just:
+            res["grading"] = to_dict(self.grading.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchAssignmentData"], d: Dict[str, Any]
+        cls: t.Type["PatchAssignmentData"], d: t.Dict[str, t.Any]
     ) -> "PatchAssignmentData":
         parsed = cls.data_parser.try_parse(d)
 
@@ -334,6 +356,8 @@ class PatchAssignmentData:
             reminder_time=parsed.reminder_time,
             done_email=parsed.done_email,
             anonymized_grading=parsed.anonymized_grading,
+            file_to_load_first=parsed.file_to_load_first,
+            grading=parsed.grading,
         )
         res.raw_data = d
         return res
