@@ -2,14 +2,14 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .json_patch_auto_test import JsonPatchAutoTest
 from .types import File
@@ -17,18 +17,18 @@ from .types import File
 
 @dataclass
 class PatchAutoTestData:
-    """"""
+    """Input data required for the `AutoTest::Patch` operation."""
 
     json: "JsonPatchAutoTest"
-    fixture: Maybe["Sequence[File]"] = Nothing
+    fixture: Maybe["t.Sequence[File]"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "json",
-                ParserFor.make(JsonPatchAutoTest),
+                parsers.ParserFor.make(JsonPatchAutoTest),
                 doc="",
             ),
             rqa.OptionalArgument(
@@ -40,18 +40,20 @@ class PatchAutoTestData:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.fixture = maybe_from_nullable(self.fixture)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["json"] = to_dict(self.json)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "json": to_dict(self.json),
+        }
         if self.fixture.is_just:
             res["fixture"] = to_dict(self.fixture.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchAutoTestData"], d: Dict[str, Any]
+        cls: t.Type["PatchAutoTestData"], d: t.Dict[str, t.Any]
     ) -> "PatchAutoTestData":
         parsed = cls.data_parser.try_parse(d)
 
