@@ -2,21 +2,21 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
 from cg_maybe.utils import maybe_from_nullable
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .course_state import CourseState
 
 
 @dataclass
 class PatchCourseData:
-    """"""
+    """Input data required for the `Course::Patch` operation."""
 
     #: The new name of the course
     name: Maybe["str"] = Nothing
@@ -24,9 +24,9 @@ class PatchCourseData:
     #: course to 'deleted'
     state: Maybe["CourseState"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.OptionalArgument(
                 "name",
@@ -45,11 +45,12 @@ class PatchCourseData:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.name = maybe_from_nullable(self.name)
         self.state = maybe_from_nullable(self.state)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {}
         if self.name.is_just:
             res["name"] = to_dict(self.name.value)
         if self.state.is_just:
@@ -58,7 +59,7 @@ class PatchCourseData:
 
     @classmethod
     def from_dict(
-        cls: Type["PatchCourseData"], d: Dict[str, Any]
+        cls: t.Type["PatchCourseData"], d: t.Dict[str, t.Any]
     ) -> "PatchCourseData":
         parsed = cls.data_parser.try_parse(d)
 
