@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .email_notification_types import EmailNotificationTypes
 from .notification_reasons import NotificationReasons
@@ -15,16 +15,18 @@ from .notification_reasons import NotificationReasons
 
 @dataclass
 class PatchNotificationSettingUserSettingData:
-    """"""
+    """Input data required for the `User Setting::PatchNotificationSetting`
+    operation.
+    """
 
     #: For what type notification do you want to change the settings.
     reason: "NotificationReasons"
     #: The new value of the notification setting.
     value: "EmailNotificationTypes"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "reason",
@@ -42,15 +44,17 @@ class PatchNotificationSettingUserSettingData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["reason"] = to_dict(self.reason)
-        res["value"] = to_dict(self.value)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "reason": to_dict(self.reason),
+            "value": to_dict(self.value),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchNotificationSettingUserSettingData"], d: Dict[str, Any]
+        cls: t.Type["PatchNotificationSettingUserSettingData"],
+        d: t.Dict[str, t.Any],
     ) -> "PatchNotificationSettingUserSettingData":
         parsed = cls.data_parser.try_parse(d)
 
