@@ -2,20 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    ClassVar,
-    Dict,
-    Optional,
-    Sequence,
-    Type,
-    Union,
-)
 
 import cg_request_args as rqa
 
+from .. import parsers
 from ..parsers import ParserFor, make_union
 from ..utils import to_dict
 from ._submission_rubric_item_data_parser import (
@@ -25,14 +17,14 @@ from ._submission_rubric_item_data_parser import (
 
 @dataclass
 class PatchRubricResultSubmissionData_1:
-    """"""
+    """ """
 
     #: An array of rubric ids to select. This format is deprecated.
-    items: "Sequence[int]"
+    items: "t.Sequence[int]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "items",
@@ -45,14 +37,15 @@ class PatchRubricResultSubmissionData_1:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["items"] = to_dict(self.items)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "items": to_dict(self.items),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchRubricResultSubmissionData_1"], d: Dict[str, Any]
+        cls: t.Type["PatchRubricResultSubmissionData_1"], d: t.Dict[str, t.Any]
     ) -> "PatchRubricResultSubmissionData_1":
         parsed = cls.data_parser.try_parse(d)
 
@@ -65,31 +58,35 @@ class PatchRubricResultSubmissionData_1:
 
 @dataclass
 class PatchRubricResultSubmissionData_1_2:
-    """"""
+    """ """
 
     #: An array of rubric items to select.
-    items: "Sequence[_SubmissionRubricItemDataParser]"
+    items: "t.Sequence[_SubmissionRubricItemDataParser]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "items",
-                rqa.List(ParserFor.make(_SubmissionRubricItemDataParser)),
+                rqa.List(
+                    parsers.ParserFor.make(_SubmissionRubricItemDataParser)
+                ),
                 doc="An array of rubric items to select.",
             ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["items"] = to_dict(self.items)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "items": to_dict(self.items),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchRubricResultSubmissionData_1_2"], d: Dict[str, Any]
+        cls: t.Type["PatchRubricResultSubmissionData_1_2"],
+        d: t.Dict[str, t.Any],
     ) -> "PatchRubricResultSubmissionData_1_2":
         parsed = cls.data_parser.try_parse(d)
 
@@ -100,7 +97,7 @@ class PatchRubricResultSubmissionData_1_2:
         return res
 
 
-PatchRubricResultSubmissionData = Union[
+PatchRubricResultSubmissionData = t.Union[
     PatchRubricResultSubmissionData_1,
     PatchRubricResultSubmissionData_1_2,
 ]
