@@ -2,26 +2,26 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor, make_union
+from .. import parsers
 from ..utils import to_dict
 from .site_setting_input import SiteSettingInput, SiteSettingInputParser
 
 
 @dataclass
 class PatchSiteSettingsData:
-    """"""
+    """Input data required for the `Site Settings::Patch` operation."""
 
     #: The items you want to update
-    updates: "Sequence[SiteSettingInput]"
+    updates: "t.Sequence[SiteSettingInput]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "updates",
@@ -31,14 +31,15 @@ class PatchSiteSettingsData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["updates"] = to_dict(self.updates)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "updates": to_dict(self.updates),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchSiteSettingsData"], d: Dict[str, Any]
+        cls: t.Type["PatchSiteSettingsData"], d: t.Dict[str, t.Any]
     ) -> "PatchSiteSettingsData":
         parsed = cls.data_parser.try_parse(d)
 
