@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -12,16 +12,16 @@ from ..utils import to_dict
 
 @dataclass
 class PatchSnippetCourseData:
-    """"""
+    """Input data required for the `Course::PatchSnippet` operation."""
 
     #: The new key of the snippet
     key: "str"
     #: The new value of the snippet
     value: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "key",
@@ -36,15 +36,16 @@ class PatchSnippetCourseData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["key"] = to_dict(self.key)
-        res["value"] = to_dict(self.value)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "key": to_dict(self.key),
+            "value": to_dict(self.value),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchSnippetCourseData"], d: Dict[str, Any]
+        cls: t.Type["PatchSnippetCourseData"], d: t.Dict[str, t.Any]
     ) -> "PatchSnippetCourseData":
         parsed = cls.data_parser.try_parse(d)
 
