@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -14,16 +14,16 @@ from ..utils import to_dict
 
 @dataclass
 class PatchSubmissionData:
-    """"""
+    """Input data required for the `Submission::Patch` operation."""
 
     #: General feedback on the submission.
-    feedback: Maybe["Optional[str]"] = Nothing
+    feedback: Maybe["t.Optional[str]"] = Nothing
     #: The grade of the submission.
-    grade: Maybe["Optional[float]"] = Nothing
+    grade: Maybe["t.Optional[float]"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.OptionalArgument(
                 "feedback",
@@ -39,11 +39,12 @@ class PatchSubmissionData:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.feedback = maybe_from_nullable(self.feedback)
         self.grade = maybe_from_nullable(self.grade)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {}
         if self.feedback.is_just:
             res["feedback"] = to_dict(self.feedback.value)
         if self.grade.is_just:
@@ -52,7 +53,7 @@ class PatchSubmissionData:
 
     @classmethod
     def from_dict(
-        cls: Type["PatchSubmissionData"], d: Dict[str, Any]
+        cls: t.Type["PatchSubmissionData"], d: t.Dict[str, t.Any]
     ) -> "PatchSubmissionData":
         parsed = cls.data_parser.try_parse(d)
 
