@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -14,7 +14,7 @@ from ..utils import to_dict
 
 @dataclass
 class PatchTenantData:
-    """"""
+    """Input data required for the `Tenant::Patch` operation."""
 
     #: The new name of the tenant
     name: Maybe["str"] = Nothing
@@ -23,9 +23,9 @@ class PatchTenantData:
     #: The new order category of the tenant
     order_category: Maybe["int"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.OptionalArgument(
                 "name",
@@ -46,12 +46,13 @@ class PatchTenantData:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.name = maybe_from_nullable(self.name)
         self.abbreviated_name = maybe_from_nullable(self.abbreviated_name)
         self.order_category = maybe_from_nullable(self.order_category)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {}
         if self.name.is_just:
             res["name"] = to_dict(self.name.value)
         if self.abbreviated_name.is_just:
@@ -62,7 +63,7 @@ class PatchTenantData:
 
     @classmethod
     def from_dict(
-        cls: Type["PatchTenantData"], d: Dict[str, Any]
+        cls: t.Type["PatchTenantData"], d: t.Dict[str, t.Any]
     ) -> "PatchTenantData":
         parsed = cls.data_parser.try_parse(d)
 
