@@ -2,28 +2,28 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .ui_preference_name import UIPreferenceName
 
 
 @dataclass
 class PatchUiPreferenceUserSettingData:
-    """"""
+    """Input data required for the `User Setting::PatchUiPreference` operation."""
 
     #: The ui preference you want to change.
     name: "UIPreferenceName"
     #: The new value of the preference.
     value: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "name",
@@ -38,15 +38,16 @@ class PatchUiPreferenceUserSettingData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["name"] = to_dict(self.name)
-        res["value"] = to_dict(self.value)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "name": to_dict(self.name),
+            "value": to_dict(self.value),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PatchUiPreferenceUserSettingData"], d: Dict[str, Any]
+        cls: t.Type["PatchUiPreferenceUserSettingData"], d: t.Dict[str, t.Any]
     ) -> "PatchUiPreferenceUserSettingData":
         parsed = cls.data_parser.try_parse(d)
 
