@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -23,9 +23,9 @@ class PlagiarismRunPlagiarismCourseAsJSON:
     #: Is this is a virtual course?
     virtual: "bool"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -45,16 +45,18 @@ class PlagiarismRunPlagiarismCourseAsJSON:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["name"] = to_dict(self.name)
-        res["virtual"] = to_dict(self.virtual)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "name": to_dict(self.name),
+            "virtual": to_dict(self.virtual),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["PlagiarismRunPlagiarismCourseAsJSON"], d: Dict[str, Any]
+        cls: t.Type["PlagiarismRunPlagiarismCourseAsJSON"],
+        d: t.Dict[str, t.Any],
     ) -> "PlagiarismRunPlagiarismCourseAsJSON":
         parsed = cls.data_parser.try_parse(d)
 
