@@ -3,8 +3,8 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -15,7 +15,7 @@ from ..utils import to_dict
 
 @dataclass
 class PutEnrollLinkCourseData:
-    """"""
+    """Input data required for the `Course::PutEnrollLink` operation."""
 
     #: The id of the role that users should get when enrolling with this link.
     role_id: "int"
@@ -27,9 +27,9 @@ class PutEnrollLinkCourseData:
     #: For registration to actually work this feature should be enabled.
     allow_register: Maybe["bool"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "role_id",
@@ -62,13 +62,15 @@ class PutEnrollLinkCourseData:
     )
 
     def __post_init__(self) -> None:
+        getattr(super(), "__post_init__", lambda: None)()
         self.id = maybe_from_nullable(self.id)
         self.allow_register = maybe_from_nullable(self.allow_register)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["role_id"] = to_dict(self.role_id)
-        res["expiration_date"] = to_dict(self.expiration_date)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "role_id": to_dict(self.role_id),
+            "expiration_date": to_dict(self.expiration_date),
+        }
         if self.id.is_just:
             res["id"] = to_dict(self.id.value)
         if self.allow_register.is_just:
@@ -77,7 +79,7 @@ class PutEnrollLinkCourseData:
 
     @classmethod
     def from_dict(
-        cls: Type["PutEnrollLinkCourseData"], d: Dict[str, Any]
+        cls: t.Type["PutEnrollLinkCourseData"], d: t.Dict[str, t.Any]
     ) -> "PutEnrollLinkCourseData":
         parsed = cls.data_parser.try_parse(d)
 
