@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -12,7 +12,7 @@ from ..utils import to_dict
 
 @dataclass
 class RegisterUserData:
-    """"""
+    """Input data required for the `User::Register` operation."""
 
     #: Username to register.
     username: "str"
@@ -25,9 +25,9 @@ class RegisterUserData:
     #: Id of the tenant to register the new user with.
     tenant_id: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "username",
@@ -57,18 +57,19 @@ class RegisterUserData:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["username"] = to_dict(self.username)
-        res["password"] = to_dict(self.password)
-        res["email"] = to_dict(self.email)
-        res["name"] = to_dict(self.name)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "username": to_dict(self.username),
+            "password": to_dict(self.password),
+            "email": to_dict(self.email),
+            "name": to_dict(self.name),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["RegisterUserData"], d: Dict[str, Any]
+        cls: t.Type["RegisterUserData"], d: t.Dict[str, t.Any]
     ) -> "RegisterUserData":
         parsed = cls.data_parser.try_parse(d)
 
