@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .extended_job import ExtendedJob
 
@@ -17,31 +17,31 @@ class ResultDataGetTaskResultGetAll:
     """The history of jobs for an instance."""
 
     #: Jobs that have not yet started
-    not_started: "Sequence[ExtendedJob]"
+    not_started: "t.Sequence[ExtendedJob]"
     #: Jobs that are currently running.
-    active: "Sequence[ExtendedJob]"
+    active: "t.Sequence[ExtendedJob]"
     #: A part of the jobs that have finished.
-    finished: "Sequence[ExtendedJob]"
+    finished: "t.Sequence[ExtendedJob]"
     #: The total amount of jobs that have finished.
     total_finished: "int"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "not_started",
-                rqa.List(ParserFor.make(ExtendedJob)),
+                rqa.List(parsers.ParserFor.make(ExtendedJob)),
                 doc="Jobs that have not yet started",
             ),
             rqa.RequiredArgument(
                 "active",
-                rqa.List(ParserFor.make(ExtendedJob)),
+                rqa.List(parsers.ParserFor.make(ExtendedJob)),
                 doc="Jobs that are currently running.",
             ),
             rqa.RequiredArgument(
                 "finished",
-                rqa.List(ParserFor.make(ExtendedJob)),
+                rqa.List(parsers.ParserFor.make(ExtendedJob)),
                 doc="A part of the jobs that have finished.",
             ),
             rqa.RequiredArgument(
@@ -52,17 +52,18 @@ class ResultDataGetTaskResultGetAll:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["not_started"] = to_dict(self.not_started)
-        res["active"] = to_dict(self.active)
-        res["finished"] = to_dict(self.finished)
-        res["total_finished"] = to_dict(self.total_finished)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "not_started": to_dict(self.not_started),
+            "active": to_dict(self.active),
+            "finished": to_dict(self.finished),
+            "total_finished": to_dict(self.total_finished),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ResultDataGetTaskResultGetAll"], d: Dict[str, Any]
+        cls: t.Type["ResultDataGetTaskResultGetAll"], d: t.Dict[str, t.Any]
     ) -> "ResultDataGetTaskResultGetAll":
         parsed = cls.data_parser.try_parse(d)
 
