@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .extended_user import ExtendedUser
 
@@ -21,13 +21,13 @@ class ResultDataPostUserLogin:
     #: A JWT token that can be used to do authenticated requests.
     access_token: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "user",
-                ParserFor.make(ExtendedUser),
+                parsers.ParserFor.make(ExtendedUser),
                 doc="The user that was logged in.",
             ),
             rqa.RequiredArgument(
@@ -41,15 +41,16 @@ class ResultDataPostUserLogin:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["user"] = to_dict(self.user)
-        res["access_token"] = to_dict(self.access_token)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "user": to_dict(self.user),
+            "access_token": to_dict(self.access_token),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["ResultDataPostUserLogin"], d: Dict[str, Any]
+        cls: t.Type["ResultDataPostUserLogin"], d: t.Dict[str, t.Any]
     ) -> "ResultDataPostUserLogin":
         parsed = cls.data_parser.try_parse(d)
 
