@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -18,9 +18,9 @@ class RubricItem(BaseRubricItem):
     #: The id of this rubric item.
     id: "int"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseRubricItem.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -32,16 +32,19 @@ class RubricItem(BaseRubricItem):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["description"] = to_dict(self.description)
-        res["header"] = to_dict(self.header)
-        res["points"] = to_dict(self.points)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "description": to_dict(self.description),
+            "header": to_dict(self.header),
+            "points": to_dict(self.points),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["RubricItem"], d: Dict[str, Any]) -> "RubricItem":
+    def from_dict(
+        cls: t.Type["RubricItem"], d: t.Dict[str, t.Any]
+    ) -> "RubricItem":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
