@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -21,9 +21,9 @@ class RubricItemInputAsJSON(BaseRubricItem):
     #: omit if you want to create a new item.
     id: Maybe["int"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: BaseRubricItem.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.OptionalArgument(
@@ -43,18 +43,19 @@ class RubricItemInputAsJSON(BaseRubricItem):
         getattr(super(), "__post_init__", lambda: None)()
         self.id = maybe_from_nullable(self.id)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["description"] = to_dict(self.description)
-        res["header"] = to_dict(self.header)
-        res["points"] = to_dict(self.points)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "description": to_dict(self.description),
+            "header": to_dict(self.header),
+            "points": to_dict(self.points),
+        }
         if self.id.is_just:
             res["id"] = to_dict(self.id.value)
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["RubricItemInputAsJSON"], d: Dict[str, Any]
+        cls: t.Type["RubricItemInputAsJSON"], d: t.Dict[str, t.Any]
     ) -> "RubricItemInputAsJSON":
         parsed = cls.data_parser.try_parse(d)
 
