@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type, Union
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor, make_union
+from .. import parsers
 from ..utils import to_dict
 from .rubric_description_type import RubricDescriptionType
 from .rubric_item import RubricItem
@@ -23,21 +23,21 @@ class RubricRowBase:
     #: The header of this row.
     header: "str"
     #: The description of this row.
-    description: "Optional[str]"
+    description: "t.Optional[str]"
     #: The type of descriptions in this row.
     description_type: "RubricDescriptionType"
     #: The item in this row. The length will always be 1 for continuous rubric
     #: rows.
-    items: "Sequence[RubricItem]"
+    items: "t.Sequence[RubricItem]"
     #: Is this row locked. If it is locked you cannot update it, nor can you
     #: manually select items in it.
-    locked: "Union[RubricLockReason, bool]"
+    locked: "t.Union[RubricLockReason, bool]"
     #: The type of rubric row.
     type: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -61,7 +61,7 @@ class RubricRowBase:
             ),
             rqa.RequiredArgument(
                 "items",
-                rqa.List(ParserFor.make(RubricItem)),
+                rqa.List(parsers.ParserFor.make(RubricItem)),
                 doc=(
                     "The item in this row. The length will always be 1 for"
                     " continuous rubric rows."
@@ -69,7 +69,7 @@ class RubricRowBase:
             ),
             rqa.RequiredArgument(
                 "locked",
-                make_union(
+                parsers.make_union(
                     rqa.EnumValue(RubricLockReason), rqa.SimpleValue.bool
                 ),
                 doc=(
@@ -85,20 +85,21 @@ class RubricRowBase:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["header"] = to_dict(self.header)
-        res["description"] = to_dict(self.description)
-        res["description_type"] = to_dict(self.description_type)
-        res["items"] = to_dict(self.items)
-        res["locked"] = to_dict(self.locked)
-        res["type"] = to_dict(self.type)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "header": to_dict(self.header),
+            "description": to_dict(self.description),
+            "description_type": to_dict(self.description_type),
+            "items": to_dict(self.items),
+            "locked": to_dict(self.locked),
+            "type": to_dict(self.type),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["RubricRowBase"], d: Dict[str, Any]
+        cls: t.Type["RubricRowBase"], d: t.Dict[str, t.Any]
     ) -> "RubricRowBase":
         parsed = cls.data_parser.try_parse(d)
 
