@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 from cg_maybe import Maybe, Nothing
@@ -23,9 +23,9 @@ class RubricRowBaseInputAsJSON(RubricRowBaseInputBaseAsJSON):
     #: The type of rubric row. Will default to "normal" if not passed.
     type: Maybe["str"] = Nothing
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: RubricRowBaseInputBaseAsJSON.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.OptionalArgument(
@@ -53,11 +53,12 @@ class RubricRowBaseInputAsJSON(RubricRowBaseInputBaseAsJSON):
         self.id = maybe_from_nullable(self.id)
         self.type = maybe_from_nullable(self.type)
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["header"] = to_dict(self.header)
-        res["description"] = to_dict(self.description)
-        res["items"] = to_dict(self.items)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "header": to_dict(self.header),
+            "description": to_dict(self.description),
+            "items": to_dict(self.items),
+        }
         if self.id.is_just:
             res["id"] = to_dict(self.id.value)
         if self.type.is_just:
@@ -66,7 +67,7 @@ class RubricRowBaseInputAsJSON(RubricRowBaseInputBaseAsJSON):
 
     @classmethod
     def from_dict(
-        cls: Type["RubricRowBaseInputAsJSON"], d: Dict[str, Any]
+        cls: t.Type["RubricRowBaseInputAsJSON"], d: t.Dict[str, t.Any]
     ) -> "RubricRowBaseInputAsJSON":
         parsed = cls.data_parser.try_parse(d)
 
