@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .rubric_item_input_as_json import RubricItemInputAsJSON
 
@@ -21,11 +21,11 @@ class RubricRowBaseInputBaseAsJSON:
     #: The description of this row.
     description: "str"
     #: The items in this row.
-    items: "Sequence[RubricItemInputAsJSON]"
+    items: "t.Sequence[RubricItemInputAsJSON]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "header",
@@ -39,22 +39,23 @@ class RubricRowBaseInputBaseAsJSON:
             ),
             rqa.RequiredArgument(
                 "items",
-                rqa.List(ParserFor.make(RubricItemInputAsJSON)),
+                rqa.List(parsers.ParserFor.make(RubricItemInputAsJSON)),
                 doc="The items in this row.",
             ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["header"] = to_dict(self.header)
-        res["description"] = to_dict(self.description)
-        res["items"] = to_dict(self.items)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "header": to_dict(self.header),
+            "description": to_dict(self.description),
+            "items": to_dict(self.items),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["RubricRowBaseInputBaseAsJSON"], d: Dict[str, Any]
+        cls: t.Type["RubricRowBaseInputBaseAsJSON"], d: t.Dict[str, t.Any]
     ) -> "RubricRowBaseInputBaseAsJSON":
         parsed = cls.data_parser.try_parse(d)
 
