@@ -2,13 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
-from typing_extensions import Literal
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .file_rule_input_data import FileRuleInputData
 from .options_input_data import OptionsInputData
@@ -19,25 +18,25 @@ class SubmissionValidatorInputData:
     """The input data for the SubmissionValidator ignore type."""
 
     #: The default policy of this validator.
-    policy: "Literal['deny_all_files', 'allow_all_files']"
+    policy: "t.Literal['allow_all_files', 'deny_all_files']"
     #: The rules in this validator. If the policy is "deny\_all\_files" this
     #: should not be empty.
-    rules: "Sequence[FileRuleInputData]"
+    rules: "t.Sequence[FileRuleInputData]"
     #: The options for this validator.
-    options: "Sequence[OptionsInputData]"
+    options: "t.Sequence[OptionsInputData]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "policy",
-                rqa.StringEnum("deny_all_files", "allow_all_files"),
+                rqa.StringEnum("allow_all_files", "deny_all_files"),
                 doc="The default policy of this validator.",
             ),
             rqa.RequiredArgument(
                 "rules",
-                rqa.List(ParserFor.make(FileRuleInputData)),
+                rqa.List(parsers.ParserFor.make(FileRuleInputData)),
                 doc=(
                     "The rules in this validator. If the policy is"
                     ' "deny\\_all\\_files" this should not be empty.'
@@ -45,22 +44,23 @@ class SubmissionValidatorInputData:
             ),
             rqa.RequiredArgument(
                 "options",
-                rqa.List(ParserFor.make(OptionsInputData)),
+                rqa.List(parsers.ParserFor.make(OptionsInputData)),
                 doc="The options for this validator.",
             ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["policy"] = to_dict(self.policy)
-        res["rules"] = to_dict(self.rules)
-        res["options"] = to_dict(self.options)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "policy": to_dict(self.policy),
+            "rules": to_dict(self.rules),
+            "options": to_dict(self.options),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["SubmissionValidatorInputData"], d: Dict[str, Any]
+        cls: t.Type["SubmissionValidatorInputData"], d: t.Dict[str, t.Any]
     ) -> "SubmissionValidatorInputData":
         parsed = cls.data_parser.try_parse(d)
 
