@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .tenant_statistics import TenantStatistics
 
@@ -21,21 +21,21 @@ class Tenant:
     #: The name of the tenant
     name: "str"
     #: Maybe the id of the SSO provider connected to this tenant.
-    sso_provider_id: "Optional[str]"
+    sso_provider_id: "t.Optional[str]"
     #: Maybe the statistics of this tenant, if requested and if you have the
     #: permission to see it.
-    statistics: "Optional[TenantStatistics]"
+    statistics: "t.Optional[TenantStatistics]"
     #: The short name (or names) of the tenant. This is used to make searching
     #: for tenants by end users easier.
-    abbreviated_name: "Optional[str]"
+    abbreviated_name: "t.Optional[str]"
     #: This value determines how the tenant should be ordered. Tenants should
     #: first be ordered from highest `order_category` to lowest, and then by
     #: name.
     order_category: "int"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -57,7 +57,7 @@ class Tenant:
             ),
             rqa.RequiredArgument(
                 "statistics",
-                rqa.Nullable(ParserFor.make(TenantStatistics)),
+                rqa.Nullable(parsers.ParserFor.make(TenantStatistics)),
                 doc=(
                     "Maybe the statistics of this tenant, if requested and if"
                     " you have the permission to see it."
@@ -83,18 +83,19 @@ class Tenant:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["name"] = to_dict(self.name)
-        res["sso_provider_id"] = to_dict(self.sso_provider_id)
-        res["statistics"] = to_dict(self.statistics)
-        res["abbreviated_name"] = to_dict(self.abbreviated_name)
-        res["order_category"] = to_dict(self.order_category)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "name": to_dict(self.name),
+            "sso_provider_id": to_dict(self.sso_provider_id),
+            "statistics": to_dict(self.statistics),
+            "abbreviated_name": to_dict(self.abbreviated_name),
+            "order_category": to_dict(self.order_category),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["Tenant"], d: Dict[str, Any]) -> "Tenant":
+    def from_dict(cls: t.Type["Tenant"], d: t.Dict[str, t.Any]) -> "Tenant":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
