@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -21,9 +21,9 @@ class TenantCourseStatistics:
     #: days.
     active: "int"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "total",
@@ -42,15 +42,16 @@ class TenantCourseStatistics:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["total"] = to_dict(self.total)
-        res["active"] = to_dict(self.active)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "total": to_dict(self.total),
+            "active": to_dict(self.active),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["TenantCourseStatistics"], d: Dict[str, Any]
+        cls: t.Type["TenantCourseStatistics"], d: t.Dict[str, t.Any]
     ) -> "TenantCourseStatistics":
         parsed = cls.data_parser.try_parse(d)
 
