@@ -15,3 +15,6 @@ class UIPreferenceName(str, Enum):
     no_msg_for_nobel_2 = "no_msg_for_nobel_2"
     no_msg_for_orchid = "no_msg_for_orchid"
     no_msg_for_orchid_1 = "no_msg_for_orchid_1"
+    no_msg_for_orchid_2 = "no_msg_for_orchid_2"
+    no_msg_for_orchid_3 = "no_msg_for_orchid_3"
+    no_msg_for_perfectly_normal = "no_msg_for_perfectly_normal"
