@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .group import Group
 from .user_without_group import UserWithoutGroup
@@ -19,16 +19,16 @@ class User(UserWithoutGroup):
 
     #: If this user is a wrapper user for a group this will contain this group,
     #: otherwise it will be `null`.
-    group: "Optional[Group]"
+    group: "t.Optional[Group]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: UserWithoutGroup.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "group",
-                    rqa.Nullable(ParserFor.make(Group)),
+                    rqa.Nullable(parsers.ParserFor.make(Group)),
                     doc=(
                         "If this user is a wrapper user for a group this will"
                         " contain this group, otherwise it will be `null`."
@@ -38,18 +38,19 @@ class User(UserWithoutGroup):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["group"] = to_dict(self.group)
-        res["id"] = to_dict(self.id)
-        res["name"] = to_dict(self.name)
-        res["username"] = to_dict(self.username)
-        res["is_test_student"] = to_dict(self.is_test_student)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "group": to_dict(self.group),
+            "id": to_dict(self.id),
+            "name": to_dict(self.name),
+            "username": to_dict(self.username),
+            "is_test_student": to_dict(self.is_test_student),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["User"], d: Dict[str, Any]) -> "User":
+    def from_dict(cls: t.Type["User"], d: t.Dict[str, t.Any]) -> "User":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
