@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .course_role import CourseRole
 from .user import User
@@ -22,31 +22,34 @@ class UserCourse:
     #: The role that the user got.
     course_role: "CourseRole"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "User",
-                ParserFor.make(User),
+                parsers.ParserFor.make(User),
                 doc="The User that was added.",
             ),
             rqa.RequiredArgument(
                 "CourseRole",
-                ParserFor.make(CourseRole),
+                parsers.ParserFor.make(CourseRole),
                 doc="The role that the user got.",
             ),
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["User"] = to_dict(self.user)
-        res["CourseRole"] = to_dict(self.course_role)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "User": to_dict(self.user),
+            "CourseRole": to_dict(self.course_role),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["UserCourse"], d: Dict[str, Any]) -> "UserCourse":
+    def from_dict(
+        cls: t.Type["UserCourse"], d: t.Dict[str, t.Any]
+    ) -> "UserCourse":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
