@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -24,11 +24,11 @@ class UserWithoutGroup:
     #: Is this user a test student.
     is_test_student: "bool"
     #: The tenant of the user
-    tenant_id: "Optional[str]"
+    tenant_id: "t.Optional[str]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -61,18 +61,19 @@ class UserWithoutGroup:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["name"] = to_dict(self.name)
-        res["username"] = to_dict(self.username)
-        res["is_test_student"] = to_dict(self.is_test_student)
-        res["tenant_id"] = to_dict(self.tenant_id)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "name": to_dict(self.name),
+            "username": to_dict(self.username),
+            "is_test_student": to_dict(self.is_test_student),
+            "tenant_id": to_dict(self.tenant_id),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["UserWithoutGroup"], d: Dict[str, Any]
+        cls: t.Type["UserWithoutGroup"], d: t.Dict[str, t.Any]
     ) -> "UserWithoutGroup":
         parsed = cls.data_parser.try_parse(d)
 
