@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -29,9 +29,9 @@ class WebhookBase:
     #: The default branch configured by the teacher, currently not used.
     default_branch: "str"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -78,19 +78,20 @@ class WebhookBase:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["public_key"] = to_dict(self.public_key)
-        res["assignment_id"] = to_dict(self.assignment_id)
-        res["user_id"] = to_dict(self.user_id)
-        res["secret"] = to_dict(self.secret)
-        res["default_branch"] = to_dict(self.default_branch)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "public_key": to_dict(self.public_key),
+            "assignment_id": to_dict(self.assignment_id),
+            "user_id": to_dict(self.user_id),
+            "secret": to_dict(self.secret),
+            "default_branch": to_dict(self.default_branch),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["WebhookBase"], d: Dict[str, Any]
+        cls: t.Type["WebhookBase"], d: t.Dict[str, t.Any]
     ) -> "WebhookBase":
         parsed = cls.data_parser.try_parse(d)
 
