@@ -3,12 +3,12 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .user import User
 from .work_origin import WorkOrigin
@@ -29,19 +29,19 @@ class Work:
     created_at: "datetime.datetime"
     #: The grade of the submission, or `None` if the submission hasn't been
     #: graded of you cannot see the grade.
-    grade: "Optional[float]"
+    grade: "t.Optional[float]"
     #: The user assigned to this submission. Or `None` if not assigned or if
     #: you may not see the assignee.
-    assignee: "Optional[User]"
+    assignee: "t.Optional[User]"
     #: Does this submission have a rubric grade which has been overridden.
     grade_overridden: "bool"
     #: Some extra info that might be available. Currently only used for git
     #: submissions.
-    extra_info: "Any"
+    extra_info: "t.Any"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "id",
@@ -50,7 +50,7 @@ class Work:
             ),
             rqa.RequiredArgument(
                 "user",
-                ParserFor.make(User),
+                parsers.ParserFor.make(User),
                 doc=(
                     "The author of the submission. If submission was created"
                     " by a group this will be the virtual user of the group."
@@ -76,7 +76,7 @@ class Work:
             ),
             rqa.RequiredArgument(
                 "assignee",
-                rqa.Nullable(ParserFor.make(User)),
+                rqa.Nullable(parsers.ParserFor.make(User)),
                 doc=(
                     "The user assigned to this submission. Or `None` if not"
                     " assigned or if you may not see the assignee."
@@ -101,20 +101,21 @@ class Work:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["id"] = to_dict(self.id)
-        res["user"] = to_dict(self.user)
-        res["origin"] = to_dict(self.origin)
-        res["created_at"] = to_dict(self.created_at)
-        res["grade"] = to_dict(self.grade)
-        res["assignee"] = to_dict(self.assignee)
-        res["grade_overridden"] = to_dict(self.grade_overridden)
-        res["extra_info"] = to_dict(self.extra_info)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "id": to_dict(self.id),
+            "user": to_dict(self.user),
+            "origin": to_dict(self.origin),
+            "created_at": to_dict(self.created_at),
+            "grade": to_dict(self.grade),
+            "assignee": to_dict(self.assignee),
+            "grade_overridden": to_dict(self.grade_overridden),
+            "extra_info": to_dict(self.extra_info),
+        }
         return res
 
     @classmethod
-    def from_dict(cls: Type["Work"], d: Dict[str, Any]) -> "Work":
+    def from_dict(cls: t.Type["Work"], d: t.Dict[str, t.Any]) -> "Work":
         parsed = cls.data_parser.try_parse(d)
 
         res = cls(
