@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -23,9 +23,9 @@ class WorkRubricItem(RubricItem):
     #: `points` field multiplied by the `multiplier` field.
     achieved_points: "float"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: RubricItem.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
@@ -51,19 +51,20 @@ class WorkRubricItem(RubricItem):
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["multiplier"] = to_dict(self.multiplier)
-        res["achieved_points"] = to_dict(self.achieved_points)
-        res["id"] = to_dict(self.id)
-        res["description"] = to_dict(self.description)
-        res["header"] = to_dict(self.header)
-        res["points"] = to_dict(self.points)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "multiplier": to_dict(self.multiplier),
+            "achieved_points": to_dict(self.achieved_points),
+            "id": to_dict(self.id),
+            "description": to_dict(self.description),
+            "header": to_dict(self.header),
+            "points": to_dict(self.points),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["WorkRubricItem"], d: Dict[str, Any]
+        cls: t.Type["WorkRubricItem"], d: t.Dict[str, t.Any]
     ) -> "WorkRubricItem":
         parsed = cls.data_parser.try_parse(d)
 
