@@ -2,12 +2,12 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Sequence, Type
 
 import cg_request_args as rqa
 
-from ..parsers import ParserFor
+from .. import parsers
 from ..utils import to_dict
 from .rubric_row_base import RubricRowBase
 from .work_rubric_item import WorkRubricItem
@@ -19,20 +19,20 @@ class WorkRubricResultAsJSON:
     """The rubric result of a single submission."""
 
     #: A list of rubric rows that make up the rubric of this assignment.
-    rubrics: "Sequence[RubricRowBase]"
+    rubrics: "t.Sequence[RubricRowBase]"
     #: A list of all the selected rubric items for this work, or an empty list
     #: if the logged in user doesn't have permission to see the rubric.
-    selected: "Sequence[WorkRubricItem]"
+    selected: "t.Sequence[WorkRubricItem]"
     #: The points achieved by this submission and possible in this rubric.
     points: "WorkRubricResultPointsAsJSON"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "rubrics",
-                rqa.List(ParserFor.make(RubricRowBase)),
+                rqa.List(parsers.ParserFor.make(RubricRowBase)),
                 doc=(
                     "A list of rubric rows that make up the rubric of this"
                     " assignment."
@@ -40,7 +40,7 @@ class WorkRubricResultAsJSON:
             ),
             rqa.RequiredArgument(
                 "selected",
-                rqa.List(ParserFor.make(WorkRubricItem)),
+                rqa.List(parsers.ParserFor.make(WorkRubricItem)),
                 doc=(
                     "A list of all the selected rubric items for this work, or"
                     " an empty list if the logged in user doesn't have"
@@ -49,7 +49,7 @@ class WorkRubricResultAsJSON:
             ),
             rqa.RequiredArgument(
                 "points",
-                ParserFor.make(WorkRubricResultPointsAsJSON),
+                parsers.ParserFor.make(WorkRubricResultPointsAsJSON),
                 doc=(
                     "The points achieved by this submission and possible in"
                     " this rubric."
@@ -58,16 +58,17 @@ class WorkRubricResultAsJSON:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["rubrics"] = to_dict(self.rubrics)
-        res["selected"] = to_dict(self.selected)
-        res["points"] = to_dict(self.points)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "rubrics": to_dict(self.rubrics),
+            "selected": to_dict(self.selected),
+            "points": to_dict(self.points),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["WorkRubricResultAsJSON"], d: Dict[str, Any]
+        cls: t.Type["WorkRubricResultAsJSON"], d: t.Dict[str, t.Any]
     ) -> "WorkRubricResultAsJSON":
         parsed = cls.data_parser.try_parse(d)
 
