@@ -2,8 +2,8 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import typing as t
 from dataclasses import dataclass, field
-from typing import Any, ClassVar, Dict, Optional, Type
 
 import cg_request_args as rqa
 
@@ -16,14 +16,14 @@ class WorkRubricResultPointsAsJSON:
 
     #: The maximal amount of points for this rubric, or None if logged in user
     #: doesn't have permission to see the rubric.
-    max: "Optional[float]"
+    max: "t.Optional[float]"
     #: The amount of point that is selected for this work, or None if the
     #: logged in user doesn't have permission to see the rubric.
-    selected: "Optional[float]"
+    selected: "t.Optional[float]"
 
-    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
-    data_parser: ClassVar = rqa.Lazy(
+    data_parser: t.ClassVar = rqa.Lazy(
         lambda: rqa.FixedMapping(
             rqa.RequiredArgument(
                 "max",
@@ -46,15 +46,16 @@ class WorkRubricResultPointsAsJSON:
         ).use_readable_describe(True)
     )
 
-    def to_dict(self) -> Dict[str, Any]:
-        res: Dict[str, Any] = {}
-        res["max"] = to_dict(self.max)
-        res["selected"] = to_dict(self.selected)
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        res: t.Dict[str, t.Any] = {
+            "max": to_dict(self.max),
+            "selected": to_dict(self.selected),
+        }
         return res
 
     @classmethod
     def from_dict(
-        cls: Type["WorkRubricResultPointsAsJSON"], d: Dict[str, Any]
+        cls: t.Type["WorkRubricResultPointsAsJSON"], d: t.Dict[str, t.Any]
     ) -> "WorkRubricResultPointsAsJSON":
         parsed = cls.data_parser.try_parse(d)
 
