@@ -14,8 +14,11 @@ import warnings
 from dataclasses import dataclass
 
 import cg_maybe
+import cg_request_args as rqa
 import structlog
 
+from . import parsers
+
 if t.TYPE_CHECKING:
     from httpx import Response
 
@@ -52,8 +55,6 @@ def to_multipart(dct: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
 
 
 def to_dict(obj: t.Any) -> t.Any:
-    from .models.types import File
-
     if obj is None:
         return None
     elif isinstance(obj, (str, bool, int, float)):
@@ -72,20 +73,50 @@ def to_dict(obj: t.Any) -> t.Any:
         return obj.isoformat()
     elif isinstance(obj, datetime.timedelta):
         return obj.total_seconds()
-    elif isinstance(obj, File):
+
+    from .models.types import File
+
+    if isinstance(obj, File):
         return obj.to_tuple()
-    else:
+    elif hasattr(obj, "to_dict"):
         return obj.to_dict()
 
+    import decimal
+
+    if isinstance(obj, decimal.Decimal):
+        return str(obj)
+
+    raise AssertionError("Don't know how to serialize {!r}".format(obj))
+
+
+def unpack_union(typ: t.Any) -> t.Tuple[t.Type, ...]:
+    if getattr(typ, "__origin__", None) == t.Union:
+        subs = typ.__args__
+        if any(hasattr(el, "__origin__") for el in subs):
+            return tuple(s for sub in subs for s in unpack_union(sub))
+        return subs
+    return (typ,)
+
 
 def get_error(
     response: "Response",
-    code_errors: t.Sequence[t.Tuple[t.Sequence[t.Union[str, int]], t.Any]],
+    code_errors: t.Sequence[
+        t.Tuple[t.Sequence[t.Union[str, int]], t.Sequence[t.Any]]
+    ],
 ) -> Exception:
     found_code = response.status_code
-    for codes, make_error in code_errors:
-        if any(response_code_matches(found_code, code) for code in codes):
-            return make_error.from_dict(response.json(), response=response)
+    for codes, make_errors in code_errors:
+        if not any(response_code_matches(found_code, code) for code in codes):
+            continue
+        json_data = response.json()
+        for idx, make_error in enumerate(make_errors):
+            last = idx + 1 == len(make_errors)
+            try:
+                return make_error.from_dict(json_data, response=response)
+            except rqa.ParseError:
+                if last:
+                    raise
+                continue
 
     from .errors import ApiResponseError
 
